/**
 * Copyright (c) 2025 Enzien Audio, Ltd.
 * 
 * Redistribution and use in source and binary forms, with or without modification,
 * are permitted provided that the following conditions are met:
 * 
 * 1. Redistributions of source code must retain the above copyright notice,
 *    this list of conditions, and the following disclaimer.
 * 
 * 2. Redistributions in binary form must reproduce the phrase "powered by heavy",
 *    the heavy logo, and a hyperlink to https://enzienaudio.com, all in a visible
 *    form.
 * 
 *   2.1 If the Application is distributed in a store system (for example,
 *       the Apple "App Store" or "Google Play"), the phrase "powered by heavy"
 *       shall be included in the app description or the copyright text as well as
 *       the in the app itself. The heavy logo will shall be visible in the app
 *       itself as well.
 * 
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
 * SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
 * CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
 * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 * 
 */

#ifndef _HEAVY_CONTEXT_CHAFFVERB_HPP_
#define _HEAVY_CONTEXT_CHAFFVERB_HPP_

// object includes
#include "HeavyContext.hpp"
#include "HvControlIf.h"
#include "HvControlSlice.h"
#include "HvMath.h"
#include "HvControlSystem.h"
#include "HvSignalDel1.h"
#include "HvSignalPhasor.h"
#include "HvControlPack.h"
#include "HvControlBinop.h"
#include "HvControlRandom.h"
#include "HvTable.h"
#include "HvControlUnop.h"
#include "HvControlVar.h"
#include "HvControlTabhead.h"
#include "HvSignalRPole.h"
#include "HvSignalLine.h"
#include "HvSignalTabwrite.h"
#include "HvSignalVar.h"
#include "HvControlDelay.h"
#include "HvControlCast.h"
#include "HvSignalTabread.h"

class Heavy_ChaffVerb : public HeavyContext {

 public:
  Heavy_ChaffVerb(double sampleRate, int poolKb=10, int inQueueKb=2, int outQueueKb=0);
  ~Heavy_ChaffVerb();

  const char *getName() override { return "ChaffVerb"; }
  int getNumInputChannels() override { return 1; }
  int getNumOutputChannels() override { return 2; }

  int process(float **inputBuffers, float **outputBuffer, int n) override;
  int processInline(float *inputBuffers, float *outputBuffer, int n) override;
  int processInlineInterleaved(float *inputBuffers, float *outputBuffer, int n) override;

  int getParameterInfo(int index, HvParameterInfo *info) override;
  struct Parameter {
    struct In {
      enum ParameterIn : hv_uint32_t {
        A__LFO_PERIOD = 0x1F30993F, // A__LFO_Period
        A__LFO_STEPS_SCALE__TYPE2 = 0x1A2B8E9F, // A__LFO_Steps_Scale__Type2
        A__LFO_STEPS__TYPE2 = 0xBE3344C8, // A__LFO_Steps__Type2
        A__LFO_SWITCH = 0x7369936E, // A__LFO_Switch
        A__LFO_TYPE = 0xD64CFD23, // A__LFO_type
        B__GENERAL_OFFSET = 0x51447E19, // B__General_Offset
        B__GENERAL_SCALE = 0xA10FCFC4, // B__General_Scale
        C__RANDOM_LFO_OFFSET = 0x7EFB8E46, // C__Random_LFO_Offset
        C__RANDOM_LFO_PERIOD = 0xE6223016, // C__Random_LFO_Period
        C__RANDOM_LFO_SCALE = 0x3281900D, // C__Random_LFO_Scale
        C__RANDOM_LFO_SWITCH = 0x6150BC53, // C__Random_LFO_Switch
        D__SHIFT_MICROTONE = 0x9CBB1BF3, // D__Shift_Microtone
        D__SHIFT_TRANSPOSE = 0x4439D71, // D__Shift_Transpose
        E__FX_LEVEL = 0x890283C2, // E__Fx_Level
        E__HIPASS_FREQ = 0x12962685, // E__HiPass_Freq
        E__SHIFT_DELAY = 0x183CFEE5, // E__Shift_Delay
        E__SHIFT_WINDOW = 0x57FF40DB, // E__Shift_Window
        F__FX_DELAY = 0x69A91334, // F__FX_Delay
        F__FX_DELAY_FEEDBACK = 0x68D029F7, // F__FX_Delay_Feedback
        MIX__DRY_MIX = 0xD63693D0, // Mix__Dry_Mix
        MIX__DRY_VOL = 0x1FC3C02C, // Mix__Dry_Vol
        MIX__REVERB_LEVEL = 0x58653D84, // Mix__Reverb_Level
        MIX__REVERB_VOL = 0xE764F673, // Mix__Reverb_Vol
      };
    };
  };

 private:
  HvTable *getTableForHash(hv_uint32_t tableHash) override;
  void scheduleMessageForReceiver(hv_uint32_t receiverHash, HvMessage *m) override;

  // static sendMessage functions
  static void cVar_lXxlgfO4_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_7MbsimwS_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cPack_JnDlv10b_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_b2p1m7YB_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Zh7t3Okk_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_OrDrXnVN_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cPack_Dc2LNeH7_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_UL2ol6A2_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_KiqH7N3e_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_49DsYQhA_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_h5HXNvy5_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_FwaTouMV_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_24QHJZ99_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_zQMMbaZV_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cBinop_XGwzhjzI_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void hTable_zsW0V9Hn_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_C6LVgQif_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_cpibFMpy_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_GbpS8FR4_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_KcDDHdQ8_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_LFuz5zmT_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_LCewfMGV_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_hqXcXCS6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_Kzq1CJlg_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_9LdQQRSE_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_Zxq2Mpw1_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Gr73LdCp_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_F8J3s4Oc_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_SMCJBBqb_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_dzwlQ8yr_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_SFKkYO99_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_VDMWxd5L_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_PvjOpz0A_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_UWZf5Arl_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_VIHWfnRX_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Kg6VSYkq_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_9YPnedFk_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_YmgNSY0g_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_TunEROEO_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_lv1ldXyv_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_qx0zFwoh_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_myvI8aY5_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_GzjPvs71_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_sk4G2NNZ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_5Zwx29KP_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_Tnl6GXQ3_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_q4m76GIB_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cCast_8MGOImg1_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_v7TX9nwX_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_Oq4VDROj_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_hE58INCt_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_E2QDkBQW_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_nf9bFbxt_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_0ABzFTWn_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_tM0WCdnf_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_slgZWHUr_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_SAZLYNV7_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_4CTNR7wT_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_BeQhLTKR_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_u7bu2LTu_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_qDXMKApv_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_3xEedHFL_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_dXCBArab_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_KO2biodD_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cBinop_ORNG1vW4_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_uDRgycvF_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cRandom_XWvwig7a_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSlice_pttd8ARc_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_iGciybF6_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cDelay_v67z7oCV_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_dmOVJpVF_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_IPJQniWW_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_IYQtuPBy_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_d2qJXo7W_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_EseZzuqe_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_ojuoyhbl_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_pMsyPUYG_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_3YXVX8XL_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cTabhead_cp8DKvRz_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_aNZLIfOi_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_JIOixkVV_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_wGus0R6b_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_DVp19DqI_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_mdDbTQdy_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void sTabread_aLsECrs5_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_uLbmFaDf_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_kOaSnZLB_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_fVGFCkaH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_9YnEvjMj_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_BBjZGbx4_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_QVGIcV1u_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_2LVo4F5W_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_49OAiD0B_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_FnqBI9HT_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_2DlPEkE6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_nPo6Grx0_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_D0yQKCFL_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cTabhead_qyVXGops_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_jGhbUYvn_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_FzLYNXuY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_dLvNv0er_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_V5j2xK8K_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_m6c3071s_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void sTabread_FBDeFP8S_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_UyLp72gY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_3c9k9iGQ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_LREEgvuE_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_uMUDG6sv_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_1gzbasGJ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_dKq5w5w0_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_cEEB3nYX_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_EkoQ1nIp_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_66D8IQnO_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_gcocd51C_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_J8ALRGNG_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_KEZ7aXOr_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cTabhead_P1m3wftP_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_vbCACrHm_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_krVm5EWM_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_n1oflsyY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_mpHhGTaY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_HMWEF90w_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void sTabread_liVnSrA8_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_hHnbP7Yt_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_5Ql6tYZl_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_GP3DzkRX_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_UDGVAgPH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_ctBhqNLe_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_yyiTrMYJ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_rBaptnYC_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_4Y3ObtZq_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_B1tUpPC7_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_vDp7IfdS_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_799Iq6pv_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_zpZpNSGt_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cTabhead_KfIdq9l7_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_sPA6I0qg_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_9SwhbgQg_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_EkCzpM1O_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_7S1KZvdo_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_lbpB2sQk_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void sTabread_Ry19IS0x_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_rgDYRb2o_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_QKT5vwr5_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_v2X9NAqX_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_U5NGGgij_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_6sYmSvTA_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_WdA9uwcw_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_OLHvVK9X_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_noiJ837D_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_nKsPoQ3c_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_t1P7sFjR_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Fg2dgbHZ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_KuhPdGMC_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_bjyCPvFF_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_zhxXX1GK_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_OnyvvNtf_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_TbTtX9QR_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_gHU2Eqip_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cBinop_PZ3sMFAB_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void hTable_Eps2MvSJ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_ngkVZZxq_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_RdQ7dKzq_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_dlfPmO6r_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_WO260VSV_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_3SgOnsHV_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_gj7BlVjW_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_DsiVNcQb_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_XsamwVLR_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_w9xCtA1d_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_b7Pya8Kj_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_bf8mzpgo_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cBinop_VMuzdFJ1_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void hTable_sr6568YJ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_ehkRXXs9_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_4kGvYquZ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_seMzIF8K_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_J7BT5ni1_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_mloesGpo_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_ZzgLPTUk_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_m0sszrfW_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_k4kj7rJ2_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_slID6Kuw_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_UT1eM8Xk_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_dbuNnMrI_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cBinop_x2xAnWtD_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void hTable_g4BTC3wP_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_52D68G4S_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_UvKieLFl_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_QILHz5k5_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_2sSsi7mG_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_YmO9Zaqe_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_YL5j9Piu_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_viGNWezD_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_jfdP1P6G_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_ITeKRD7a_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_GyQxUJy2_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_AHU2xSJe_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cBinop_7gYTMIlz_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void hTable_qOqD14n5_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_71tRBKre_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_08Jtwm3N_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_oyOjntgU_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_1EXM9QII_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_E7Dtdojl_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_YUFMCfVh_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cPack_Feo0fVsu_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cPack_RjH0cWG9_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_xe58P1uL_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_w4jobXk5_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_jGto9i39_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_214ERUVM_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_E54lsimN_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_wmoKavlJ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_tdy0lSwP_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_ElROhqT3_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_3fndkk86_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_dWlBDYJe_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Ygl558Ss_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_blvX2ydM_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_65zwXySq_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_ZdJmEBbE_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_sGcl5Qwr_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_h10lexHY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_ZDd8Ne8W_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_ZFlNfDh2_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_e4EqgeNa_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_4AotWg2y_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_x0KHbQxu_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_zMB4UTuL_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_dhJ6cAA1_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_vcW9m2j1_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cBinop_EhHIs5mM_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void hTable_xGZuUzoO_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_3GSJbnY7_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_zDZAy9my_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_7zscxphT_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_Z4glxh02_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_btswxNgQ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_FMQdWcsS_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cTabhead_nqB3ukpi_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_bNQYXxiz_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_Zngtq97s_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_62QYKRhC_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_ViDyMgie_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_HNhLI4vH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void sTabread_B8TSCxn7_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_nFDlVs82_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_cduEeBvF_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_fPBThhAH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_7Cchl65p_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_5PT538YM_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_ldyPCwEY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_QG1mDwBf_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_emGdXwmU_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_O5FtunzE_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_v1aXrnAR_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_ke7WZ7QG_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_dSEBc1NJ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_JBIbhXu0_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_M6rtfRtu_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_rgpIIC9o_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_fiNJNCEq_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_bqAYOPCF_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cBinop_GgbrtthD_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void hTable_A244hBPz_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_9bvFpxoC_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_DsNaO0VD_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_Y50N5pde_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_9GD87Dva_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_IQZwZlv6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_H22CIIh6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cTabhead_MtHrWXUm_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_HapOxkwp_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_EPyr4fG9_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_vo0ItMgB_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_y2nn0Mj3_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_zfA4a6RR_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void sTabread_gssM6Xbp_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_PStHN48S_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_LmJu4r0C_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_6u7bK4kB_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_bhSEz0r7_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_8dTsAK3K_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_0yBlWJ1t_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_yvQht1tf_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_NEQoKrkL_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_FoCecrBR_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_FGFDpo0R_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_5J6P3Yyt_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_JqItHm3u_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_ZXWLgNUv_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_Yhve36PC_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_iypBPLuO_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_n4NNm6dP_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_QfUuftq5_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cBinop_f9d1Od5e_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void hTable_5OulVBgr_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_B3E65ifP_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_AWCfKC6g_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_2rCI8hMs_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_EQCkP0lp_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_XZEyYkIE_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_KBp8R5nJ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cTabhead_Bf5vLuO2_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_01JXROjJ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_9HILazzx_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_QrDb74mu_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_K8Vs0wJf_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_kVosGtY4_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void sTabread_v8gCgSiv_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_0EwkmSEz_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_VtJxyi8r_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_fJptWI1S_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_AslDTVux_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_gCCOtrwk_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_rD4UGjU6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_KAC4ltPi_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_OT8AoKAs_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_tClkyjUI_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Uvs25FpE_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_2wWiTxt8_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_CoziC7wg_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_kgMVc8YN_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_DJ8tfQKR_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_7Cm1ar95_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_Xkz3sWye_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_gYJu3FsG_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cBinop_kpJNBvRv_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void hTable_e8Zi7Pf6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_YovCtGzB_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_LXfxwPyS_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_XyrS2IiM_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_Lah1jXZk_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_EApGLeHe_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_RAMpU478_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cTabhead_yOkCpBwB_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_DDd1dlqu_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_uN1AWtmT_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_t9necXUl_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_my2S714P_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_Fzhj7ZOI_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void sTabread_ZVwjGSWx_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_KrNtIfvt_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_S9K7wzu2_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_aUWyUbZo_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_YjO3tmU3_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_GWdR1aW2_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_Dp85eN7j_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_Q21h6JmA_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_X4q3LnIe_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_37znPZgs_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_QqBVM2vX_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_gNffPjtz_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_pfYZ3S2a_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_YTsoLAqd_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_WFoQLeiY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_DpvaXwoc_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_bQNsFYwR_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_q8f2EL2V_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cBinop_AgF5Nunx_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void hTable_0cmOncnb_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_JTCm1OuA_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Y1mjW6NA_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_3noBNWEF_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_t661bjwH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_VIDemjHa_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_CTcXMX3B_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cTabhead_cOmUfBdC_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_8TUPkLkk_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_R8qq16HC_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_DFJ56Zu6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_23V8iOrc_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_no5yuAjf_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void sTabread_TFCHpICr_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_JyKTYS8e_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_IVQuUBBp_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_gzuK59tM_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_fFpDUKp1_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_rDwbPRBk_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_w46LlxmX_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_ZGK52a5t_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_MHlkycL7_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_ae9hnlAs_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_HGJ8gotB_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_JUP0nQUK_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_BmaVUM2B_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_FXDNwlmu_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_oig5zwQD_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_D8eNURnR_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_pDhpiC5s_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_8Azqv0M2_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cBinop_mm584gCn_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void hTable_rTItxtkE_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_fAYtOtdy_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_yMW2AOfQ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_pQFuUVoo_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_eiDW3vmV_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_y0nyJfw4_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_84O7eLQU_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cTabhead_FH5Gvk0k_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_hTOqHfVJ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_FZcciHkH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_94vzqeN3_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_td8lCfjZ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_pke6KglM_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void sTabread_pYhq9TgO_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_GJreoSMn_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_dgbylb5J_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_KKX9lSn6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_1bHF6n6l_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_tgBiG7hp_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_B70cxg5c_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_1i077q1J_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_1EuTNfZM_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_zGDaO83X_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_v8suJI8y_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_jWT5rigJ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_WVoKvUxv_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_TGzMkoH6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_qSSYcbjm_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cPack_RRU1jAF3_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_DQO2LvfY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_6rVWRQZl_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_rrP01qTB_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_T2HGY8sq_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_tFdXg6Wz_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_Tw4hedzd_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_cyUtsLVy_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Vxfa1dSl_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_vIFiiZy2_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_I5gaO0tC_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_DevgMWxx_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_CFeYEX3O_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_1H5j2EIH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_GugZM4e1_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_iyQ4JI3b_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_QoHyU8By_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Vuv6CKDm_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_ZIiG2u8D_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_KRCt0WBa_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_AiAnWgne_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_RB5LB5vo_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_KmUHnfLf_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_qUduBKAu_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_Jf3VMLAe_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_YtyGQkaW_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_bp77vhaj_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_XvhezXue_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_7LBiOp3M_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_Ru8iaJgG_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_26E2dheE_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_JzTiV4RG_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_ImglQkga_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cDelay_iFVceLaD_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_ym3Suejl_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_cNbjylTe_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_4nN2Ctge_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_JHWFBLAA_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_uZXXAIYx_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_5XYWwCJS_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Nbi1VT6O_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_NstkuakS_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_OuBkSOsn_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_cXWBY3z9_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_UOOoXqVU_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_0ZiSBKNV_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_MKXPThwJ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_0IShaIPC_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_pgfhv5Ee_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_jMgRbzff_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_5TmdQh2y_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_5vudOYti_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_PK2e5FCs_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cBinop_cywfDSqm_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void hTable_oXYCtuD5_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_PPLV3ke1_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_L0Yj6o9G_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_5cgpHbvL_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_ycjB3HwL_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_mQIG75Be_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_pgvqxetJ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cTabhead_WKn3hzaV_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_NiTP1fJl_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_GxapFaNh_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_abx5UgOt_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_4ideaiAI_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_VmNNfjvg_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void sTabread_MBpVdwiF_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_OipbTnGn_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_8gnUypQZ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_gqaUsNxb_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_ZVzoKqHe_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_wL1NDUXC_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_KXlUWkCu_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_ZFvvdrqI_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_HgRsJ0CK_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_kaGULr3R_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_L1p15rV2_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_4vgvX2Dg_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_NRRgyJSI_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_tRepiiKO_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cCast_RuPkr1oT_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_RayvicSX_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_D0PC9qMs_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cCast_Vo5xFsfJ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_VMcLwNaV_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_D5qtwWo5_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_Gzvjcgdo_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_Dy0ddCKf_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_eUyh8bzR_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_qYJLrLjb_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_0ysSkxwj_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_GxPrETHx_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_8RATZrXq_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_w0Yog419_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_txorMjqT_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_F4l19tyG_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_kZ7l6slT_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_i9gALaeC_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_KxDIFLft_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_NrY6ecRa_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSlice_FpV2fsVZ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_vGKcHmze_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_tirxjr7F_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_L5QelSwy_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_vf2l2wZQ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_ADwXGBqB_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_3Pj5UZpE_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_UzKO3JJ0_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_RKwV0BYN_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_AxC4FC0r_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_CCdcjYus_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_YzPmdZjq_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_3S3klRuP_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_xOObeuXx_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_Kpu5Xpzv_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_6Nt4UG02_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_KQE5if51_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_vX1elQre_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_nwEeAe6X_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_lB9xPzai_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_fchnKVOE_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_8zCgvJkM_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_INDGEanL_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_6QYovvZZ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_QNO7eqAJ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_RuLju4zG_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_UUZBFZbJ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_x1raXrcS_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_4C6K0X2G_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_ZvsuUsqq_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_40p842Kz_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_klI8fYA9_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Q4XgR5Hy_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Y3gykJRK_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_T4dJmJGJ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_DQIaGrMG_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_tj25aSOn_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_xG5WAEvV_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_S1cvVh5B_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Q5PW5Apn_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Eu5XNvYU_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_jX3eoTPD_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_K3g6VAIF_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_X2hkyRX2_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_XRVxYpn6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_cu3XqxHu_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_9KXXAcmN_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_TsZ884bh_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_SKmDvzfp_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_BpaOuBCv_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_icsTl5oz_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_bnocvfW9_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_99SszjlU_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_s4j6h4NY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_SLeVZYQu_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_ZcSrvbRs_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_X7dflLAf_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_crlAZQbq_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_zkWX3CVd_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_488053y6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_ZlsdcSog_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_cQcNDf3w_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_bAdbvxb0_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_8UboToci_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_8J387eUF_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_QT5czTTM_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_HJav80r1_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_M2aZR2uM_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_aYM6HSmC_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_mzVLspDl_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_sxSkmtjU_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_oQbZ2gro_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_MGRnV4rq_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_EzkQWw0E_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_hRdBO2Te_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_y9abJ4C7_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_OLmy2yPO_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_EHCCCnuP_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_upRSlT4T_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_TlWq6lUv_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_Cg20Zzis_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_OY31OVQS_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_2EYMm4I7_sendMessage(HeavyContextInterface *, int, const HvMessage *);

  // objects
  SignalPhasor sPhasor_oMM6tSkH;
  SignalLine sLine_UVTMOFJw;
  SignalLine sLine_KxXNQs2p;
  SignalTabhead sTabhead_TMrZvmRx;
  SignalTabread sTabread_Gn5B9YNe;
  SignalTabread sTabread_5AlxjDo1;
  SignalTabhead sTabhead_EDOuBrpS;
  SignalTabread sTabread_7H0P0rF2;
  SignalTabread sTabread_KlTbtfq8;
  SignalTabwrite sTabwrite_3dVaqRWN;
  SignalRPole sRPole_o2U1PGba;
  SignalDel1 sDel1_JhcQu2FE;
  SignalTabread sTabread_MBpVdwiF;
  SignalTabwrite sTabwrite_SXsn9obO;
  SignalTabread sTabread_aLsECrs5;
  SignalRPole sRPole_C9ZoRDL8;
  SignalLine sLine_v8sA6rWG;
  SignalLine sLine_woutXzoG;
  SignalTabread sTabread_B8TSCxn7;
  SignalTabread sTabread_gssM6Xbp;
  SignalTabread sTabread_v8gCgSiv;
  SignalTabread sTabread_ZVwjGSWx;
  SignalTabread sTabread_pYhq9TgO;
  SignalTabread sTabread_TFCHpICr;
  SignalTabwrite sTabwrite_406QjmMR;
  SignalTabwrite sTabwrite_WjBDwhFo;
  SignalTabwrite sTabwrite_tE63Zqi9;
  SignalTabwrite sTabwrite_pNsH1xbf;
  SignalTabwrite sTabwrite_xAbXIcpY;
  SignalTabwrite sTabwrite_sDmtIoVv;
  SignalTabread sTabread_FBDeFP8S;
  SignalRPole sRPole_mih8cdmK;
  SignalTabread sTabread_liVnSrA8;
  SignalRPole sRPole_1icqCNb4;
  SignalTabread sTabread_Ry19IS0x;
  SignalRPole sRPole_u80nZf9u;
  SignalTabwrite sTabwrite_crqYqLHh;
  SignalTabwrite sTabwrite_nUc2GthC;
  SignalTabwrite sTabwrite_5IRUmwEX;
  SignalTabwrite sTabwrite_NZHBFcRO;
  SignalLine sLine_gMJPoKz9;
  ControlVar cVar_lXxlgfO4;
  ControlVar cVar_7MbsimwS;
  ControlPack cPack_JnDlv10b;
  ControlBinop cBinop_Zh7t3Okk;
  ControlVar cVar_OrDrXnVN;
  ControlPack cPack_Dc2LNeH7;
  ControlVar cVar_UL2ol6A2;
  ControlVar cVar_KiqH7N3e;
  ControlDelay cDelay_FwaTouMV;
  ControlDelay cDelay_24QHJZ99;
  ControlBinop cBinop_XGwzhjzI;
  HvTable hTable_zsW0V9Hn;
  ControlBinop cBinop_cpibFMpy;
  ControlVar cVar_9LdQQRSE;
  ControlBinop cBinop_Gr73LdCp;
  ControlBinop cBinop_SMCJBBqb;
  SignalVarf sVarf_mCi7Rvj4;
  SignalVarf sVarf_gJcP0uUO;
  SignalVarf sVarf_ulhN83Qc;
  ControlVar cVar_VDMWxd5L;
  ControlBinop cBinop_UWZf5Arl;
  ControlBinop cBinop_Kg6VSYkq;
  SignalVarf sVarf_Br5dP5pX;
  SignalVarf sVarf_F6GntIho;
  SignalVarf sVarf_v3sNsTsi;
  ControlBinop cBinop_9YPnedFk;
  ControlBinop cBinop_YmgNSY0g;
  ControlBinop cBinop_qx0zFwoh;
  ControlBinop cBinop_myvI8aY5;
  ControlBinop cBinop_GzjPvs71;
  ControlBinop cBinop_sk4G2NNZ;
  ControlBinop cBinop_5Zwx29KP;
  ControlBinop cBinop_hE58INCt;
  ControlBinop cBinop_E2QDkBQW;
  SignalVarf sVarf_ZzPSROtU;
  ControlVar cVar_nf9bFbxt;
  ControlBinop cBinop_slgZWHUr;
  ControlBinop cBinop_SAZLYNV7;
  ControlBinop cBinop_BeQhLTKR;
  ControlBinop cBinop_u7bu2LTu;
  ControlBinop cBinop_qDXMKApv;
  ControlBinop cBinop_3xEedHFL;
  ControlBinop cBinop_dXCBArab;
  SignalVarf sVarf_05SywGIo;
  ControlBinop cBinop_ORNG1vW4;
  ControlRandom cRandom_XWvwig7a;
  ControlSlice cSlice_pttd8ARc;
  ControlDelay cDelay_v67z7oCV;
  ControlVar cVar_d2qJXo7W;
  ControlBinop cBinop_ojuoyhbl;
  ControlBinop cBinop_pMsyPUYG;
  ControlBinop cBinop_3YXVX8XL;
  ControlTabhead cTabhead_cp8DKvRz;
  ControlVar cVar_wGus0R6b;
  ControlDelay cDelay_DVp19DqI;
  ControlDelay cDelay_mdDbTQdy;
  ControlBinop cBinop_uLbmFaDf;
  ControlBinop cBinop_kOaSnZLB;
  ControlBinop cBinop_fVGFCkaH;
  ControlBinop cBinop_49OAiD0B;
  ControlBinop cBinop_2DlPEkE6;
  ControlBinop cBinop_nPo6Grx0;
  ControlTabhead cTabhead_qyVXGops;
  ControlVar cVar_dLvNv0er;
  ControlDelay cDelay_V5j2xK8K;
  ControlDelay cDelay_m6c3071s;
  ControlBinop cBinop_UyLp72gY;
  ControlBinop cBinop_3c9k9iGQ;
  ControlBinop cBinop_LREEgvuE;
  ControlBinop cBinop_EkoQ1nIp;
  ControlBinop cBinop_gcocd51C;
  ControlBinop cBinop_J8ALRGNG;
  ControlTabhead cTabhead_P1m3wftP;
  ControlVar cVar_n1oflsyY;
  ControlDelay cDelay_mpHhGTaY;
  ControlDelay cDelay_HMWEF90w;
  ControlBinop cBinop_hHnbP7Yt;
  ControlBinop cBinop_5Ql6tYZl;
  ControlBinop cBinop_GP3DzkRX;
  ControlBinop cBinop_4Y3ObtZq;
  ControlBinop cBinop_vDp7IfdS;
  ControlBinop cBinop_799Iq6pv;
  ControlTabhead cTabhead_KfIdq9l7;
  ControlVar cVar_EkCzpM1O;
  ControlDelay cDelay_7S1KZvdo;
  ControlDelay cDelay_lbpB2sQk;
  ControlBinop cBinop_rgDYRb2o;
  ControlBinop cBinop_QKT5vwr5;
  ControlBinop cBinop_v2X9NAqX;
  ControlBinop cBinop_noiJ837D;
  ControlBinop cBinop_t1P7sFjR;
  ControlBinop cBinop_Fg2dgbHZ;
  ControlDelay cDelay_OnyvvNtf;
  ControlDelay cDelay_TbTtX9QR;
  ControlBinop cBinop_PZ3sMFAB;
  HvTable hTable_Eps2MvSJ;
  ControlBinop cBinop_RdQ7dKzq;
  ControlDelay cDelay_w9xCtA1d;
  ControlDelay cDelay_b7Pya8Kj;
  ControlBinop cBinop_VMuzdFJ1;
  HvTable hTable_sr6568YJ;
  ControlBinop cBinop_4kGvYquZ;
  ControlDelay cDelay_slID6Kuw;
  ControlDelay cDelay_UT1eM8Xk;
  ControlBinop cBinop_x2xAnWtD;
  HvTable hTable_g4BTC3wP;
  ControlBinop cBinop_UvKieLFl;
  ControlDelay cDelay_ITeKRD7a;
  ControlDelay cDelay_GyQxUJy2;
  ControlBinop cBinop_7gYTMIlz;
  HvTable hTable_qOqD14n5;
  ControlBinop cBinop_08Jtwm3N;
  ControlPack cPack_Feo0fVsu;
  ControlPack cPack_RjH0cWG9;
  ControlBinop cBinop_xe58P1uL;
  ControlBinop cBinop_w4jobXk5;
  ControlVar cVar_jGto9i39;
  ControlBinop cBinop_wmoKavlJ;
  ControlBinop cBinop_tdy0lSwP;
  SignalVarf sVarf_saMXdENi;
  ControlBinop cBinop_3fndkk86;
  ControlBinop cBinop_dWlBDYJe;
  ControlBinop cBinop_Ygl558Ss;
  SignalVarf sVarf_yuyuarWk;
  ControlVar cVar_blvX2ydM;
  ControlVar cVar_65zwXySq;
  ControlVar cVar_ZdJmEBbE;
  ControlVar cVar_sGcl5Qwr;
  ControlIf cIf_h10lexHY;
  ControlBinop cBinop_ZDd8Ne8W;
  ControlBinop cBinop_ZFlNfDh2;
  ControlBinop cBinop_e4EqgeNa;
  ControlDelay cDelay_zMB4UTuL;
  ControlDelay cDelay_dhJ6cAA1;
  ControlBinop cBinop_EhHIs5mM;
  HvTable hTable_xGZuUzoO;
  ControlBinop cBinop_zDZAy9my;
  ControlTabhead cTabhead_nqB3ukpi;
  ControlVar cVar_62QYKRhC;
  ControlDelay cDelay_ViDyMgie;
  ControlDelay cDelay_HNhLI4vH;
  ControlBinop cBinop_nFDlVs82;
  ControlBinop cBinop_cduEeBvF;
  ControlBinop cBinop_fPBThhAH;
  ControlBinop cBinop_emGdXwmU;
  ControlBinop cBinop_v1aXrnAR;
  ControlBinop cBinop_ke7WZ7QG;
  ControlDelay cDelay_rgpIIC9o;
  ControlDelay cDelay_fiNJNCEq;
  ControlBinop cBinop_GgbrtthD;
  HvTable hTable_A244hBPz;
  ControlBinop cBinop_DsNaO0VD;
  ControlTabhead cTabhead_MtHrWXUm;
  ControlVar cVar_vo0ItMgB;
  ControlDelay cDelay_y2nn0Mj3;
  ControlDelay cDelay_zfA4a6RR;
  ControlBinop cBinop_PStHN48S;
  ControlBinop cBinop_LmJu4r0C;
  ControlBinop cBinop_6u7bK4kB;
  ControlBinop cBinop_NEQoKrkL;
  ControlBinop cBinop_FGFDpo0R;
  ControlBinop cBinop_5J6P3Yyt;
  ControlDelay cDelay_iypBPLuO;
  ControlDelay cDelay_n4NNm6dP;
  ControlBinop cBinop_f9d1Od5e;
  HvTable hTable_5OulVBgr;
  ControlBinop cBinop_AWCfKC6g;
  ControlTabhead cTabhead_Bf5vLuO2;
  ControlVar cVar_QrDb74mu;
  ControlDelay cDelay_K8Vs0wJf;
  ControlDelay cDelay_kVosGtY4;
  ControlBinop cBinop_0EwkmSEz;
  ControlBinop cBinop_VtJxyi8r;
  ControlBinop cBinop_fJptWI1S;
  ControlBinop cBinop_OT8AoKAs;
  ControlBinop cBinop_Uvs25FpE;
  ControlBinop cBinop_2wWiTxt8;
  ControlDelay cDelay_7Cm1ar95;
  ControlDelay cDelay_Xkz3sWye;
  ControlBinop cBinop_kpJNBvRv;
  HvTable hTable_e8Zi7Pf6;
  ControlBinop cBinop_LXfxwPyS;
  ControlTabhead cTabhead_yOkCpBwB;
  ControlVar cVar_t9necXUl;
  ControlDelay cDelay_my2S714P;
  ControlDelay cDelay_Fzhj7ZOI;
  ControlBinop cBinop_KrNtIfvt;
  ControlBinop cBinop_S9K7wzu2;
  ControlBinop cBinop_aUWyUbZo;
  ControlBinop cBinop_X4q3LnIe;
  ControlBinop cBinop_QqBVM2vX;
  ControlBinop cBinop_gNffPjtz;
  ControlDelay cDelay_DpvaXwoc;
  ControlDelay cDelay_bQNsFYwR;
  ControlBinop cBinop_AgF5Nunx;
  HvTable hTable_0cmOncnb;
  ControlBinop cBinop_Y1mjW6NA;
  ControlTabhead cTabhead_cOmUfBdC;
  ControlVar cVar_DFJ56Zu6;
  ControlDelay cDelay_23V8iOrc;
  ControlDelay cDelay_no5yuAjf;
  ControlBinop cBinop_JyKTYS8e;
  ControlBinop cBinop_IVQuUBBp;
  ControlBinop cBinop_gzuK59tM;
  ControlBinop cBinop_MHlkycL7;
  ControlBinop cBinop_HGJ8gotB;
  ControlBinop cBinop_JUP0nQUK;
  ControlDelay cDelay_D8eNURnR;
  ControlDelay cDelay_pDhpiC5s;
  ControlBinop cBinop_mm584gCn;
  HvTable hTable_rTItxtkE;
  ControlBinop cBinop_yMW2AOfQ;
  ControlTabhead cTabhead_FH5Gvk0k;
  ControlVar cVar_94vzqeN3;
  ControlDelay cDelay_td8lCfjZ;
  ControlDelay cDelay_pke6KglM;
  ControlBinop cBinop_GJreoSMn;
  ControlBinop cBinop_dgbylb5J;
  ControlBinop cBinop_KKX9lSn6;
  ControlBinop cBinop_1EuTNfZM;
  ControlBinop cBinop_v8suJI8y;
  ControlBinop cBinop_jWT5rigJ;
  ControlVar cVar_TGzMkoH6;
  ControlVar cVar_qSSYcbjm;
  ControlPack cPack_RRU1jAF3;
  ControlVar cVar_DQO2LvfY;
  ControlBinop cBinop_T2HGY8sq;
  ControlBinop cBinop_tFdXg6Wz;
  SignalVarf sVarf_pteFS2PQ;
  ControlBinop cBinop_cyUtsLVy;
  ControlBinop cBinop_Vxfa1dSl;
  ControlBinop cBinop_vIFiiZy2;
  SignalVarf sVarf_dHhr6ESU;
  ControlVar cVar_I5gaO0tC;
  ControlBinop cBinop_1H5j2EIH;
  ControlBinop cBinop_GugZM4e1;
  SignalVarf sVarf_tTcxmJiT;
  ControlBinop cBinop_QoHyU8By;
  ControlBinop cBinop_Vuv6CKDm;
  ControlBinop cBinop_ZIiG2u8D;
  SignalVarf sVarf_YmoKf5nx;
  ControlVar cVar_KRCt0WBa;
  ControlBinop cBinop_KmUHnfLf;
  ControlBinop cBinop_qUduBKAu;
  SignalVarf sVarf_A7gWX3An;
  ControlBinop cBinop_YtyGQkaW;
  ControlBinop cBinop_bp77vhaj;
  ControlBinop cBinop_XvhezXue;
  SignalVarf sVarf_qiuzN5la;
  ControlBinop cBinop_7LBiOp3M;
  ControlBinop cBinop_26E2dheE;
  ControlBinop cBinop_JzTiV4RG;
  ControlDelay cDelay_iFVceLaD;
  ControlVar cVar_JHWFBLAA;
  ControlBinop cBinop_5XYWwCJS;
  ControlBinop cBinop_Nbi1VT6O;
  ControlBinop cBinop_NstkuakS;
  ControlVar cVar_OuBkSOsn;
  ControlVar cVar_cXWBY3z9;
  ControlIf cIf_MKXPThwJ;
  ControlBinop cBinop_0IShaIPC;
  ControlDelay cDelay_5TmdQh2y;
  ControlDelay cDelay_5vudOYti;
  ControlBinop cBinop_cywfDSqm;
  HvTable hTable_oXYCtuD5;
  ControlBinop cBinop_L0Yj6o9G;
  ControlTabhead cTabhead_WKn3hzaV;
  ControlVar cVar_abx5UgOt;
  ControlDelay cDelay_4ideaiAI;
  ControlDelay cDelay_VmNNfjvg;
  ControlBinop cBinop_OipbTnGn;
  ControlBinop cBinop_8gnUypQZ;
  ControlBinop cBinop_gqaUsNxb;
  ControlBinop cBinop_HgRsJ0CK;
  ControlBinop cBinop_L1p15rV2;
  ControlBinop cBinop_4vgvX2Dg;
  ControlVar cVar_RayvicSX;
  ControlVar cVar_VMcLwNaV;
  ControlVar cVar_D5qtwWo5;
  ControlVar cVar_Gzvjcgdo;
  ControlVar cVar_Dy0ddCKf;
  ControlVar cVar_eUyh8bzR;
  ControlIf cIf_GxPrETHx;
  ControlBinop cBinop_8RATZrXq;
  ControlVar cVar_w0Yog419;
  ControlIf cIf_kZ7l6slT;
  ControlBinop cBinop_i9gALaeC;
  ControlSlice cSlice_NrY6ecRa;
  ControlSlice cSlice_FpV2fsVZ;
  ControlVar cVar_vGKcHmze;
  ControlIf cIf_tirxjr7F;
  ControlBinop cBinop_ADwXGBqB;
  ControlIf cIf_RKwV0BYN;
  ControlIf cIf_AxC4FC0r;
  ControlIf cIf_CCdcjYus;
  ControlIf cIf_YzPmdZjq;
  ControlIf cIf_3S3klRuP;
  SignalVarf sVarf_51CGUAQR;
  ControlBinop cBinop_vX1elQre;
  ControlBinop cBinop_nwEeAe6X;
  ControlBinop cBinop_fchnKVOE;
  ControlBinop cBinop_8zCgvJkM;
  SignalVarf sVarf_hynS8Scz;
  ControlBinop cBinop_6QYovvZZ;
  ControlBinop cBinop_QNO7eqAJ;
  SignalVarf sVarf_8cUDkXDK;
  SignalVarf sVarf_5gikGZdR;
  ControlBinop cBinop_ZvsuUsqq;
  ControlBinop cBinop_40p842Kz;
  ControlBinop cBinop_klI8fYA9;
  ControlBinop cBinop_Q4XgR5Hy;
  ControlBinop cBinop_T4dJmJGJ;
  ControlBinop cBinop_DQIaGrMG;
  ControlBinop cBinop_tj25aSOn;
  ControlBinop cBinop_xG5WAEvV;
  ControlBinop cBinop_Q5PW5Apn;
  ControlBinop cBinop_Eu5XNvYU;
  ControlBinop cBinop_jX3eoTPD;
  ControlBinop cBinop_99SszjlU;
  ControlBinop cBinop_s4j6h4NY;
};

#endif // _HEAVY_CONTEXT_CHAFFVERB_HPP_
