/**
 * Copyright (c) 2025 Enzien Audio, Ltd.
 * 
 * Redistribution and use in source and binary forms, with or without modification,
 * are permitted provided that the following conditions are met:
 * 
 * 1. Redistributions of source code must retain the above copyright notice,
 *    this list of conditions, and the following disclaimer.
 * 
 * 2. Redistributions in binary form must reproduce the phrase "powered by heavy",
 *    the heavy logo, and a hyperlink to https://enzienaudio.com, all in a visible
 *    form.
 * 
 *   2.1 If the Application is distributed in a store system (for example,
 *       the Apple "App Store" or "Google Play"), the phrase "powered by heavy"
 *       shall be included in the app description or the copyright text as well as
 *       the in the app itself. The heavy logo will shall be visible in the app
 *       itself as well.
 * 
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
 * SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
 * CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
 * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 * 
 */

#include "Heavy_ChaffVerb.hpp"

#include <new>

#define Context(_c) static_cast<Heavy_ChaffVerb *>(_c)


/*
 * C Functions
 */

extern "C" {
  HV_EXPORT HeavyContextInterface *hv_ChaffVerb_new(double sampleRate) {
    // allocate aligned memory
    void *ptr = hv_malloc(sizeof(Heavy_ChaffVerb));
    // ensure non-null
    if (!ptr) return nullptr;
    // call constructor
    new(ptr) Heavy_ChaffVerb(sampleRate);
    return Context(ptr);
  }

  HV_EXPORT HeavyContextInterface *hv_ChaffVerb_new_with_options(double sampleRate,
      int poolKb, int inQueueKb, int outQueueKb) {
    // allocate aligned memory
    void *ptr = hv_malloc(sizeof(Heavy_ChaffVerb));
    // ensure non-null
    if (!ptr) return nullptr;
    // call constructor
    new(ptr) Heavy_ChaffVerb(sampleRate, poolKb, inQueueKb, outQueueKb);
    return Context(ptr);
  }

  HV_EXPORT void hv_ChaffVerb_free(HeavyContextInterface *instance) {
    // call destructor
    Context(instance)->~Heavy_ChaffVerb();
    // free memory
    hv_free(instance);
  }
} // extern "C"







/*
 * Class Functions
 */

Heavy_ChaffVerb::Heavy_ChaffVerb(double sampleRate, int poolKb, int inQueueKb, int outQueueKb)
    : HeavyContext(sampleRate, poolKb, inQueueKb, outQueueKb) {
  numBytes += sPhasor_k_init(&sPhasor_oMM6tSkH, 0.0f, sampleRate);
  numBytes += sLine_init(&sLine_UVTMOFJw);
  numBytes += sLine_init(&sLine_KxXNQs2p);
  numBytes += sTabhead_init(&sTabhead_TMrZvmRx, &hTable_zsW0V9Hn);
  numBytes += sTabread_init(&sTabread_Gn5B9YNe, &hTable_zsW0V9Hn, false);
  numBytes += sTabread_init(&sTabread_5AlxjDo1, &hTable_zsW0V9Hn, false);
  numBytes += sTabhead_init(&sTabhead_EDOuBrpS, &hTable_zsW0V9Hn);
  numBytes += sTabread_init(&sTabread_7H0P0rF2, &hTable_zsW0V9Hn, false);
  numBytes += sTabread_init(&sTabread_KlTbtfq8, &hTable_zsW0V9Hn, false);
  numBytes += sTabwrite_init(&sTabwrite_3dVaqRWN, &hTable_zsW0V9Hn);
  numBytes += sRPole_init(&sRPole_o2U1PGba);
  numBytes += sDel1_init(&sDel1_JhcQu2FE);
  numBytes += sTabread_init(&sTabread_MBpVdwiF, &hTable_oXYCtuD5, true);
  numBytes += sTabwrite_init(&sTabwrite_SXsn9obO, &hTable_oXYCtuD5);
  numBytes += sTabread_init(&sTabread_aLsECrs5, &hTable_Eps2MvSJ, true);
  numBytes += sRPole_init(&sRPole_C9ZoRDL8);
  numBytes += sLine_init(&sLine_v8sA6rWG);
  numBytes += sLine_init(&sLine_woutXzoG);
  numBytes += sTabread_init(&sTabread_B8TSCxn7, &hTable_xGZuUzoO, true);
  numBytes += sTabread_init(&sTabread_gssM6Xbp, &hTable_A244hBPz, true);
  numBytes += sTabread_init(&sTabread_v8gCgSiv, &hTable_5OulVBgr, true);
  numBytes += sTabread_init(&sTabread_ZVwjGSWx, &hTable_e8Zi7Pf6, true);
  numBytes += sTabread_init(&sTabread_pYhq9TgO, &hTable_rTItxtkE, true);
  numBytes += sTabread_init(&sTabread_TFCHpICr, &hTable_0cmOncnb, true);
  numBytes += sTabwrite_init(&sTabwrite_406QjmMR, &hTable_xGZuUzoO);
  numBytes += sTabwrite_init(&sTabwrite_WjBDwhFo, &hTable_A244hBPz);
  numBytes += sTabwrite_init(&sTabwrite_tE63Zqi9, &hTable_5OulVBgr);
  numBytes += sTabwrite_init(&sTabwrite_pNsH1xbf, &hTable_e8Zi7Pf6);
  numBytes += sTabwrite_init(&sTabwrite_xAbXIcpY, &hTable_0cmOncnb);
  numBytes += sTabwrite_init(&sTabwrite_sDmtIoVv, &hTable_rTItxtkE);
  numBytes += sTabread_init(&sTabread_FBDeFP8S, &hTable_sr6568YJ, true);
  numBytes += sRPole_init(&sRPole_mih8cdmK);
  numBytes += sTabread_init(&sTabread_liVnSrA8, &hTable_g4BTC3wP, true);
  numBytes += sRPole_init(&sRPole_1icqCNb4);
  numBytes += sTabread_init(&sTabread_Ry19IS0x, &hTable_qOqD14n5, true);
  numBytes += sRPole_init(&sRPole_u80nZf9u);
  numBytes += sTabwrite_init(&sTabwrite_crqYqLHh, &hTable_Eps2MvSJ);
  numBytes += sTabwrite_init(&sTabwrite_nUc2GthC, &hTable_sr6568YJ);
  numBytes += sTabwrite_init(&sTabwrite_5IRUmwEX, &hTable_g4BTC3wP);
  numBytes += sTabwrite_init(&sTabwrite_NZHBFcRO, &hTable_qOqD14n5);
  numBytes += sLine_init(&sLine_gMJPoKz9);
  numBytes += cVar_init_f(&cVar_lXxlgfO4, 0.0f);
  numBytes += cVar_init_f(&cVar_7MbsimwS, 0.0f);
  numBytes += cPack_init(&cPack_JnDlv10b, 2, 0.0f, 200.0f);
  numBytes += cVar_init_f(&cVar_OrDrXnVN, 0.0f);
  numBytes += cPack_init(&cPack_Dc2LNeH7, 2, 0.0f, 200.0f);
  numBytes += cVar_init_f(&cVar_UL2ol6A2, 0.0f);
  numBytes += cVar_init_f(&cVar_KiqH7N3e, 0.0f);
  numBytes += cDelay_init(this, &cDelay_FwaTouMV, 0.0f);
  numBytes += cDelay_init(this, &cDelay_24QHJZ99, 0.0f);
  numBytes += hTable_init(&hTable_zsW0V9Hn, 256);
  numBytes += cVar_init_s(&cVar_9LdQQRSE, "del-1002-shifter");
  numBytes += sVarf_init(&sVarf_mCi7Rvj4, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_gJcP0uUO, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_ulhN83Qc, 0.0f, 0.0f, false);
  numBytes += cVar_init_s(&cVar_VDMWxd5L, "del-1002-shifter");
  numBytes += sVarf_init(&sVarf_Br5dP5pX, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_F6GntIho, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_v3sNsTsi, 0.0f, 0.0f, false);
  numBytes += cBinop_init(&cBinop_9YPnedFk, 0.0f); // __div
  numBytes += sVarf_init(&sVarf_ZzPSROtU, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_nf9bFbxt, 0.0f);
  numBytes += cBinop_init(&cBinop_dXCBArab, 0.0f); // __div
  numBytes += sVarf_init(&sVarf_05SywGIo, 0.0f, 0.0f, false);
  numBytes += cRandom_init(&cRandom_XWvwig7a, -805604550);
  numBytes += cSlice_init(&cSlice_pttd8ARc, 1, 1);
  numBytes += cDelay_init(this, &cDelay_v67z7oCV, 0.0f);
  numBytes += cVar_init_f(&cVar_d2qJXo7W, 5.0f);
  numBytes += cBinop_init(&cBinop_3YXVX8XL, 0.0f); // __mul
  numBytes += cTabhead_init(&cTabhead_cp8DKvRz, &hTable_Eps2MvSJ);
  numBytes += cVar_init_s(&cVar_wGus0R6b, "del-1052-del1");
  numBytes += cDelay_init(this, &cDelay_DVp19DqI, 58.6435f);
  numBytes += cDelay_init(this, &cDelay_mdDbTQdy, 0.0f);
  numBytes += cBinop_init(&cBinop_uLbmFaDf, 58.6435f); // __mul
  numBytes += cBinop_init(&cBinop_fVGFCkaH, 0.0f); // __sub
  numBytes += cBinop_init(&cBinop_49OAiD0B, 0.0f); // __max
  numBytes += cBinop_init(&cBinop_nPo6Grx0, 0.0f); // __sub
  numBytes += cTabhead_init(&cTabhead_qyVXGops, &hTable_sr6568YJ);
  numBytes += cVar_init_s(&cVar_dLvNv0er, "del-1052-del2");
  numBytes += cDelay_init(this, &cDelay_V5j2xK8K, 69.4325f);
  numBytes += cDelay_init(this, &cDelay_m6c3071s, 0.0f);
  numBytes += cBinop_init(&cBinop_UyLp72gY, 69.4325f); // __mul
  numBytes += cBinop_init(&cBinop_LREEgvuE, 0.0f); // __sub
  numBytes += cBinop_init(&cBinop_EkoQ1nIp, 0.0f); // __max
  numBytes += cBinop_init(&cBinop_J8ALRGNG, 0.0f); // __sub
  numBytes += cTabhead_init(&cTabhead_P1m3wftP, &hTable_g4BTC3wP);
  numBytes += cVar_init_s(&cVar_n1oflsyY, "del-1052-del3");
  numBytes += cDelay_init(this, &cDelay_mpHhGTaY, 74.5234f);
  numBytes += cDelay_init(this, &cDelay_HMWEF90w, 0.0f);
  numBytes += cBinop_init(&cBinop_hHnbP7Yt, 74.5234f); // __mul
  numBytes += cBinop_init(&cBinop_GP3DzkRX, 0.0f); // __sub
  numBytes += cBinop_init(&cBinop_4Y3ObtZq, 0.0f); // __max
  numBytes += cBinop_init(&cBinop_799Iq6pv, 0.0f); // __sub
  numBytes += cTabhead_init(&cTabhead_KfIdq9l7, &hTable_qOqD14n5);
  numBytes += cVar_init_s(&cVar_EkCzpM1O, "del-1052-del4");
  numBytes += cDelay_init(this, &cDelay_7S1KZvdo, 86.1244f);
  numBytes += cDelay_init(this, &cDelay_lbpB2sQk, 0.0f);
  numBytes += cBinop_init(&cBinop_rgDYRb2o, 86.1244f); // __mul
  numBytes += cBinop_init(&cBinop_v2X9NAqX, 0.0f); // __sub
  numBytes += cBinop_init(&cBinop_noiJ837D, 0.0f); // __max
  numBytes += cBinop_init(&cBinop_Fg2dgbHZ, 0.0f); // __sub
  numBytes += cDelay_init(this, &cDelay_OnyvvNtf, 0.0f);
  numBytes += cDelay_init(this, &cDelay_TbTtX9QR, 0.0f);
  numBytes += hTable_init(&hTable_Eps2MvSJ, 256);
  numBytes += cDelay_init(this, &cDelay_w9xCtA1d, 0.0f);
  numBytes += cDelay_init(this, &cDelay_b7Pya8Kj, 0.0f);
  numBytes += hTable_init(&hTable_sr6568YJ, 256);
  numBytes += cDelay_init(this, &cDelay_slID6Kuw, 0.0f);
  numBytes += cDelay_init(this, &cDelay_UT1eM8Xk, 0.0f);
  numBytes += hTable_init(&hTable_g4BTC3wP, 256);
  numBytes += cDelay_init(this, &cDelay_ITeKRD7a, 0.0f);
  numBytes += cDelay_init(this, &cDelay_GyQxUJy2, 0.0f);
  numBytes += hTable_init(&hTable_qOqD14n5, 256);
  numBytes += cPack_init(&cPack_Feo0fVsu, 2, 0.0f, 30.0f);
  numBytes += cPack_init(&cPack_RjH0cWG9, 2, 0.0f, 50.0f);
  numBytes += cVar_init_f(&cVar_jGto9i39, 22050.0f);
  numBytes += cBinop_init(&cBinop_wmoKavlJ, 0.0f); // __mul
  numBytes += sVarf_init(&sVarf_saMXdENi, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_yuyuarWk, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_blvX2ydM, 0.0f);
  numBytes += cVar_init_f(&cVar_65zwXySq, 0.0f);
  numBytes += cVar_init_f(&cVar_ZdJmEBbE, 0.0f);
  numBytes += cVar_init_f(&cVar_sGcl5Qwr, 0.0f);
  numBytes += cIf_init(&cIf_h10lexHY, false);
  numBytes += cDelay_init(this, &cDelay_zMB4UTuL, 0.0f);
  numBytes += cDelay_init(this, &cDelay_dhJ6cAA1, 0.0f);
  numBytes += hTable_init(&hTable_xGZuUzoO, 256);
  numBytes += cTabhead_init(&cTabhead_nqB3ukpi, &hTable_xGZuUzoO);
  numBytes += cVar_init_s(&cVar_62QYKRhC, "del-1052-ref1");
  numBytes += cDelay_init(this, &cDelay_ViDyMgie, 43.5337f);
  numBytes += cDelay_init(this, &cDelay_HNhLI4vH, 0.0f);
  numBytes += cBinop_init(&cBinop_nFDlVs82, 43.5337f); // __mul
  numBytes += cBinop_init(&cBinop_fPBThhAH, 0.0f); // __sub
  numBytes += cBinop_init(&cBinop_emGdXwmU, 0.0f); // __max
  numBytes += cBinop_init(&cBinop_ke7WZ7QG, 0.0f); // __sub
  numBytes += cDelay_init(this, &cDelay_rgpIIC9o, 0.0f);
  numBytes += cDelay_init(this, &cDelay_fiNJNCEq, 0.0f);
  numBytes += hTable_init(&hTable_A244hBPz, 256);
  numBytes += cTabhead_init(&cTabhead_MtHrWXUm, &hTable_A244hBPz);
  numBytes += cVar_init_s(&cVar_vo0ItMgB, "del-1052-ref2");
  numBytes += cDelay_init(this, &cDelay_y2nn0Mj3, 25.796f);
  numBytes += cDelay_init(this, &cDelay_zfA4a6RR, 0.0f);
  numBytes += cBinop_init(&cBinop_PStHN48S, 25.796f); // __mul
  numBytes += cBinop_init(&cBinop_6u7bK4kB, 0.0f); // __sub
  numBytes += cBinop_init(&cBinop_NEQoKrkL, 0.0f); // __max
  numBytes += cBinop_init(&cBinop_5J6P3Yyt, 0.0f); // __sub
  numBytes += cDelay_init(this, &cDelay_iypBPLuO, 0.0f);
  numBytes += cDelay_init(this, &cDelay_n4NNm6dP, 0.0f);
  numBytes += hTable_init(&hTable_5OulVBgr, 256);
  numBytes += cTabhead_init(&cTabhead_Bf5vLuO2, &hTable_5OulVBgr);
  numBytes += cVar_init_s(&cVar_QrDb74mu, "del-1052-ref3");
  numBytes += cDelay_init(this, &cDelay_K8Vs0wJf, 19.392f);
  numBytes += cDelay_init(this, &cDelay_kVosGtY4, 0.0f);
  numBytes += cBinop_init(&cBinop_0EwkmSEz, 19.392f); // __mul
  numBytes += cBinop_init(&cBinop_fJptWI1S, 0.0f); // __sub
  numBytes += cBinop_init(&cBinop_OT8AoKAs, 0.0f); // __max
  numBytes += cBinop_init(&cBinop_2wWiTxt8, 0.0f); // __sub
  numBytes += cDelay_init(this, &cDelay_7Cm1ar95, 0.0f);
  numBytes += cDelay_init(this, &cDelay_Xkz3sWye, 0.0f);
  numBytes += hTable_init(&hTable_e8Zi7Pf6, 256);
  numBytes += cTabhead_init(&cTabhead_yOkCpBwB, &hTable_e8Zi7Pf6);
  numBytes += cVar_init_s(&cVar_t9necXUl, "del-1052-ref4");
  numBytes += cDelay_init(this, &cDelay_my2S714P, 16.364f);
  numBytes += cDelay_init(this, &cDelay_Fzhj7ZOI, 0.0f);
  numBytes += cBinop_init(&cBinop_KrNtIfvt, 16.364f); // __mul
  numBytes += cBinop_init(&cBinop_aUWyUbZo, 0.0f); // __sub
  numBytes += cBinop_init(&cBinop_X4q3LnIe, 0.0f); // __max
  numBytes += cBinop_init(&cBinop_gNffPjtz, 0.0f); // __sub
  numBytes += cDelay_init(this, &cDelay_DpvaXwoc, 0.0f);
  numBytes += cDelay_init(this, &cDelay_bQNsFYwR, 0.0f);
  numBytes += hTable_init(&hTable_0cmOncnb, 256);
  numBytes += cTabhead_init(&cTabhead_cOmUfBdC, &hTable_0cmOncnb);
  numBytes += cVar_init_s(&cVar_DFJ56Zu6, "del-1052-ref6");
  numBytes += cDelay_init(this, &cDelay_23V8iOrc, 4.2546f);
  numBytes += cDelay_init(this, &cDelay_no5yuAjf, 0.0f);
  numBytes += cBinop_init(&cBinop_JyKTYS8e, 4.2546f); // __mul
  numBytes += cBinop_init(&cBinop_gzuK59tM, 0.0f); // __sub
  numBytes += cBinop_init(&cBinop_MHlkycL7, 0.0f); // __max
  numBytes += cBinop_init(&cBinop_JUP0nQUK, 0.0f); // __sub
  numBytes += cDelay_init(this, &cDelay_D8eNURnR, 0.0f);
  numBytes += cDelay_init(this, &cDelay_pDhpiC5s, 0.0f);
  numBytes += hTable_init(&hTable_rTItxtkE, 256);
  numBytes += cTabhead_init(&cTabhead_FH5Gvk0k, &hTable_rTItxtkE);
  numBytes += cVar_init_s(&cVar_94vzqeN3, "del-1052-ref5");
  numBytes += cDelay_init(this, &cDelay_td8lCfjZ, 7.645f);
  numBytes += cDelay_init(this, &cDelay_pke6KglM, 0.0f);
  numBytes += cBinop_init(&cBinop_GJreoSMn, 7.645f); // __mul
  numBytes += cBinop_init(&cBinop_KKX9lSn6, 0.0f); // __sub
  numBytes += cBinop_init(&cBinop_1EuTNfZM, 0.0f); // __max
  numBytes += cBinop_init(&cBinop_jWT5rigJ, 0.0f); // __sub
  numBytes += cVar_init_f(&cVar_TGzMkoH6, 0.0f);
  numBytes += cVar_init_f(&cVar_qSSYcbjm, 0.0f);
  numBytes += cPack_init(&cPack_RRU1jAF3, 2, 0.0f, 50.0f);
  numBytes += cVar_init_f(&cVar_DQO2LvfY, 22050.0f);
  numBytes += cBinop_init(&cBinop_T2HGY8sq, 0.0f); // __mul
  numBytes += sVarf_init(&sVarf_pteFS2PQ, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_dHhr6ESU, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_I5gaO0tC, 22050.0f);
  numBytes += cBinop_init(&cBinop_1H5j2EIH, 0.0f); // __mul
  numBytes += sVarf_init(&sVarf_tTcxmJiT, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_YmoKf5nx, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_KRCt0WBa, 22050.0f);
  numBytes += cBinop_init(&cBinop_KmUHnfLf, 0.0f); // __mul
  numBytes += sVarf_init(&sVarf_A7gWX3An, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_qiuzN5la, 0.0f, 0.0f, false);
  numBytes += cDelay_init(this, &cDelay_iFVceLaD, 0.0f);
  numBytes += cVar_init_f(&cVar_JHWFBLAA, 1000.0f);
  numBytes += cBinop_init(&cBinop_NstkuakS, 0.0f); // __mul
  numBytes += cVar_init_f(&cVar_OuBkSOsn, 0.0f);
  numBytes += cVar_init_f(&cVar_cXWBY3z9, 0.0f);
  numBytes += cIf_init(&cIf_MKXPThwJ, false);
  numBytes += cDelay_init(this, &cDelay_5TmdQh2y, 0.0f);
  numBytes += cDelay_init(this, &cDelay_5vudOYti, 0.0f);
  numBytes += hTable_init(&hTable_oXYCtuD5, 256);
  numBytes += cTabhead_init(&cTabhead_WKn3hzaV, &hTable_oXYCtuD5);
  numBytes += cVar_init_s(&cVar_abx5UgOt, "del-1001-del1");
  numBytes += cDelay_init(this, &cDelay_4ideaiAI, 150.0f);
  numBytes += cDelay_init(this, &cDelay_VmNNfjvg, 0.0f);
  numBytes += cBinop_init(&cBinop_OipbTnGn, 150.0f); // __mul
  numBytes += cBinop_init(&cBinop_gqaUsNxb, 0.0f); // __sub
  numBytes += cBinop_init(&cBinop_HgRsJ0CK, 0.0f); // __max
  numBytes += cBinop_init(&cBinop_4vgvX2Dg, 0.0f); // __sub
  numBytes += cVar_init_f(&cVar_RayvicSX, 0.0f);
  numBytes += cVar_init_f(&cVar_VMcLwNaV, 0.0f);
  numBytes += cVar_init_f(&cVar_D5qtwWo5, 0.0f);
  numBytes += cVar_init_f(&cVar_Gzvjcgdo, 0.0f);
  numBytes += cVar_init_f(&cVar_Dy0ddCKf, 0.0f);
  numBytes += cVar_init_f(&cVar_eUyh8bzR, 0.0f);
  numBytes += cIf_init(&cIf_GxPrETHx, false);
  numBytes += cVar_init_f(&cVar_w0Yog419, 0.0f);
  numBytes += cIf_init(&cIf_kZ7l6slT, false);
  numBytes += cSlice_init(&cSlice_NrY6ecRa, 1, -1);
  numBytes += cSlice_init(&cSlice_FpV2fsVZ, 1, -1);
  numBytes += cVar_init_f(&cVar_vGKcHmze, 0.0f);
  numBytes += cIf_init(&cIf_tirxjr7F, false);
  numBytes += cBinop_init(&cBinop_ADwXGBqB, 0.0f); // __neq
  numBytes += cIf_init(&cIf_RKwV0BYN, false);
  numBytes += cIf_init(&cIf_AxC4FC0r, false);
  numBytes += cIf_init(&cIf_CCdcjYus, false);
  numBytes += cIf_init(&cIf_YzPmdZjq, true);
  numBytes += cIf_init(&cIf_3S3klRuP, false);
  numBytes += sVarf_init(&sVarf_51CGUAQR, 1.0f, 0.0f, false);
  numBytes += cBinop_init(&cBinop_fchnKVOE, 4.0f); // __unimod
  numBytes += sVarf_init(&sVarf_hynS8Scz, 0.1f, 0.0f, false);
  numBytes += cBinop_init(&cBinop_6QYovvZZ, 0.0f); // __add
  numBytes += cBinop_init(&cBinop_QNO7eqAJ, 0.0f); // __add
  numBytes += sVarf_init(&sVarf_8cUDkXDK, 0.65f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_5gikGZdR, 0.55f, 0.0f, false);
  numBytes += cBinop_init(&cBinop_40p842Kz, 1.0f); // __mul
  numBytes += cBinop_init(&cBinop_Q5PW5Apn, 0.0f); // __add
  numBytes += cBinop_init(&cBinop_Eu5XNvYU, 1.0f); // __mul
  numBytes += cBinop_init(&cBinop_jX3eoTPD, 0.0f); // __add
  numBytes += cBinop_init(&cBinop_99SszjlU, 1.0f); // __mul
  numBytes += cBinop_init(&cBinop_s4j6h4NY, 0.0f); // __add
  
  // schedule a message to trigger all loadbangs via the __hv_init receiver
  scheduleMessageForReceiver(0xCE5CC65B, msg_initWithBang(HV_MESSAGE_ON_STACK(1), 0));
}

Heavy_ChaffVerb::~Heavy_ChaffVerb() {
  cPack_free(&cPack_JnDlv10b);
  cPack_free(&cPack_Dc2LNeH7);
  hTable_free(&hTable_zsW0V9Hn);
  hTable_free(&hTable_Eps2MvSJ);
  hTable_free(&hTable_sr6568YJ);
  hTable_free(&hTable_g4BTC3wP);
  hTable_free(&hTable_qOqD14n5);
  cPack_free(&cPack_Feo0fVsu);
  cPack_free(&cPack_RjH0cWG9);
  hTable_free(&hTable_xGZuUzoO);
  hTable_free(&hTable_A244hBPz);
  hTable_free(&hTable_5OulVBgr);
  hTable_free(&hTable_e8Zi7Pf6);
  hTable_free(&hTable_0cmOncnb);
  hTable_free(&hTable_rTItxtkE);
  cPack_free(&cPack_RRU1jAF3);
  hTable_free(&hTable_oXYCtuD5);
}

HvTable *Heavy_ChaffVerb::getTableForHash(hv_uint32_t tableHash) {switch (tableHash) {
    case 0xA1445E2C: return &hTable_zsW0V9Hn; // del-1002-shifter
    case 0xAAA0EB60: return &hTable_Eps2MvSJ; // del-1052-del1
    case 0xA2AC524D: return &hTable_sr6568YJ; // del-1052-del2
    case 0xE36A35B: return &hTable_g4BTC3wP; // del-1052-del3
    case 0x48CE0509: return &hTable_qOqD14n5; // del-1052-del4
    case 0xE34D6E72: return &hTable_xGZuUzoO; // del-1052-ref1
    case 0x6A1027AB: return &hTable_A244hBPz; // del-1052-ref2
    case 0xA37C6D49: return &hTable_5OulVBgr; // del-1052-ref3
    case 0xCEFE5FE5: return &hTable_e8Zi7Pf6; // del-1052-ref4
    case 0x48EB8BBB: return &hTable_0cmOncnb; // del-1052-ref6
    case 0xCC6F73D5: return &hTable_rTItxtkE; // del-1052-ref5
    case 0xED65564F: return &hTable_oXYCtuD5; // del-1001-del1
    default: return nullptr;
  }
}

void Heavy_ChaffVerb::scheduleMessageForReceiver(hv_uint32_t receiverHash, HvMessage *m) {
  switch (receiverHash) {
    case 0x1F30993F: { // A__LFO_Period
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_ZlsdcSog_sendMessage);
      break;
    }
    case 0x1A2B8E9F: { // A__LFO_Steps_Scale__Type2
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_8UboToci_sendMessage);
      break;
    }
    case 0xBE3344C8: { // A__LFO_Steps__Type2
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_bAdbvxb0_sendMessage);
      break;
    }
    case 0x7369936E: { // A__LFO_Switch
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_2EYMm4I7_sendMessage);
      break;
    }
    case 0xD64CFD23: { // A__LFO_type
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_cQcNDf3w_sendMessage);
      break;
    }
    case 0x51447E19: { // B__General_Offset
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_8J387eUF_sendMessage);
      break;
    }
    case 0xA10FCFC4: { // B__General_Scale
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_QT5czTTM_sendMessage);
      break;
    }
    case 0x7EFB8E46: { // C__Random_LFO_Offset
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_mzVLspDl_sendMessage);
      break;
    }
    case 0xE6223016: { // C__Random_LFO_Period
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_aYM6HSmC_sendMessage);
      break;
    }
    case 0x3281900D: { // C__Random_LFO_Scale
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_sxSkmtjU_sendMessage);
      break;
    }
    case 0x6150BC53: { // C__Random_LFO_Switch
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_oQbZ2gro_sendMessage);
      break;
    }
    case 0x9CBB1BF3: { // D__Shift_Microtone
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_HJav80r1_sendMessage);
      break;
    }
    case 0x4439D71: { // D__Shift_Transpose
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_M2aZR2uM_sendMessage);
      break;
    }
    case 0x890283C2: { // E__Fx_Level
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_TlWq6lUv_sendMessage);
      break;
    }
    case 0x12962685: { // E__HiPass_Freq
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_upRSlT4T_sendMessage);
      break;
    }
    case 0x183CFEE5: { // E__Shift_Delay
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_EHCCCnuP_sendMessage);
      break;
    }
    case 0x57FF40DB: { // E__Shift_Window
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_OLmy2yPO_sendMessage);
      break;
    }
    case 0x69A91334: { // F__FX_Delay
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_OY31OVQS_sendMessage);
      break;
    }
    case 0x68D029F7: { // F__FX_Delay_Feedback
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_Cg20Zzis_sendMessage);
      break;
    }
    case 0xD63693D0: { // Mix__Dry_Mix
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_EzkQWw0E_sendMessage);
      break;
    }
    case 0x1FC3C02C: { // Mix__Dry_Vol
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_MGRnV4rq_sendMessage);
      break;
    }
    case 0x58653D84: { // Mix__Reverb_Level
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_y9abJ4C7_sendMessage);
      break;
    }
    case 0xE764F673: { // Mix__Reverb_Vol
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_hRdBO2Te_sendMessage);
      break;
    }
    case 0xCE5CC65B: { // __hv_init
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_488053y6_sendMessage);
      break;
    }
    default: return;
  }
}

int Heavy_ChaffVerb::getParameterInfo(int index, HvParameterInfo *info) {
  if (info != nullptr) {
    switch (index) {
      case 0: {
        info->name = "A__LFO_Period";
        info->hash = 0x1F30993F;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 1.0f;
        info->maxVal = 4000.0f;
        info->defaultVal = 1500.0f;
        break;
      }
      case 1: {
        info->name = "A__LFO_Steps_Scale__Type2";
        info->hash = 0x1A2B8E9F;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = -5.0f;
        info->maxVal = 5.0f;
        info->defaultVal = 1.0f;
        break;
      }
      case 2: {
        info->name = "A__LFO_Steps__Type2";
        info->hash = 0xBE3344C8;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 2.0f;
        info->maxVal = 10.0f;
        info->defaultVal = 4.0f;
        break;
      }
      case 3: {
        info->name = "A__LFO_Switch";
        info->hash = 0x7369936E;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 1.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 4: {
        info->name = "A__LFO_type";
        info->hash = 0xD64CFD23;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 2.99f;
        info->defaultVal = 0.0f;
        break;
      }
      case 5: {
        info->name = "B__General_Offset";
        info->hash = 0x51447E19;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = -2.0f;
        info->maxVal = 2.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 6: {
        info->name = "B__General_Scale";
        info->hash = 0xA10FCFC4;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = -7.0f;
        info->maxVal = 7.0f;
        info->defaultVal = 1.0f;
        break;
      }
      case 7: {
        info->name = "C__Random_LFO_Offset";
        info->hash = 0x7EFB8E46;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = -2.0f;
        info->maxVal = 2.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 8: {
        info->name = "C__Random_LFO_Period";
        info->hash = 0xE6223016;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 1.0f;
        info->maxVal = 4000.0f;
        info->defaultVal = 1500.0f;
        break;
      }
      case 9: {
        info->name = "C__Random_LFO_Scale";
        info->hash = 0x3281900D;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = -7.0f;
        info->maxVal = 7.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 10: {
        info->name = "C__Random_LFO_Switch";
        info->hash = 0x6150BC53;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 1.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 11: {
        info->name = "D__Shift_Microtone";
        info->hash = 0x9CBB1BF3;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = -1.0f;
        info->maxVal = 1.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 12: {
        info->name = "D__Shift_Transpose";
        info->hash = 0x4439D71;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = -36.0f;
        info->maxVal = 36.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 13: {
        info->name = "E__Fx_Level";
        info->hash = 0x890283C2;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 1.0f;
        info->defaultVal = 0.7f;
        break;
      }
      case 14: {
        info->name = "E__HiPass_Freq";
        info->hash = 0x12962685;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 100.0f;
        info->maxVal = 2500.0f;
        info->defaultVal = 800.0f;
        break;
      }
      case 15: {
        info->name = "E__Shift_Delay";
        info->hash = 0x183CFEE5;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 500.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 16: {
        info->name = "E__Shift_Window";
        info->hash = 0x57FF40DB;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 1.0f;
        info->maxVal = 3500.0f;
        info->defaultVal = 1000.0f;
        break;
      }
      case 17: {
        info->name = "F__FX_Delay";
        info->hash = 0x69A91334;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 2000.0f;
        info->defaultVal = 500.0f;
        break;
      }
      case 18: {
        info->name = "F__FX_Delay_Feedback";
        info->hash = 0x68D029F7;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 0.97f;
        info->defaultVal = 0.65f;
        break;
      }
      case 19: {
        info->name = "Mix__Dry_Mix";
        info->hash = 0xD63693D0;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 1.0f;
        info->defaultVal = 0.45f;
        break;
      }
      case 20: {
        info->name = "Mix__Dry_Vol";
        info->hash = 0x1FC3C02C;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 1.0f;
        info->defaultVal = 0.1f;
        break;
      }
      case 21: {
        info->name = "Mix__Reverb_Level";
        info->hash = 0x58653D84;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 1.0f;
        info->defaultVal = 0.85f;
        break;
      }
      case 22: {
        info->name = "Mix__Reverb_Vol";
        info->hash = 0xE764F673;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 1.0f;
        info->defaultVal = 0.5f;
        break;
      }
      default: {
        info->name = "invalid parameter index";
        info->hash = 0;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 0.0f;
        info->defaultVal = 0.0f;
        break;
      }
    }
  }
  return 23;
}



/*
 * Send Function Implementations
 */


void Heavy_ChaffVerb::cVar_lXxlgfO4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.05776f, 0, m, &cBinop_myvI8aY5_sendMessage);
}

void Heavy_ChaffVerb::cVar_7MbsimwS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 1.0f, 0, m, &cBinop_5Zwx29KP_sendMessage);
}

void Heavy_ChaffVerb::cPack_JnDlv10b_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sLine_onMessage(_c, &Context(_c)->sLine_UVTMOFJw, 0, m, NULL);
}

void Heavy_ChaffVerb::cUnop_b2p1m7YB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_OrDrXnVN, 0, m, &cVar_OrDrXnVN_sendMessage);
}

void Heavy_ChaffVerb::cBinop_Zh7t3Okk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_EXP, m, &cUnop_b2p1m7YB_sendMessage);
}

void Heavy_ChaffVerb::cVar_OrDrXnVN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_qx0zFwoh_sendMessage);
}

void Heavy_ChaffVerb::cPack_Dc2LNeH7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sLine_onMessage(_c, &Context(_c)->sLine_KxXNQs2p, 0, m, NULL);
}

void Heavy_ChaffVerb::cVar_UL2ol6A2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 1.5f, 0, m, &cBinop_sk4G2NNZ_sendMessage);
}

void Heavy_ChaffVerb::cVar_KiqH7N3e_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sPhasor_k_onMessage(_c, &Context(_c)->sPhasor_oMM6tSkH, 0, m);
}

void Heavy_ChaffVerb::cMsg_49DsYQhA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_h5HXNvy5_sendMessage);
}

void Heavy_ChaffVerb::cSystem_h5HXNvy5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_cpibFMpy_sendMessage);
}

void Heavy_ChaffVerb::cDelay_FwaTouMV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_FwaTouMV, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_24QHJZ99, 0, m, &cDelay_24QHJZ99_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_FwaTouMV, 0, m, &cDelay_FwaTouMV_sendMessage);
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_3dVaqRWN, 1, m, NULL);
}

void Heavy_ChaffVerb::cDelay_24QHJZ99_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_24QHJZ99, m);
  cMsg_GbpS8FR4_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cSwitchcase_zQMMbaZV_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x47BE8354: { // "clear"
      cMsg_LCewfMGV_sendMessage(_c, 0, m);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_ChaffVerb::cBinop_XGwzhjzI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_C6LVgQif_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::hTable_zsW0V9Hn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_LFuz5zmT_sendMessage(_c, 0, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_FwaTouMV, 2, m, &cDelay_FwaTouMV_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_KcDDHdQ8_sendMessage);
}

void Heavy_ChaffVerb::cMsg_C6LVgQif_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "resize");
  msg_setElementToFrom(m, 1, n, 0);
  hTable_onMessage(_c, &Context(_c)->hTable_zsW0V9Hn, 0, m, &hTable_zsW0V9Hn_sendMessage);
}

void Heavy_ChaffVerb::cBinop_cpibFMpy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 5000.0f, 0, m, &cBinop_XGwzhjzI_sendMessage);
}

void Heavy_ChaffVerb::cMsg_GbpS8FR4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mirror");
  hTable_onMessage(_c, &Context(_c)->hTable_zsW0V9Hn, 0, m, &hTable_zsW0V9Hn_sendMessage);
}

void Heavy_ChaffVerb::cCast_KcDDHdQ8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_FwaTouMV, 0, m, &cDelay_FwaTouMV_sendMessage);
}

void Heavy_ChaffVerb::cMsg_LFuz5zmT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cDelay_onMessage(_c, &Context(_c)->cDelay_24QHJZ99, 2, m, &cDelay_24QHJZ99_sendMessage);
}

void Heavy_ChaffVerb::cMsg_LCewfMGV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_3dVaqRWN, 1, m, NULL);
}

void Heavy_ChaffVerb::cMsg_hqXcXCS6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_Kzq1CJlg_sendMessage);
}

void Heavy_ChaffVerb::cSystem_Kzq1CJlg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_Gr73LdCp_sendMessage);
}

void Heavy_ChaffVerb::cVar_9LdQQRSE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_F8J3s4Oc_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cSystem_Zxq2Mpw1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_SMCJBBqb_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_mCi7Rvj4, m);
}

void Heavy_ChaffVerb::cBinop_Gr73LdCp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_gJcP0uUO, m);
}

void Heavy_ChaffVerb::cMsg_F8J3s4Oc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(3);
  msg_init(m, 3, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "table");
  msg_setElementToFrom(m, 1, n, 0);
  msg_setSymbol(m, 2, "size");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_Zxq2Mpw1_sendMessage);
}

void Heavy_ChaffVerb::cBinop_SMCJBBqb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_ulhN83Qc, m);
}

void Heavy_ChaffVerb::cMsg_dzwlQ8yr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_SFKkYO99_sendMessage);
}

void Heavy_ChaffVerb::cSystem_SFKkYO99_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_UWZf5Arl_sendMessage);
}

void Heavy_ChaffVerb::cVar_VDMWxd5L_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_VIHWfnRX_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cSystem_PvjOpz0A_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_Kg6VSYkq_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_Br5dP5pX, m);
}

void Heavy_ChaffVerb::cBinop_UWZf5Arl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_F6GntIho, m);
}

void Heavy_ChaffVerb::cMsg_VIHWfnRX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(3);
  msg_init(m, 3, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "table");
  msg_setElementToFrom(m, 1, n, 0);
  msg_setSymbol(m, 2, "size");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_PvjOpz0A_sendMessage);
}

void Heavy_ChaffVerb::cBinop_Kg6VSYkq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_v3sNsTsi, m);
}

void Heavy_ChaffVerb::cBinop_9YPnedFk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_KiqH7N3e, 0, m, &cVar_KiqH7N3e_sendMessage);
}

void Heavy_ChaffVerb::cBinop_YmgNSY0g_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_lv1ldXyv_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_TunEROEO_sendMessage);
}

void Heavy_ChaffVerb::cCast_TunEROEO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_9YPnedFk, HV_BINOP_DIVIDE, 0, m, &cBinop_9YPnedFk_sendMessage);
}

void Heavy_ChaffVerb::cCast_lv1ldXyv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_9YPnedFk, HV_BINOP_DIVIDE, 1, m, &cBinop_9YPnedFk_sendMessage);
}

void Heavy_ChaffVerb::cBinop_qx0zFwoh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_GzjPvs71_sendMessage);
}

void Heavy_ChaffVerb::cBinop_myvI8aY5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 87.3365f, 0, m, &cBinop_Zh7t3Okk_sendMessage);
}

void Heavy_ChaffVerb::cBinop_GzjPvs71_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_9YPnedFk, HV_BINOP_DIVIDE, 0, m, &cBinop_9YPnedFk_sendMessage);
}

void Heavy_ChaffVerb::cBinop_sk4G2NNZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cPack_onMessage(_c, &Context(_c)->cPack_Dc2LNeH7, 0, m, &cPack_Dc2LNeH7_sendMessage);
}

void Heavy_ChaffVerb::cBinop_5Zwx29KP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.001f, 0, m, &cBinop_YmgNSY0g_sendMessage);
  cPack_onMessage(_c, &Context(_c)->cPack_JnDlv10b, 0, m, &cPack_JnDlv10b_sendMessage);
}

void Heavy_ChaffVerb::cUnop_Tnl6GXQ3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_AxC4FC0r, 0, m, &cIf_AxC4FC0r_sendMessage);
}

void Heavy_ChaffVerb::cSwitchcase_q4m76GIB_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x0: { // "0.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_8MGOImg1_sendMessage);
      break;
    }
    case 0x3F800000: { // "1.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_v7TX9nwX_sendMessage);
      break;
    }
    case 0x40000000: { // "2.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_Oq4VDROj_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_ChaffVerb::cCast_8MGOImg1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_6Nt4UG02_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cCast_v7TX9nwX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Kpu5Xpzv_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cCast_Oq4VDROj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_INDGEanL_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cBinop_hE58INCt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_E2QDkBQW_sendMessage);
}

void Heavy_ChaffVerb::cBinop_E2QDkBQW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_slgZWHUr_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_u7bu2LTu_sendMessage);
}

void Heavy_ChaffVerb::cVar_nf9bFbxt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 1.0f, 0, m, &cBinop_qDXMKApv_sendMessage);
}

void Heavy_ChaffVerb::cMsg_0ABzFTWn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_tM0WCdnf_sendMessage);
}

void Heavy_ChaffVerb::cSystem_tM0WCdnf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_dXCBArab, HV_BINOP_DIVIDE, 1, m, &cBinop_dXCBArab_sendMessage);
}

void Heavy_ChaffVerb::cBinop_slgZWHUr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_SAZLYNV7_sendMessage);
}

void Heavy_ChaffVerb::cBinop_SAZLYNV7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_05SywGIo, m);
}

void Heavy_ChaffVerb::cMsg_4CTNR7wT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_BeQhLTKR_sendMessage);
}

void Heavy_ChaffVerb::cBinop_BeQhLTKR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_hE58INCt_sendMessage);
}

void Heavy_ChaffVerb::cBinop_u7bu2LTu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_ZzPSROtU, m);
}

void Heavy_ChaffVerb::cBinop_qDXMKApv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 6.28319f, 0, m, &cBinop_3xEedHFL_sendMessage);
}

void Heavy_ChaffVerb::cBinop_3xEedHFL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_dXCBArab, HV_BINOP_DIVIDE, 0, m, &cBinop_dXCBArab_sendMessage);
}

void Heavy_ChaffVerb::cBinop_dXCBArab_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_4CTNR7wT_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cSwitchcase_KO2biodD_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7E64BD01: { // "seed"
      cSlice_onMessage(_c, &Context(_c)->cSlice_pttd8ARc, 0, m, &cSlice_pttd8ARc_sendMessage);
      break;
    }
    default: {
      cRandom_onMessage(_c, &Context(_c)->cRandom_XWvwig7a, 0, m, &cRandom_XWvwig7a_sendMessage);
      break;
    }
  }
}

void Heavy_ChaffVerb::cBinop_ORNG1vW4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_FLOOR, m, &cUnop_uDRgycvF_sendMessage);
}

void Heavy_ChaffVerb::cUnop_uDRgycvF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 50.0f, 0, m, &cBinop_nwEeAe6X_sendMessage);
}

void Heavy_ChaffVerb::cRandom_XWvwig7a_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 100.0f, 0, m, &cBinop_ORNG1vW4_sendMessage);
}

void Heavy_ChaffVerb::cSlice_pttd8ARc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cRandom_onMessage(_c, &Context(_c)->cRandom_XWvwig7a, 1, m, &cRandom_XWvwig7a_sendMessage);
      break;
    }
    case 1: {
      break;
    }
    default: return;
  }
}

void Heavy_ChaffVerb::cSwitchcase_iGciybF6_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x0: { // "0.0"
      cMsg_EseZzuqe_sendMessage(_c, 0, m);
      break;
    }
    case 0x7A5B032D: { // "stop"
      cMsg_EseZzuqe_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_dmOVJpVF_sendMessage);
      break;
    }
  }
}

void Heavy_ChaffVerb::cDelay_v67z7oCV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_v67z7oCV, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_v67z7oCV, 0, m, &cDelay_v67z7oCV_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_OuBkSOsn, 0, m, &cVar_OuBkSOsn_sendMessage);
}

void Heavy_ChaffVerb::cCast_dmOVJpVF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_EseZzuqe_sendMessage(_c, 0, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_v67z7oCV, 0, m, &cDelay_v67z7oCV_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_OuBkSOsn, 0, m, &cVar_OuBkSOsn_sendMessage);
}

void Heavy_ChaffVerb::cMsg_IPJQniWW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_IYQtuPBy_sendMessage);
}

void Heavy_ChaffVerb::cSystem_IYQtuPBy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_pMsyPUYG_sendMessage);
}

void Heavy_ChaffVerb::cVar_d2qJXo7W_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_3YXVX8XL, HV_BINOP_MULTIPLY, 0, m, &cBinop_3YXVX8XL_sendMessage);
}

void Heavy_ChaffVerb::cMsg_EseZzuqe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_v67z7oCV, 0, m, &cDelay_v67z7oCV_sendMessage);
}

void Heavy_ChaffVerb::cBinop_ojuoyhbl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_v67z7oCV, 2, m, &cDelay_v67z7oCV_sendMessage);
}

void Heavy_ChaffVerb::cBinop_pMsyPUYG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_3YXVX8XL, HV_BINOP_MULTIPLY, 1, m, &cBinop_3YXVX8XL_sendMessage);
}

void Heavy_ChaffVerb::cBinop_3YXVX8XL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 1.0f, 0, m, &cBinop_ojuoyhbl_sendMessage);
}

void Heavy_ChaffVerb::cTabhead_cp8DKvRz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_fVGFCkaH, HV_BINOP_SUBTRACT, 0, m, &cBinop_fVGFCkaH_sendMessage);
}

void Heavy_ChaffVerb::cMsg_aNZLIfOi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_JIOixkVV_sendMessage);
}

void Heavy_ChaffVerb::cSystem_JIOixkVV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_kOaSnZLB_sendMessage);
}

void Heavy_ChaffVerb::cVar_wGus0R6b_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_BBjZGbx4_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cDelay_DVp19DqI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_DVp19DqI, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_mdDbTQdy, 0, m, &cDelay_mdDbTQdy_sendMessage);
  sTabread_onMessage(_c, &Context(_c)->sTabread_aLsECrs5, 0, m, &sTabread_aLsECrs5_sendMessage);
}

void Heavy_ChaffVerb::cDelay_mdDbTQdy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_mdDbTQdy, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_aLsECrs5, 0, m, &sTabread_aLsECrs5_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_mdDbTQdy, 0, m, &cDelay_mdDbTQdy_sendMessage);
}

void Heavy_ChaffVerb::sTabread_aLsECrs5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_onMessage(_c, &Context(_c)->cBinop_nPo6Grx0, HV_BINOP_SUBTRACT, 0, m, &cBinop_nPo6Grx0_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_ChaffVerb::cBinop_uLbmFaDf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_49OAiD0B, HV_BINOP_MAX, 0, m, &cBinop_49OAiD0B_sendMessage);
}

void Heavy_ChaffVerb::cBinop_kOaSnZLB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_uLbmFaDf, HV_BINOP_MULTIPLY, 0, m, &cBinop_uLbmFaDf_sendMessage);
}

void Heavy_ChaffVerb::cBinop_fVGFCkaH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_QVGIcV1u_sendMessage(_c, 0, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_aLsECrs5, 0, m, &sTabread_aLsECrs5_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_FnqBI9HT_sendMessage);
}

void Heavy_ChaffVerb::cSystem_9YnEvjMj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_nPo6Grx0, HV_BINOP_SUBTRACT, 1, m, &cBinop_nPo6Grx0_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_mdDbTQdy, 2, m, &cDelay_mdDbTQdy_sendMessage);
}

void Heavy_ChaffVerb::cMsg_BBjZGbx4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(3);
  msg_init(m, 3, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "table");
  msg_setElementToFrom(m, 1, n, 0);
  msg_setSymbol(m, 2, "size");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_9YnEvjMj_sendMessage);
}

void Heavy_ChaffVerb::cMsg_QVGIcV1u_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_DVp19DqI, 0, m, &cDelay_DVp19DqI_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_mdDbTQdy, 0, m, &cDelay_mdDbTQdy_sendMessage);
}

void Heavy_ChaffVerb::cMsg_2LVo4F5W_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cBinop_onMessage(_c, &Context(_c)->cBinop_49OAiD0B, HV_BINOP_MAX, 1, m, &cBinop_49OAiD0B_sendMessage);
}

void Heavy_ChaffVerb::cBinop_49OAiD0B_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_fVGFCkaH, HV_BINOP_SUBTRACT, 1, m, &cBinop_fVGFCkaH_sendMessage);
}

void Heavy_ChaffVerb::cCast_FnqBI9HT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_DVp19DqI, 0, m, &cDelay_DVp19DqI_sendMessage);
}

void Heavy_ChaffVerb::cBinop_2DlPEkE6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_DVp19DqI, 2, m, &cDelay_DVp19DqI_sendMessage);
}

void Heavy_ChaffVerb::cBinop_nPo6Grx0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_2DlPEkE6_sendMessage);
}

void Heavy_ChaffVerb::cCast_D0yQKCFL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_wGus0R6b, 0, m, &cVar_wGus0R6b_sendMessage);
  cMsg_aNZLIfOi_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_cp8DKvRz, 0, m, &cTabhead_cp8DKvRz_sendMessage);
}

void Heavy_ChaffVerb::cTabhead_qyVXGops_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_LREEgvuE, HV_BINOP_SUBTRACT, 0, m, &cBinop_LREEgvuE_sendMessage);
}

void Heavy_ChaffVerb::cMsg_jGhbUYvn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_FzLYNXuY_sendMessage);
}

void Heavy_ChaffVerb::cSystem_FzLYNXuY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_3c9k9iGQ_sendMessage);
}

void Heavy_ChaffVerb::cVar_dLvNv0er_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_1gzbasGJ_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cDelay_V5j2xK8K_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_V5j2xK8K, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_m6c3071s, 0, m, &cDelay_m6c3071s_sendMessage);
  sTabread_onMessage(_c, &Context(_c)->sTabread_FBDeFP8S, 0, m, &sTabread_FBDeFP8S_sendMessage);
}

void Heavy_ChaffVerb::cDelay_m6c3071s_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_m6c3071s, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_FBDeFP8S, 0, m, &sTabread_FBDeFP8S_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_m6c3071s, 0, m, &cDelay_m6c3071s_sendMessage);
}

void Heavy_ChaffVerb::sTabread_FBDeFP8S_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_onMessage(_c, &Context(_c)->cBinop_J8ALRGNG, HV_BINOP_SUBTRACT, 0, m, &cBinop_J8ALRGNG_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_ChaffVerb::cBinop_UyLp72gY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_EkoQ1nIp, HV_BINOP_MAX, 0, m, &cBinop_EkoQ1nIp_sendMessage);
}

void Heavy_ChaffVerb::cBinop_3c9k9iGQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_UyLp72gY, HV_BINOP_MULTIPLY, 0, m, &cBinop_UyLp72gY_sendMessage);
}

void Heavy_ChaffVerb::cBinop_LREEgvuE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_dKq5w5w0_sendMessage(_c, 0, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_FBDeFP8S, 0, m, &sTabread_FBDeFP8S_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_66D8IQnO_sendMessage);
}

void Heavy_ChaffVerb::cSystem_uMUDG6sv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_J8ALRGNG, HV_BINOP_SUBTRACT, 1, m, &cBinop_J8ALRGNG_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_m6c3071s, 2, m, &cDelay_m6c3071s_sendMessage);
}

void Heavy_ChaffVerb::cMsg_1gzbasGJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(3);
  msg_init(m, 3, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "table");
  msg_setElementToFrom(m, 1, n, 0);
  msg_setSymbol(m, 2, "size");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_uMUDG6sv_sendMessage);
}

void Heavy_ChaffVerb::cMsg_dKq5w5w0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_V5j2xK8K, 0, m, &cDelay_V5j2xK8K_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_m6c3071s, 0, m, &cDelay_m6c3071s_sendMessage);
}

void Heavy_ChaffVerb::cMsg_cEEB3nYX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cBinop_onMessage(_c, &Context(_c)->cBinop_EkoQ1nIp, HV_BINOP_MAX, 1, m, &cBinop_EkoQ1nIp_sendMessage);
}

void Heavy_ChaffVerb::cBinop_EkoQ1nIp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_LREEgvuE, HV_BINOP_SUBTRACT, 1, m, &cBinop_LREEgvuE_sendMessage);
}

void Heavy_ChaffVerb::cCast_66D8IQnO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_V5j2xK8K, 0, m, &cDelay_V5j2xK8K_sendMessage);
}

void Heavy_ChaffVerb::cBinop_gcocd51C_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_V5j2xK8K, 2, m, &cDelay_V5j2xK8K_sendMessage);
}

void Heavy_ChaffVerb::cBinop_J8ALRGNG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_gcocd51C_sendMessage);
}

void Heavy_ChaffVerb::cCast_KEZ7aXOr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_dLvNv0er, 0, m, &cVar_dLvNv0er_sendMessage);
  cMsg_jGhbUYvn_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_qyVXGops, 0, m, &cTabhead_qyVXGops_sendMessage);
}

void Heavy_ChaffVerb::cTabhead_P1m3wftP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_GP3DzkRX, HV_BINOP_SUBTRACT, 0, m, &cBinop_GP3DzkRX_sendMessage);
}

void Heavy_ChaffVerb::cMsg_vbCACrHm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_krVm5EWM_sendMessage);
}

void Heavy_ChaffVerb::cSystem_krVm5EWM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_5Ql6tYZl_sendMessage);
}

void Heavy_ChaffVerb::cVar_n1oflsyY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_ctBhqNLe_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cDelay_mpHhGTaY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_mpHhGTaY, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_HMWEF90w, 0, m, &cDelay_HMWEF90w_sendMessage);
  sTabread_onMessage(_c, &Context(_c)->sTabread_liVnSrA8, 0, m, &sTabread_liVnSrA8_sendMessage);
}

void Heavy_ChaffVerb::cDelay_HMWEF90w_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_HMWEF90w, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_liVnSrA8, 0, m, &sTabread_liVnSrA8_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_HMWEF90w, 0, m, &cDelay_HMWEF90w_sendMessage);
}

void Heavy_ChaffVerb::sTabread_liVnSrA8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_onMessage(_c, &Context(_c)->cBinop_799Iq6pv, HV_BINOP_SUBTRACT, 0, m, &cBinop_799Iq6pv_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_ChaffVerb::cBinop_hHnbP7Yt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_4Y3ObtZq, HV_BINOP_MAX, 0, m, &cBinop_4Y3ObtZq_sendMessage);
}

void Heavy_ChaffVerb::cBinop_5Ql6tYZl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_hHnbP7Yt, HV_BINOP_MULTIPLY, 0, m, &cBinop_hHnbP7Yt_sendMessage);
}

void Heavy_ChaffVerb::cBinop_GP3DzkRX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_yyiTrMYJ_sendMessage(_c, 0, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_liVnSrA8, 0, m, &sTabread_liVnSrA8_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_B1tUpPC7_sendMessage);
}

void Heavy_ChaffVerb::cSystem_UDGVAgPH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_799Iq6pv, HV_BINOP_SUBTRACT, 1, m, &cBinop_799Iq6pv_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_HMWEF90w, 2, m, &cDelay_HMWEF90w_sendMessage);
}

void Heavy_ChaffVerb::cMsg_ctBhqNLe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(3);
  msg_init(m, 3, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "table");
  msg_setElementToFrom(m, 1, n, 0);
  msg_setSymbol(m, 2, "size");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_UDGVAgPH_sendMessage);
}

void Heavy_ChaffVerb::cMsg_yyiTrMYJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_mpHhGTaY, 0, m, &cDelay_mpHhGTaY_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_HMWEF90w, 0, m, &cDelay_HMWEF90w_sendMessage);
}

void Heavy_ChaffVerb::cMsg_rBaptnYC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cBinop_onMessage(_c, &Context(_c)->cBinop_4Y3ObtZq, HV_BINOP_MAX, 1, m, &cBinop_4Y3ObtZq_sendMessage);
}

void Heavy_ChaffVerb::cBinop_4Y3ObtZq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_GP3DzkRX, HV_BINOP_SUBTRACT, 1, m, &cBinop_GP3DzkRX_sendMessage);
}

void Heavy_ChaffVerb::cCast_B1tUpPC7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_mpHhGTaY, 0, m, &cDelay_mpHhGTaY_sendMessage);
}

void Heavy_ChaffVerb::cBinop_vDp7IfdS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_mpHhGTaY, 2, m, &cDelay_mpHhGTaY_sendMessage);
}

void Heavy_ChaffVerb::cBinop_799Iq6pv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_vDp7IfdS_sendMessage);
}

void Heavy_ChaffVerb::cCast_zpZpNSGt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_n1oflsyY, 0, m, &cVar_n1oflsyY_sendMessage);
  cMsg_vbCACrHm_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_P1m3wftP, 0, m, &cTabhead_P1m3wftP_sendMessage);
}

void Heavy_ChaffVerb::cTabhead_KfIdq9l7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_v2X9NAqX, HV_BINOP_SUBTRACT, 0, m, &cBinop_v2X9NAqX_sendMessage);
}

void Heavy_ChaffVerb::cMsg_sPA6I0qg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_9SwhbgQg_sendMessage);
}

void Heavy_ChaffVerb::cSystem_9SwhbgQg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_QKT5vwr5_sendMessage);
}

void Heavy_ChaffVerb::cVar_EkCzpM1O_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_6sYmSvTA_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cDelay_7S1KZvdo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_7S1KZvdo, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_lbpB2sQk, 0, m, &cDelay_lbpB2sQk_sendMessage);
  sTabread_onMessage(_c, &Context(_c)->sTabread_Ry19IS0x, 0, m, &sTabread_Ry19IS0x_sendMessage);
}

void Heavy_ChaffVerb::cDelay_lbpB2sQk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_lbpB2sQk, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_Ry19IS0x, 0, m, &sTabread_Ry19IS0x_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_lbpB2sQk, 0, m, &cDelay_lbpB2sQk_sendMessage);
}

void Heavy_ChaffVerb::sTabread_Ry19IS0x_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_onMessage(_c, &Context(_c)->cBinop_Fg2dgbHZ, HV_BINOP_SUBTRACT, 0, m, &cBinop_Fg2dgbHZ_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_ChaffVerb::cBinop_rgDYRb2o_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_noiJ837D, HV_BINOP_MAX, 0, m, &cBinop_noiJ837D_sendMessage);
}

void Heavy_ChaffVerb::cBinop_QKT5vwr5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_rgDYRb2o, HV_BINOP_MULTIPLY, 0, m, &cBinop_rgDYRb2o_sendMessage);
}

void Heavy_ChaffVerb::cBinop_v2X9NAqX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_WdA9uwcw_sendMessage(_c, 0, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_Ry19IS0x, 0, m, &sTabread_Ry19IS0x_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_nKsPoQ3c_sendMessage);
}

void Heavy_ChaffVerb::cSystem_U5NGGgij_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Fg2dgbHZ, HV_BINOP_SUBTRACT, 1, m, &cBinop_Fg2dgbHZ_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_lbpB2sQk, 2, m, &cDelay_lbpB2sQk_sendMessage);
}

void Heavy_ChaffVerb::cMsg_6sYmSvTA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(3);
  msg_init(m, 3, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "table");
  msg_setElementToFrom(m, 1, n, 0);
  msg_setSymbol(m, 2, "size");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_U5NGGgij_sendMessage);
}

void Heavy_ChaffVerb::cMsg_WdA9uwcw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_7S1KZvdo, 0, m, &cDelay_7S1KZvdo_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_lbpB2sQk, 0, m, &cDelay_lbpB2sQk_sendMessage);
}

void Heavy_ChaffVerb::cMsg_OLHvVK9X_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cBinop_onMessage(_c, &Context(_c)->cBinop_noiJ837D, HV_BINOP_MAX, 1, m, &cBinop_noiJ837D_sendMessage);
}

void Heavy_ChaffVerb::cBinop_noiJ837D_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_v2X9NAqX, HV_BINOP_SUBTRACT, 1, m, &cBinop_v2X9NAqX_sendMessage);
}

void Heavy_ChaffVerb::cCast_nKsPoQ3c_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_7S1KZvdo, 0, m, &cDelay_7S1KZvdo_sendMessage);
}

void Heavy_ChaffVerb::cBinop_t1P7sFjR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_7S1KZvdo, 2, m, &cDelay_7S1KZvdo_sendMessage);
}

void Heavy_ChaffVerb::cBinop_Fg2dgbHZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_t1P7sFjR_sendMessage);
}

void Heavy_ChaffVerb::cCast_KuhPdGMC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_EkCzpM1O, 0, m, &cVar_EkCzpM1O_sendMessage);
  cMsg_sPA6I0qg_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_KfIdq9l7, 0, m, &cTabhead_KfIdq9l7_sendMessage);
}

void Heavy_ChaffVerb::cMsg_bjyCPvFF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_zhxXX1GK_sendMessage);
}

void Heavy_ChaffVerb::cSystem_zhxXX1GK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_RdQ7dKzq_sendMessage);
}

void Heavy_ChaffVerb::cDelay_OnyvvNtf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_OnyvvNtf, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_TbTtX9QR, 0, m, &cDelay_TbTtX9QR_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_OnyvvNtf, 0, m, &cDelay_OnyvvNtf_sendMessage);
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_crqYqLHh, 1, m, NULL);
}

void Heavy_ChaffVerb::cDelay_TbTtX9QR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_TbTtX9QR, m);
  cMsg_dlfPmO6r_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cSwitchcase_gHU2Eqip_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x47BE8354: { // "clear"
      cMsg_gj7BlVjW_sendMessage(_c, 0, m);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_ChaffVerb::cBinop_PZ3sMFAB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_ngkVZZxq_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::hTable_Eps2MvSJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_3SgOnsHV_sendMessage(_c, 0, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_OnyvvNtf, 2, m, &cDelay_OnyvvNtf_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_WO260VSV_sendMessage);
}

void Heavy_ChaffVerb::cMsg_ngkVZZxq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "resize");
  msg_setElementToFrom(m, 1, n, 0);
  hTable_onMessage(_c, &Context(_c)->hTable_Eps2MvSJ, 0, m, &hTable_Eps2MvSJ_sendMessage);
}

void Heavy_ChaffVerb::cBinop_RdQ7dKzq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 58.6435f, 0, m, &cBinop_PZ3sMFAB_sendMessage);
}

void Heavy_ChaffVerb::cMsg_dlfPmO6r_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mirror");
  hTable_onMessage(_c, &Context(_c)->hTable_Eps2MvSJ, 0, m, &hTable_Eps2MvSJ_sendMessage);
}

void Heavy_ChaffVerb::cCast_WO260VSV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_OnyvvNtf, 0, m, &cDelay_OnyvvNtf_sendMessage);
}

void Heavy_ChaffVerb::cMsg_3SgOnsHV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cDelay_onMessage(_c, &Context(_c)->cDelay_TbTtX9QR, 2, m, &cDelay_TbTtX9QR_sendMessage);
}

void Heavy_ChaffVerb::cMsg_gj7BlVjW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_crqYqLHh, 1, m, NULL);
}

void Heavy_ChaffVerb::cMsg_DsiVNcQb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_XsamwVLR_sendMessage);
}

void Heavy_ChaffVerb::cSystem_XsamwVLR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_4kGvYquZ_sendMessage);
}

void Heavy_ChaffVerb::cDelay_w9xCtA1d_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_w9xCtA1d, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_b7Pya8Kj, 0, m, &cDelay_b7Pya8Kj_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_w9xCtA1d, 0, m, &cDelay_w9xCtA1d_sendMessage);
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_nUc2GthC, 1, m, NULL);
}

void Heavy_ChaffVerb::cDelay_b7Pya8Kj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_b7Pya8Kj, m);
  cMsg_seMzIF8K_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cSwitchcase_bf8mzpgo_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x47BE8354: { // "clear"
      cMsg_ZzgLPTUk_sendMessage(_c, 0, m);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_ChaffVerb::cBinop_VMuzdFJ1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_ehkRXXs9_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::hTable_sr6568YJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_mloesGpo_sendMessage(_c, 0, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_w9xCtA1d, 2, m, &cDelay_w9xCtA1d_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_J7BT5ni1_sendMessage);
}

void Heavy_ChaffVerb::cMsg_ehkRXXs9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "resize");
  msg_setElementToFrom(m, 1, n, 0);
  hTable_onMessage(_c, &Context(_c)->hTable_sr6568YJ, 0, m, &hTable_sr6568YJ_sendMessage);
}

void Heavy_ChaffVerb::cBinop_4kGvYquZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 69.4325f, 0, m, &cBinop_VMuzdFJ1_sendMessage);
}

void Heavy_ChaffVerb::cMsg_seMzIF8K_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mirror");
  hTable_onMessage(_c, &Context(_c)->hTable_sr6568YJ, 0, m, &hTable_sr6568YJ_sendMessage);
}

void Heavy_ChaffVerb::cCast_J7BT5ni1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_w9xCtA1d, 0, m, &cDelay_w9xCtA1d_sendMessage);
}

void Heavy_ChaffVerb::cMsg_mloesGpo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cDelay_onMessage(_c, &Context(_c)->cDelay_b7Pya8Kj, 2, m, &cDelay_b7Pya8Kj_sendMessage);
}

void Heavy_ChaffVerb::cMsg_ZzgLPTUk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_nUc2GthC, 1, m, NULL);
}

void Heavy_ChaffVerb::cMsg_m0sszrfW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_k4kj7rJ2_sendMessage);
}

void Heavy_ChaffVerb::cSystem_k4kj7rJ2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_UvKieLFl_sendMessage);
}

void Heavy_ChaffVerb::cDelay_slID6Kuw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_slID6Kuw, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_UT1eM8Xk, 0, m, &cDelay_UT1eM8Xk_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_slID6Kuw, 0, m, &cDelay_slID6Kuw_sendMessage);
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_5IRUmwEX, 1, m, NULL);
}

void Heavy_ChaffVerb::cDelay_UT1eM8Xk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_UT1eM8Xk, m);
  cMsg_QILHz5k5_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cSwitchcase_dbuNnMrI_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x47BE8354: { // "clear"
      cMsg_YL5j9Piu_sendMessage(_c, 0, m);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_ChaffVerb::cBinop_x2xAnWtD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_52D68G4S_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::hTable_g4BTC3wP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_YmO9Zaqe_sendMessage(_c, 0, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_slID6Kuw, 2, m, &cDelay_slID6Kuw_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_2sSsi7mG_sendMessage);
}

void Heavy_ChaffVerb::cMsg_52D68G4S_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "resize");
  msg_setElementToFrom(m, 1, n, 0);
  hTable_onMessage(_c, &Context(_c)->hTable_g4BTC3wP, 0, m, &hTable_g4BTC3wP_sendMessage);
}

void Heavy_ChaffVerb::cBinop_UvKieLFl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 74.5234f, 0, m, &cBinop_x2xAnWtD_sendMessage);
}

void Heavy_ChaffVerb::cMsg_QILHz5k5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mirror");
  hTable_onMessage(_c, &Context(_c)->hTable_g4BTC3wP, 0, m, &hTable_g4BTC3wP_sendMessage);
}

void Heavy_ChaffVerb::cCast_2sSsi7mG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_slID6Kuw, 0, m, &cDelay_slID6Kuw_sendMessage);
}

void Heavy_ChaffVerb::cMsg_YmO9Zaqe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cDelay_onMessage(_c, &Context(_c)->cDelay_UT1eM8Xk, 2, m, &cDelay_UT1eM8Xk_sendMessage);
}

void Heavy_ChaffVerb::cMsg_YL5j9Piu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_5IRUmwEX, 1, m, NULL);
}

void Heavy_ChaffVerb::cMsg_viGNWezD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_jfdP1P6G_sendMessage);
}

void Heavy_ChaffVerb::cSystem_jfdP1P6G_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_08Jtwm3N_sendMessage);
}

void Heavy_ChaffVerb::cDelay_ITeKRD7a_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_ITeKRD7a, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_GyQxUJy2, 0, m, &cDelay_GyQxUJy2_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_ITeKRD7a, 0, m, &cDelay_ITeKRD7a_sendMessage);
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_NZHBFcRO, 1, m, NULL);
}

void Heavy_ChaffVerb::cDelay_GyQxUJy2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_GyQxUJy2, m);
  cMsg_oyOjntgU_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cSwitchcase_AHU2xSJe_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x47BE8354: { // "clear"
      cMsg_YUFMCfVh_sendMessage(_c, 0, m);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_ChaffVerb::cBinop_7gYTMIlz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_71tRBKre_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::hTable_qOqD14n5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_E7Dtdojl_sendMessage(_c, 0, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_ITeKRD7a, 2, m, &cDelay_ITeKRD7a_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_1EXM9QII_sendMessage);
}

void Heavy_ChaffVerb::cMsg_71tRBKre_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "resize");
  msg_setElementToFrom(m, 1, n, 0);
  hTable_onMessage(_c, &Context(_c)->hTable_qOqD14n5, 0, m, &hTable_qOqD14n5_sendMessage);
}

void Heavy_ChaffVerb::cBinop_08Jtwm3N_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 86.1244f, 0, m, &cBinop_7gYTMIlz_sendMessage);
}

void Heavy_ChaffVerb::cMsg_oyOjntgU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mirror");
  hTable_onMessage(_c, &Context(_c)->hTable_qOqD14n5, 0, m, &hTable_qOqD14n5_sendMessage);
}

void Heavy_ChaffVerb::cCast_1EXM9QII_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_ITeKRD7a, 0, m, &cDelay_ITeKRD7a_sendMessage);
}

void Heavy_ChaffVerb::cMsg_E7Dtdojl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cDelay_onMessage(_c, &Context(_c)->cDelay_GyQxUJy2, 2, m, &cDelay_GyQxUJy2_sendMessage);
}

void Heavy_ChaffVerb::cMsg_YUFMCfVh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_NZHBFcRO, 1, m, NULL);
}

void Heavy_ChaffVerb::cPack_Feo0fVsu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sLine_onMessage(_c, &Context(_c)->sLine_gMJPoKz9, 0, m, NULL);
}

void Heavy_ChaffVerb::cPack_RjH0cWG9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sLine_onMessage(_c, &Context(_c)->sLine_woutXzoG, 0, m, NULL);
}

void Heavy_ChaffVerb::cBinop_xe58P1uL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_w4jobXk5_sendMessage);
}

void Heavy_ChaffVerb::cBinop_w4jobXk5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 200.0f, 0, m, &cBinop_7LBiOp3M_sendMessage);
}

void Heavy_ChaffVerb::cVar_jGto9i39_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_wmoKavlJ, HV_BINOP_MULTIPLY, 0, m, &cBinop_wmoKavlJ_sendMessage);
}

void Heavy_ChaffVerb::cMsg_214ERUVM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_E54lsimN_sendMessage);
}

void Heavy_ChaffVerb::cSystem_E54lsimN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_ElROhqT3_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cBinop_wmoKavlJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_3fndkk86_sendMessage);
}

void Heavy_ChaffVerb::cBinop_tdy0lSwP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_wmoKavlJ, HV_BINOP_MULTIPLY, 1, m, &cBinop_wmoKavlJ_sendMessage);
}

void Heavy_ChaffVerb::cMsg_ElROhqT3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 6.28319f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_tdy0lSwP_sendMessage);
}

void Heavy_ChaffVerb::cBinop_3fndkk86_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_dWlBDYJe_sendMessage);
}

void Heavy_ChaffVerb::cBinop_dWlBDYJe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_Ygl558Ss_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_yuyuarWk, m);
}

void Heavy_ChaffVerb::cBinop_Ygl558Ss_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_saMXdENi, m);
}

void Heavy_ChaffVerb::cVar_blvX2ydM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.125f, 0, m, &cBinop_JzTiV4RG_sendMessage);
}

void Heavy_ChaffVerb::cVar_65zwXySq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 100.0f, 0, m, &cBinop_xe58P1uL_sendMessage);
}

void Heavy_ChaffVerb::cVar_ZdJmEBbE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN_EQL, 1.0f, 0, m, &cBinop_ZDd8Ne8W_sendMessage);
  cIf_onMessage(_c, &Context(_c)->cIf_h10lexHY, 0, m, &cIf_h10lexHY_sendMessage);
}

void Heavy_ChaffVerb::cVar_sGcl5Qwr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 100.0f, 0, m, &cBinop_ZFlNfDh2_sendMessage);
}

void Heavy_ChaffVerb::cIf_h10lexHY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cMsg_Ru8iaJgG_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cVar_onMessage(_c, &Context(_c)->cVar_TGzMkoH6, 0, m, &cVar_TGzMkoH6_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_ChaffVerb::cBinop_ZDd8Ne8W_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_h10lexHY, 1, m, &cIf_h10lexHY_sendMessage);
}

void Heavy_ChaffVerb::cBinop_ZFlNfDh2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_e4EqgeNa_sendMessage);
}

void Heavy_ChaffVerb::cBinop_e4EqgeNa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_qSSYcbjm, 0, m, &cVar_qSSYcbjm_sendMessage);
}

void Heavy_ChaffVerb::cMsg_4AotWg2y_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_x0KHbQxu_sendMessage);
}

void Heavy_ChaffVerb::cSystem_x0KHbQxu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_zDZAy9my_sendMessage);
}

void Heavy_ChaffVerb::cDelay_zMB4UTuL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_zMB4UTuL, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_dhJ6cAA1, 0, m, &cDelay_dhJ6cAA1_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_zMB4UTuL, 0, m, &cDelay_zMB4UTuL_sendMessage);
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_406QjmMR, 1, m, NULL);
}

void Heavy_ChaffVerb::cDelay_dhJ6cAA1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_dhJ6cAA1, m);
  cMsg_7zscxphT_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cSwitchcase_vcW9m2j1_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x47BE8354: { // "clear"
      cMsg_FMQdWcsS_sendMessage(_c, 0, m);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_ChaffVerb::cBinop_EhHIs5mM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_3GSJbnY7_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::hTable_xGZuUzoO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_btswxNgQ_sendMessage(_c, 0, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_zMB4UTuL, 2, m, &cDelay_zMB4UTuL_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_Z4glxh02_sendMessage);
}

void Heavy_ChaffVerb::cMsg_3GSJbnY7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "resize");
  msg_setElementToFrom(m, 1, n, 0);
  hTable_onMessage(_c, &Context(_c)->hTable_xGZuUzoO, 0, m, &hTable_xGZuUzoO_sendMessage);
}

void Heavy_ChaffVerb::cBinop_zDZAy9my_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 43.5337f, 0, m, &cBinop_EhHIs5mM_sendMessage);
}

void Heavy_ChaffVerb::cMsg_7zscxphT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mirror");
  hTable_onMessage(_c, &Context(_c)->hTable_xGZuUzoO, 0, m, &hTable_xGZuUzoO_sendMessage);
}

void Heavy_ChaffVerb::cCast_Z4glxh02_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_zMB4UTuL, 0, m, &cDelay_zMB4UTuL_sendMessage);
}

void Heavy_ChaffVerb::cMsg_btswxNgQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cDelay_onMessage(_c, &Context(_c)->cDelay_dhJ6cAA1, 2, m, &cDelay_dhJ6cAA1_sendMessage);
}

void Heavy_ChaffVerb::cMsg_FMQdWcsS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_406QjmMR, 1, m, NULL);
}

void Heavy_ChaffVerb::cTabhead_nqB3ukpi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_fPBThhAH, HV_BINOP_SUBTRACT, 0, m, &cBinop_fPBThhAH_sendMessage);
}

void Heavy_ChaffVerb::cMsg_bNQYXxiz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_Zngtq97s_sendMessage);
}

void Heavy_ChaffVerb::cSystem_Zngtq97s_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_cduEeBvF_sendMessage);
}

void Heavy_ChaffVerb::cVar_62QYKRhC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_5PT538YM_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cDelay_ViDyMgie_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_ViDyMgie, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_HNhLI4vH, 0, m, &cDelay_HNhLI4vH_sendMessage);
  sTabread_onMessage(_c, &Context(_c)->sTabread_B8TSCxn7, 0, m, &sTabread_B8TSCxn7_sendMessage);
}

void Heavy_ChaffVerb::cDelay_HNhLI4vH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_HNhLI4vH, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_B8TSCxn7, 0, m, &sTabread_B8TSCxn7_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_HNhLI4vH, 0, m, &cDelay_HNhLI4vH_sendMessage);
}

void Heavy_ChaffVerb::sTabread_B8TSCxn7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_onMessage(_c, &Context(_c)->cBinop_ke7WZ7QG, HV_BINOP_SUBTRACT, 0, m, &cBinop_ke7WZ7QG_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_ChaffVerb::cBinop_nFDlVs82_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_emGdXwmU, HV_BINOP_MAX, 0, m, &cBinop_emGdXwmU_sendMessage);
}

void Heavy_ChaffVerb::cBinop_cduEeBvF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_nFDlVs82, HV_BINOP_MULTIPLY, 0, m, &cBinop_nFDlVs82_sendMessage);
}

void Heavy_ChaffVerb::cBinop_fPBThhAH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_ldyPCwEY_sendMessage(_c, 0, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_B8TSCxn7, 0, m, &sTabread_B8TSCxn7_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_O5FtunzE_sendMessage);
}

void Heavy_ChaffVerb::cSystem_7Cchl65p_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_ke7WZ7QG, HV_BINOP_SUBTRACT, 1, m, &cBinop_ke7WZ7QG_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_HNhLI4vH, 2, m, &cDelay_HNhLI4vH_sendMessage);
}

void Heavy_ChaffVerb::cMsg_5PT538YM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(3);
  msg_init(m, 3, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "table");
  msg_setElementToFrom(m, 1, n, 0);
  msg_setSymbol(m, 2, "size");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_7Cchl65p_sendMessage);
}

void Heavy_ChaffVerb::cMsg_ldyPCwEY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_ViDyMgie, 0, m, &cDelay_ViDyMgie_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_HNhLI4vH, 0, m, &cDelay_HNhLI4vH_sendMessage);
}

void Heavy_ChaffVerb::cMsg_QG1mDwBf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cBinop_onMessage(_c, &Context(_c)->cBinop_emGdXwmU, HV_BINOP_MAX, 1, m, &cBinop_emGdXwmU_sendMessage);
}

void Heavy_ChaffVerb::cBinop_emGdXwmU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_fPBThhAH, HV_BINOP_SUBTRACT, 1, m, &cBinop_fPBThhAH_sendMessage);
}

void Heavy_ChaffVerb::cCast_O5FtunzE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_ViDyMgie, 0, m, &cDelay_ViDyMgie_sendMessage);
}

void Heavy_ChaffVerb::cBinop_v1aXrnAR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_ViDyMgie, 2, m, &cDelay_ViDyMgie_sendMessage);
}

void Heavy_ChaffVerb::cBinop_ke7WZ7QG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_v1aXrnAR_sendMessage);
}

void Heavy_ChaffVerb::cCast_dSEBc1NJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_62QYKRhC, 0, m, &cVar_62QYKRhC_sendMessage);
  cMsg_bNQYXxiz_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_nqB3ukpi, 0, m, &cTabhead_nqB3ukpi_sendMessage);
}

void Heavy_ChaffVerb::cMsg_JBIbhXu0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_M6rtfRtu_sendMessage);
}

void Heavy_ChaffVerb::cSystem_M6rtfRtu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_DsNaO0VD_sendMessage);
}

void Heavy_ChaffVerb::cDelay_rgpIIC9o_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_rgpIIC9o, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_fiNJNCEq, 0, m, &cDelay_fiNJNCEq_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_rgpIIC9o, 0, m, &cDelay_rgpIIC9o_sendMessage);
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_WjBDwhFo, 1, m, NULL);
}

void Heavy_ChaffVerb::cDelay_fiNJNCEq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_fiNJNCEq, m);
  cMsg_Y50N5pde_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cSwitchcase_bqAYOPCF_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x47BE8354: { // "clear"
      cMsg_H22CIIh6_sendMessage(_c, 0, m);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_ChaffVerb::cBinop_GgbrtthD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_9bvFpxoC_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::hTable_A244hBPz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_IQZwZlv6_sendMessage(_c, 0, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_rgpIIC9o, 2, m, &cDelay_rgpIIC9o_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_9GD87Dva_sendMessage);
}

void Heavy_ChaffVerb::cMsg_9bvFpxoC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "resize");
  msg_setElementToFrom(m, 1, n, 0);
  hTable_onMessage(_c, &Context(_c)->hTable_A244hBPz, 0, m, &hTable_A244hBPz_sendMessage);
}

void Heavy_ChaffVerb::cBinop_DsNaO0VD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 25.796f, 0, m, &cBinop_GgbrtthD_sendMessage);
}

void Heavy_ChaffVerb::cMsg_Y50N5pde_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mirror");
  hTable_onMessage(_c, &Context(_c)->hTable_A244hBPz, 0, m, &hTable_A244hBPz_sendMessage);
}

void Heavy_ChaffVerb::cCast_9GD87Dva_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_rgpIIC9o, 0, m, &cDelay_rgpIIC9o_sendMessage);
}

void Heavy_ChaffVerb::cMsg_IQZwZlv6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cDelay_onMessage(_c, &Context(_c)->cDelay_fiNJNCEq, 2, m, &cDelay_fiNJNCEq_sendMessage);
}

void Heavy_ChaffVerb::cMsg_H22CIIh6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_WjBDwhFo, 1, m, NULL);
}

void Heavy_ChaffVerb::cTabhead_MtHrWXUm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_6u7bK4kB, HV_BINOP_SUBTRACT, 0, m, &cBinop_6u7bK4kB_sendMessage);
}

void Heavy_ChaffVerb::cMsg_HapOxkwp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_EPyr4fG9_sendMessage);
}

void Heavy_ChaffVerb::cSystem_EPyr4fG9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_LmJu4r0C_sendMessage);
}

void Heavy_ChaffVerb::cVar_vo0ItMgB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_8dTsAK3K_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cDelay_y2nn0Mj3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_y2nn0Mj3, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_zfA4a6RR, 0, m, &cDelay_zfA4a6RR_sendMessage);
  sTabread_onMessage(_c, &Context(_c)->sTabread_gssM6Xbp, 0, m, &sTabread_gssM6Xbp_sendMessage);
}

void Heavy_ChaffVerb::cDelay_zfA4a6RR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_zfA4a6RR, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_gssM6Xbp, 0, m, &sTabread_gssM6Xbp_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_zfA4a6RR, 0, m, &cDelay_zfA4a6RR_sendMessage);
}

void Heavy_ChaffVerb::sTabread_gssM6Xbp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_onMessage(_c, &Context(_c)->cBinop_5J6P3Yyt, HV_BINOP_SUBTRACT, 0, m, &cBinop_5J6P3Yyt_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_ChaffVerb::cBinop_PStHN48S_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_NEQoKrkL, HV_BINOP_MAX, 0, m, &cBinop_NEQoKrkL_sendMessage);
}

void Heavy_ChaffVerb::cBinop_LmJu4r0C_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_PStHN48S, HV_BINOP_MULTIPLY, 0, m, &cBinop_PStHN48S_sendMessage);
}

void Heavy_ChaffVerb::cBinop_6u7bK4kB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_0yBlWJ1t_sendMessage(_c, 0, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_gssM6Xbp, 0, m, &sTabread_gssM6Xbp_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_FoCecrBR_sendMessage);
}

void Heavy_ChaffVerb::cSystem_bhSEz0r7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_5J6P3Yyt, HV_BINOP_SUBTRACT, 1, m, &cBinop_5J6P3Yyt_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_zfA4a6RR, 2, m, &cDelay_zfA4a6RR_sendMessage);
}

void Heavy_ChaffVerb::cMsg_8dTsAK3K_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(3);
  msg_init(m, 3, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "table");
  msg_setElementToFrom(m, 1, n, 0);
  msg_setSymbol(m, 2, "size");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_bhSEz0r7_sendMessage);
}

void Heavy_ChaffVerb::cMsg_0yBlWJ1t_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_y2nn0Mj3, 0, m, &cDelay_y2nn0Mj3_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_zfA4a6RR, 0, m, &cDelay_zfA4a6RR_sendMessage);
}

void Heavy_ChaffVerb::cMsg_yvQht1tf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cBinop_onMessage(_c, &Context(_c)->cBinop_NEQoKrkL, HV_BINOP_MAX, 1, m, &cBinop_NEQoKrkL_sendMessage);
}

void Heavy_ChaffVerb::cBinop_NEQoKrkL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_6u7bK4kB, HV_BINOP_SUBTRACT, 1, m, &cBinop_6u7bK4kB_sendMessage);
}

void Heavy_ChaffVerb::cCast_FoCecrBR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_y2nn0Mj3, 0, m, &cDelay_y2nn0Mj3_sendMessage);
}

void Heavy_ChaffVerb::cBinop_FGFDpo0R_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_y2nn0Mj3, 2, m, &cDelay_y2nn0Mj3_sendMessage);
}

void Heavy_ChaffVerb::cBinop_5J6P3Yyt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_FGFDpo0R_sendMessage);
}

void Heavy_ChaffVerb::cCast_JqItHm3u_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_vo0ItMgB, 0, m, &cVar_vo0ItMgB_sendMessage);
  cMsg_HapOxkwp_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_MtHrWXUm, 0, m, &cTabhead_MtHrWXUm_sendMessage);
}

void Heavy_ChaffVerb::cMsg_ZXWLgNUv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_Yhve36PC_sendMessage);
}

void Heavy_ChaffVerb::cSystem_Yhve36PC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_AWCfKC6g_sendMessage);
}

void Heavy_ChaffVerb::cDelay_iypBPLuO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_iypBPLuO, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_n4NNm6dP, 0, m, &cDelay_n4NNm6dP_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_iypBPLuO, 0, m, &cDelay_iypBPLuO_sendMessage);
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_tE63Zqi9, 1, m, NULL);
}

void Heavy_ChaffVerb::cDelay_n4NNm6dP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_n4NNm6dP, m);
  cMsg_2rCI8hMs_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cSwitchcase_QfUuftq5_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x47BE8354: { // "clear"
      cMsg_KBp8R5nJ_sendMessage(_c, 0, m);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_ChaffVerb::cBinop_f9d1Od5e_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_B3E65ifP_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::hTable_5OulVBgr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_XZEyYkIE_sendMessage(_c, 0, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_iypBPLuO, 2, m, &cDelay_iypBPLuO_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_EQCkP0lp_sendMessage);
}

void Heavy_ChaffVerb::cMsg_B3E65ifP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "resize");
  msg_setElementToFrom(m, 1, n, 0);
  hTable_onMessage(_c, &Context(_c)->hTable_5OulVBgr, 0, m, &hTable_5OulVBgr_sendMessage);
}

void Heavy_ChaffVerb::cBinop_AWCfKC6g_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 19.392f, 0, m, &cBinop_f9d1Od5e_sendMessage);
}

void Heavy_ChaffVerb::cMsg_2rCI8hMs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mirror");
  hTable_onMessage(_c, &Context(_c)->hTable_5OulVBgr, 0, m, &hTable_5OulVBgr_sendMessage);
}

void Heavy_ChaffVerb::cCast_EQCkP0lp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_iypBPLuO, 0, m, &cDelay_iypBPLuO_sendMessage);
}

void Heavy_ChaffVerb::cMsg_XZEyYkIE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cDelay_onMessage(_c, &Context(_c)->cDelay_n4NNm6dP, 2, m, &cDelay_n4NNm6dP_sendMessage);
}

void Heavy_ChaffVerb::cMsg_KBp8R5nJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_tE63Zqi9, 1, m, NULL);
}

void Heavy_ChaffVerb::cTabhead_Bf5vLuO2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_fJptWI1S, HV_BINOP_SUBTRACT, 0, m, &cBinop_fJptWI1S_sendMessage);
}

void Heavy_ChaffVerb::cMsg_01JXROjJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_9HILazzx_sendMessage);
}

void Heavy_ChaffVerb::cSystem_9HILazzx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_VtJxyi8r_sendMessage);
}

void Heavy_ChaffVerb::cVar_QrDb74mu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_gCCOtrwk_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cDelay_K8Vs0wJf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_K8Vs0wJf, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_kVosGtY4, 0, m, &cDelay_kVosGtY4_sendMessage);
  sTabread_onMessage(_c, &Context(_c)->sTabread_v8gCgSiv, 0, m, &sTabread_v8gCgSiv_sendMessage);
}

void Heavy_ChaffVerb::cDelay_kVosGtY4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_kVosGtY4, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_v8gCgSiv, 0, m, &sTabread_v8gCgSiv_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_kVosGtY4, 0, m, &cDelay_kVosGtY4_sendMessage);
}

void Heavy_ChaffVerb::sTabread_v8gCgSiv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_onMessage(_c, &Context(_c)->cBinop_2wWiTxt8, HV_BINOP_SUBTRACT, 0, m, &cBinop_2wWiTxt8_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_ChaffVerb::cBinop_0EwkmSEz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_OT8AoKAs, HV_BINOP_MAX, 0, m, &cBinop_OT8AoKAs_sendMessage);
}

void Heavy_ChaffVerb::cBinop_VtJxyi8r_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_0EwkmSEz, HV_BINOP_MULTIPLY, 0, m, &cBinop_0EwkmSEz_sendMessage);
}

void Heavy_ChaffVerb::cBinop_fJptWI1S_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_rD4UGjU6_sendMessage(_c, 0, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_v8gCgSiv, 0, m, &sTabread_v8gCgSiv_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_tClkyjUI_sendMessage);
}

void Heavy_ChaffVerb::cSystem_AslDTVux_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_2wWiTxt8, HV_BINOP_SUBTRACT, 1, m, &cBinop_2wWiTxt8_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_kVosGtY4, 2, m, &cDelay_kVosGtY4_sendMessage);
}

void Heavy_ChaffVerb::cMsg_gCCOtrwk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(3);
  msg_init(m, 3, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "table");
  msg_setElementToFrom(m, 1, n, 0);
  msg_setSymbol(m, 2, "size");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_AslDTVux_sendMessage);
}

void Heavy_ChaffVerb::cMsg_rD4UGjU6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_K8Vs0wJf, 0, m, &cDelay_K8Vs0wJf_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_kVosGtY4, 0, m, &cDelay_kVosGtY4_sendMessage);
}

void Heavy_ChaffVerb::cMsg_KAC4ltPi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cBinop_onMessage(_c, &Context(_c)->cBinop_OT8AoKAs, HV_BINOP_MAX, 1, m, &cBinop_OT8AoKAs_sendMessage);
}

void Heavy_ChaffVerb::cBinop_OT8AoKAs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_fJptWI1S, HV_BINOP_SUBTRACT, 1, m, &cBinop_fJptWI1S_sendMessage);
}

void Heavy_ChaffVerb::cCast_tClkyjUI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_K8Vs0wJf, 0, m, &cDelay_K8Vs0wJf_sendMessage);
}

void Heavy_ChaffVerb::cBinop_Uvs25FpE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_K8Vs0wJf, 2, m, &cDelay_K8Vs0wJf_sendMessage);
}

void Heavy_ChaffVerb::cBinop_2wWiTxt8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_Uvs25FpE_sendMessage);
}

void Heavy_ChaffVerb::cCast_CoziC7wg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_QrDb74mu, 0, m, &cVar_QrDb74mu_sendMessage);
  cMsg_01JXROjJ_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_Bf5vLuO2, 0, m, &cTabhead_Bf5vLuO2_sendMessage);
}

void Heavy_ChaffVerb::cMsg_kgMVc8YN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_DJ8tfQKR_sendMessage);
}

void Heavy_ChaffVerb::cSystem_DJ8tfQKR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_LXfxwPyS_sendMessage);
}

void Heavy_ChaffVerb::cDelay_7Cm1ar95_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_7Cm1ar95, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_Xkz3sWye, 0, m, &cDelay_Xkz3sWye_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_7Cm1ar95, 0, m, &cDelay_7Cm1ar95_sendMessage);
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_pNsH1xbf, 1, m, NULL);
}

void Heavy_ChaffVerb::cDelay_Xkz3sWye_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_Xkz3sWye, m);
  cMsg_XyrS2IiM_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cSwitchcase_gYJu3FsG_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x47BE8354: { // "clear"
      cMsg_RAMpU478_sendMessage(_c, 0, m);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_ChaffVerb::cBinop_kpJNBvRv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_YovCtGzB_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::hTable_e8Zi7Pf6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_EApGLeHe_sendMessage(_c, 0, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_7Cm1ar95, 2, m, &cDelay_7Cm1ar95_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_Lah1jXZk_sendMessage);
}

void Heavy_ChaffVerb::cMsg_YovCtGzB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "resize");
  msg_setElementToFrom(m, 1, n, 0);
  hTable_onMessage(_c, &Context(_c)->hTable_e8Zi7Pf6, 0, m, &hTable_e8Zi7Pf6_sendMessage);
}

void Heavy_ChaffVerb::cBinop_LXfxwPyS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 16.364f, 0, m, &cBinop_kpJNBvRv_sendMessage);
}

void Heavy_ChaffVerb::cMsg_XyrS2IiM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mirror");
  hTable_onMessage(_c, &Context(_c)->hTable_e8Zi7Pf6, 0, m, &hTable_e8Zi7Pf6_sendMessage);
}

void Heavy_ChaffVerb::cCast_Lah1jXZk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_7Cm1ar95, 0, m, &cDelay_7Cm1ar95_sendMessage);
}

void Heavy_ChaffVerb::cMsg_EApGLeHe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cDelay_onMessage(_c, &Context(_c)->cDelay_Xkz3sWye, 2, m, &cDelay_Xkz3sWye_sendMessage);
}

void Heavy_ChaffVerb::cMsg_RAMpU478_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_pNsH1xbf, 1, m, NULL);
}

void Heavy_ChaffVerb::cTabhead_yOkCpBwB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_aUWyUbZo, HV_BINOP_SUBTRACT, 0, m, &cBinop_aUWyUbZo_sendMessage);
}

void Heavy_ChaffVerb::cMsg_DDd1dlqu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_uN1AWtmT_sendMessage);
}

void Heavy_ChaffVerb::cSystem_uN1AWtmT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_S9K7wzu2_sendMessage);
}

void Heavy_ChaffVerb::cVar_t9necXUl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_GWdR1aW2_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cDelay_my2S714P_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_my2S714P, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_Fzhj7ZOI, 0, m, &cDelay_Fzhj7ZOI_sendMessage);
  sTabread_onMessage(_c, &Context(_c)->sTabread_ZVwjGSWx, 0, m, &sTabread_ZVwjGSWx_sendMessage);
}

void Heavy_ChaffVerb::cDelay_Fzhj7ZOI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_Fzhj7ZOI, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_ZVwjGSWx, 0, m, &sTabread_ZVwjGSWx_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_Fzhj7ZOI, 0, m, &cDelay_Fzhj7ZOI_sendMessage);
}

void Heavy_ChaffVerb::sTabread_ZVwjGSWx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_onMessage(_c, &Context(_c)->cBinop_gNffPjtz, HV_BINOP_SUBTRACT, 0, m, &cBinop_gNffPjtz_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_ChaffVerb::cBinop_KrNtIfvt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_X4q3LnIe, HV_BINOP_MAX, 0, m, &cBinop_X4q3LnIe_sendMessage);
}

void Heavy_ChaffVerb::cBinop_S9K7wzu2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_KrNtIfvt, HV_BINOP_MULTIPLY, 0, m, &cBinop_KrNtIfvt_sendMessage);
}

void Heavy_ChaffVerb::cBinop_aUWyUbZo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Dp85eN7j_sendMessage(_c, 0, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_ZVwjGSWx, 0, m, &sTabread_ZVwjGSWx_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_37znPZgs_sendMessage);
}

void Heavy_ChaffVerb::cSystem_YjO3tmU3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_gNffPjtz, HV_BINOP_SUBTRACT, 1, m, &cBinop_gNffPjtz_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_Fzhj7ZOI, 2, m, &cDelay_Fzhj7ZOI_sendMessage);
}

void Heavy_ChaffVerb::cMsg_GWdR1aW2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(3);
  msg_init(m, 3, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "table");
  msg_setElementToFrom(m, 1, n, 0);
  msg_setSymbol(m, 2, "size");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_YjO3tmU3_sendMessage);
}

void Heavy_ChaffVerb::cMsg_Dp85eN7j_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_my2S714P, 0, m, &cDelay_my2S714P_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_Fzhj7ZOI, 0, m, &cDelay_Fzhj7ZOI_sendMessage);
}

void Heavy_ChaffVerb::cMsg_Q21h6JmA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cBinop_onMessage(_c, &Context(_c)->cBinop_X4q3LnIe, HV_BINOP_MAX, 1, m, &cBinop_X4q3LnIe_sendMessage);
}

void Heavy_ChaffVerb::cBinop_X4q3LnIe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_aUWyUbZo, HV_BINOP_SUBTRACT, 1, m, &cBinop_aUWyUbZo_sendMessage);
}

void Heavy_ChaffVerb::cCast_37znPZgs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_my2S714P, 0, m, &cDelay_my2S714P_sendMessage);
}

void Heavy_ChaffVerb::cBinop_QqBVM2vX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_my2S714P, 2, m, &cDelay_my2S714P_sendMessage);
}

void Heavy_ChaffVerb::cBinop_gNffPjtz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_QqBVM2vX_sendMessage);
}

void Heavy_ChaffVerb::cCast_pfYZ3S2a_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_t9necXUl, 0, m, &cVar_t9necXUl_sendMessage);
  cMsg_DDd1dlqu_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_yOkCpBwB, 0, m, &cTabhead_yOkCpBwB_sendMessage);
}

void Heavy_ChaffVerb::cMsg_YTsoLAqd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_WFoQLeiY_sendMessage);
}

void Heavy_ChaffVerb::cSystem_WFoQLeiY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_Y1mjW6NA_sendMessage);
}

void Heavy_ChaffVerb::cDelay_DpvaXwoc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_DpvaXwoc, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_bQNsFYwR, 0, m, &cDelay_bQNsFYwR_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_DpvaXwoc, 0, m, &cDelay_DpvaXwoc_sendMessage);
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_xAbXIcpY, 1, m, NULL);
}

void Heavy_ChaffVerb::cDelay_bQNsFYwR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_bQNsFYwR, m);
  cMsg_3noBNWEF_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cSwitchcase_q8f2EL2V_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x47BE8354: { // "clear"
      cMsg_CTcXMX3B_sendMessage(_c, 0, m);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_ChaffVerb::cBinop_AgF5Nunx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_JTCm1OuA_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::hTable_0cmOncnb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_VIDemjHa_sendMessage(_c, 0, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_DpvaXwoc, 2, m, &cDelay_DpvaXwoc_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_t661bjwH_sendMessage);
}

void Heavy_ChaffVerb::cMsg_JTCm1OuA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "resize");
  msg_setElementToFrom(m, 1, n, 0);
  hTable_onMessage(_c, &Context(_c)->hTable_0cmOncnb, 0, m, &hTable_0cmOncnb_sendMessage);
}

void Heavy_ChaffVerb::cBinop_Y1mjW6NA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 4.2546f, 0, m, &cBinop_AgF5Nunx_sendMessage);
}

void Heavy_ChaffVerb::cMsg_3noBNWEF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mirror");
  hTable_onMessage(_c, &Context(_c)->hTable_0cmOncnb, 0, m, &hTable_0cmOncnb_sendMessage);
}

void Heavy_ChaffVerb::cCast_t661bjwH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_DpvaXwoc, 0, m, &cDelay_DpvaXwoc_sendMessage);
}

void Heavy_ChaffVerb::cMsg_VIDemjHa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cDelay_onMessage(_c, &Context(_c)->cDelay_bQNsFYwR, 2, m, &cDelay_bQNsFYwR_sendMessage);
}

void Heavy_ChaffVerb::cMsg_CTcXMX3B_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_xAbXIcpY, 1, m, NULL);
}

void Heavy_ChaffVerb::cTabhead_cOmUfBdC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_gzuK59tM, HV_BINOP_SUBTRACT, 0, m, &cBinop_gzuK59tM_sendMessage);
}

void Heavy_ChaffVerb::cMsg_8TUPkLkk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_R8qq16HC_sendMessage);
}

void Heavy_ChaffVerb::cSystem_R8qq16HC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_IVQuUBBp_sendMessage);
}

void Heavy_ChaffVerb::cVar_DFJ56Zu6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_rDwbPRBk_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cDelay_23V8iOrc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_23V8iOrc, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_no5yuAjf, 0, m, &cDelay_no5yuAjf_sendMessage);
  sTabread_onMessage(_c, &Context(_c)->sTabread_TFCHpICr, 0, m, &sTabread_TFCHpICr_sendMessage);
}

void Heavy_ChaffVerb::cDelay_no5yuAjf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_no5yuAjf, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_TFCHpICr, 0, m, &sTabread_TFCHpICr_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_no5yuAjf, 0, m, &cDelay_no5yuAjf_sendMessage);
}

void Heavy_ChaffVerb::sTabread_TFCHpICr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_onMessage(_c, &Context(_c)->cBinop_JUP0nQUK, HV_BINOP_SUBTRACT, 0, m, &cBinop_JUP0nQUK_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_ChaffVerb::cBinop_JyKTYS8e_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_MHlkycL7, HV_BINOP_MAX, 0, m, &cBinop_MHlkycL7_sendMessage);
}

void Heavy_ChaffVerb::cBinop_IVQuUBBp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_JyKTYS8e, HV_BINOP_MULTIPLY, 0, m, &cBinop_JyKTYS8e_sendMessage);
}

void Heavy_ChaffVerb::cBinop_gzuK59tM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_w46LlxmX_sendMessage(_c, 0, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_TFCHpICr, 0, m, &sTabread_TFCHpICr_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_ae9hnlAs_sendMessage);
}

void Heavy_ChaffVerb::cSystem_fFpDUKp1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_JUP0nQUK, HV_BINOP_SUBTRACT, 1, m, &cBinop_JUP0nQUK_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_no5yuAjf, 2, m, &cDelay_no5yuAjf_sendMessage);
}

void Heavy_ChaffVerb::cMsg_rDwbPRBk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(3);
  msg_init(m, 3, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "table");
  msg_setElementToFrom(m, 1, n, 0);
  msg_setSymbol(m, 2, "size");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_fFpDUKp1_sendMessage);
}

void Heavy_ChaffVerb::cMsg_w46LlxmX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_23V8iOrc, 0, m, &cDelay_23V8iOrc_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_no5yuAjf, 0, m, &cDelay_no5yuAjf_sendMessage);
}

void Heavy_ChaffVerb::cMsg_ZGK52a5t_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cBinop_onMessage(_c, &Context(_c)->cBinop_MHlkycL7, HV_BINOP_MAX, 1, m, &cBinop_MHlkycL7_sendMessage);
}

void Heavy_ChaffVerb::cBinop_MHlkycL7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_gzuK59tM, HV_BINOP_SUBTRACT, 1, m, &cBinop_gzuK59tM_sendMessage);
}

void Heavy_ChaffVerb::cCast_ae9hnlAs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_23V8iOrc, 0, m, &cDelay_23V8iOrc_sendMessage);
}

void Heavy_ChaffVerb::cBinop_HGJ8gotB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_23V8iOrc, 2, m, &cDelay_23V8iOrc_sendMessage);
}

void Heavy_ChaffVerb::cBinop_JUP0nQUK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_HGJ8gotB_sendMessage);
}

void Heavy_ChaffVerb::cCast_BmaVUM2B_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_DFJ56Zu6, 0, m, &cVar_DFJ56Zu6_sendMessage);
  cMsg_8TUPkLkk_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_cOmUfBdC, 0, m, &cTabhead_cOmUfBdC_sendMessage);
}

void Heavy_ChaffVerb::cMsg_FXDNwlmu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_oig5zwQD_sendMessage);
}

void Heavy_ChaffVerb::cSystem_oig5zwQD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_yMW2AOfQ_sendMessage);
}

void Heavy_ChaffVerb::cDelay_D8eNURnR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_D8eNURnR, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_pDhpiC5s, 0, m, &cDelay_pDhpiC5s_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_D8eNURnR, 0, m, &cDelay_D8eNURnR_sendMessage);
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_sDmtIoVv, 1, m, NULL);
}

void Heavy_ChaffVerb::cDelay_pDhpiC5s_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_pDhpiC5s, m);
  cMsg_pQFuUVoo_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cSwitchcase_8Azqv0M2_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x47BE8354: { // "clear"
      cMsg_84O7eLQU_sendMessage(_c, 0, m);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_ChaffVerb::cBinop_mm584gCn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_fAYtOtdy_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::hTable_rTItxtkE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_y0nyJfw4_sendMessage(_c, 0, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_D8eNURnR, 2, m, &cDelay_D8eNURnR_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_eiDW3vmV_sendMessage);
}

void Heavy_ChaffVerb::cMsg_fAYtOtdy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "resize");
  msg_setElementToFrom(m, 1, n, 0);
  hTable_onMessage(_c, &Context(_c)->hTable_rTItxtkE, 0, m, &hTable_rTItxtkE_sendMessage);
}

void Heavy_ChaffVerb::cBinop_yMW2AOfQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 7.645f, 0, m, &cBinop_mm584gCn_sendMessage);
}

void Heavy_ChaffVerb::cMsg_pQFuUVoo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mirror");
  hTable_onMessage(_c, &Context(_c)->hTable_rTItxtkE, 0, m, &hTable_rTItxtkE_sendMessage);
}

void Heavy_ChaffVerb::cCast_eiDW3vmV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_D8eNURnR, 0, m, &cDelay_D8eNURnR_sendMessage);
}

void Heavy_ChaffVerb::cMsg_y0nyJfw4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cDelay_onMessage(_c, &Context(_c)->cDelay_pDhpiC5s, 2, m, &cDelay_pDhpiC5s_sendMessage);
}

void Heavy_ChaffVerb::cMsg_84O7eLQU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_sDmtIoVv, 1, m, NULL);
}

void Heavy_ChaffVerb::cTabhead_FH5Gvk0k_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_KKX9lSn6, HV_BINOP_SUBTRACT, 0, m, &cBinop_KKX9lSn6_sendMessage);
}

void Heavy_ChaffVerb::cMsg_hTOqHfVJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_FZcciHkH_sendMessage);
}

void Heavy_ChaffVerb::cSystem_FZcciHkH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_dgbylb5J_sendMessage);
}

void Heavy_ChaffVerb::cVar_94vzqeN3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_tgBiG7hp_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cDelay_td8lCfjZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_td8lCfjZ, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_pke6KglM, 0, m, &cDelay_pke6KglM_sendMessage);
  sTabread_onMessage(_c, &Context(_c)->sTabread_pYhq9TgO, 0, m, &sTabread_pYhq9TgO_sendMessage);
}

void Heavy_ChaffVerb::cDelay_pke6KglM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_pke6KglM, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_pYhq9TgO, 0, m, &sTabread_pYhq9TgO_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_pke6KglM, 0, m, &cDelay_pke6KglM_sendMessage);
}

void Heavy_ChaffVerb::sTabread_pYhq9TgO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_onMessage(_c, &Context(_c)->cBinop_jWT5rigJ, HV_BINOP_SUBTRACT, 0, m, &cBinop_jWT5rigJ_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_ChaffVerb::cBinop_GJreoSMn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_1EuTNfZM, HV_BINOP_MAX, 0, m, &cBinop_1EuTNfZM_sendMessage);
}

void Heavy_ChaffVerb::cBinop_dgbylb5J_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_GJreoSMn, HV_BINOP_MULTIPLY, 0, m, &cBinop_GJreoSMn_sendMessage);
}

void Heavy_ChaffVerb::cBinop_KKX9lSn6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_B70cxg5c_sendMessage(_c, 0, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_pYhq9TgO, 0, m, &sTabread_pYhq9TgO_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_zGDaO83X_sendMessage);
}

void Heavy_ChaffVerb::cSystem_1bHF6n6l_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_jWT5rigJ, HV_BINOP_SUBTRACT, 1, m, &cBinop_jWT5rigJ_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_pke6KglM, 2, m, &cDelay_pke6KglM_sendMessage);
}

void Heavy_ChaffVerb::cMsg_tgBiG7hp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(3);
  msg_init(m, 3, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "table");
  msg_setElementToFrom(m, 1, n, 0);
  msg_setSymbol(m, 2, "size");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_1bHF6n6l_sendMessage);
}

void Heavy_ChaffVerb::cMsg_B70cxg5c_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_td8lCfjZ, 0, m, &cDelay_td8lCfjZ_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_pke6KglM, 0, m, &cDelay_pke6KglM_sendMessage);
}

void Heavy_ChaffVerb::cMsg_1i077q1J_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cBinop_onMessage(_c, &Context(_c)->cBinop_1EuTNfZM, HV_BINOP_MAX, 1, m, &cBinop_1EuTNfZM_sendMessage);
}

void Heavy_ChaffVerb::cBinop_1EuTNfZM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_KKX9lSn6, HV_BINOP_SUBTRACT, 1, m, &cBinop_KKX9lSn6_sendMessage);
}

void Heavy_ChaffVerb::cCast_zGDaO83X_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_td8lCfjZ, 0, m, &cDelay_td8lCfjZ_sendMessage);
}

void Heavy_ChaffVerb::cBinop_v8suJI8y_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_td8lCfjZ, 2, m, &cDelay_td8lCfjZ_sendMessage);
}

void Heavy_ChaffVerb::cBinop_jWT5rigJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_v8suJI8y_sendMessage);
}

void Heavy_ChaffVerb::cCast_WVoKvUxv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_94vzqeN3, 0, m, &cVar_94vzqeN3_sendMessage);
  cMsg_hTOqHfVJ_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_FH5Gvk0k, 0, m, &cTabhead_FH5Gvk0k_sendMessage);
}

void Heavy_ChaffVerb::cVar_TGzMkoH6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_jGto9i39, 0, m, &cVar_jGto9i39_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_DQO2LvfY, 0, m, &cVar_DQO2LvfY_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_I5gaO0tC, 0, m, &cVar_I5gaO0tC_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_KRCt0WBa, 0, m, &cVar_KRCt0WBa_sendMessage);
}

void Heavy_ChaffVerb::cVar_qSSYcbjm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.01f, 0, m, &cBinop_26E2dheE_sendMessage);
}

void Heavy_ChaffVerb::cPack_RRU1jAF3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sLine_onMessage(_c, &Context(_c)->sLine_v8sA6rWG, 0, m, NULL);
}

void Heavy_ChaffVerb::cVar_DQO2LvfY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_T2HGY8sq, HV_BINOP_MULTIPLY, 0, m, &cBinop_T2HGY8sq_sendMessage);
}

void Heavy_ChaffVerb::cMsg_6rVWRQZl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_rrP01qTB_sendMessage);
}

void Heavy_ChaffVerb::cSystem_rrP01qTB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Tw4hedzd_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cBinop_T2HGY8sq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_cyUtsLVy_sendMessage);
}

void Heavy_ChaffVerb::cBinop_tFdXg6Wz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_T2HGY8sq, HV_BINOP_MULTIPLY, 1, m, &cBinop_T2HGY8sq_sendMessage);
}

void Heavy_ChaffVerb::cMsg_Tw4hedzd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 6.28319f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_tFdXg6Wz_sendMessage);
}

void Heavy_ChaffVerb::cBinop_cyUtsLVy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_Vxfa1dSl_sendMessage);
}

void Heavy_ChaffVerb::cBinop_Vxfa1dSl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_vIFiiZy2_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_dHhr6ESU, m);
}

void Heavy_ChaffVerb::cBinop_vIFiiZy2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_pteFS2PQ, m);
}

void Heavy_ChaffVerb::cVar_I5gaO0tC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_1H5j2EIH, HV_BINOP_MULTIPLY, 0, m, &cBinop_1H5j2EIH_sendMessage);
}

void Heavy_ChaffVerb::cMsg_DevgMWxx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_CFeYEX3O_sendMessage);
}

void Heavy_ChaffVerb::cSystem_CFeYEX3O_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_iyQ4JI3b_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cBinop_1H5j2EIH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_QoHyU8By_sendMessage);
}

void Heavy_ChaffVerb::cBinop_GugZM4e1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_1H5j2EIH, HV_BINOP_MULTIPLY, 1, m, &cBinop_1H5j2EIH_sendMessage);
}

void Heavy_ChaffVerb::cMsg_iyQ4JI3b_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 6.28319f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_GugZM4e1_sendMessage);
}

void Heavy_ChaffVerb::cBinop_QoHyU8By_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_Vuv6CKDm_sendMessage);
}

void Heavy_ChaffVerb::cBinop_Vuv6CKDm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_ZIiG2u8D_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_YmoKf5nx, m);
}

void Heavy_ChaffVerb::cBinop_ZIiG2u8D_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_tTcxmJiT, m);
}

void Heavy_ChaffVerb::cVar_KRCt0WBa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_KmUHnfLf, HV_BINOP_MULTIPLY, 0, m, &cBinop_KmUHnfLf_sendMessage);
}

void Heavy_ChaffVerb::cMsg_AiAnWgne_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_RB5LB5vo_sendMessage);
}

void Heavy_ChaffVerb::cSystem_RB5LB5vo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Jf3VMLAe_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cBinop_KmUHnfLf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_YtyGQkaW_sendMessage);
}

void Heavy_ChaffVerb::cBinop_qUduBKAu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_KmUHnfLf, HV_BINOP_MULTIPLY, 1, m, &cBinop_KmUHnfLf_sendMessage);
}

void Heavy_ChaffVerb::cMsg_Jf3VMLAe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 6.28319f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_qUduBKAu_sendMessage);
}

void Heavy_ChaffVerb::cBinop_YtyGQkaW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_bp77vhaj_sendMessage);
}

void Heavy_ChaffVerb::cBinop_bp77vhaj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_XvhezXue_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_qiuzN5la, m);
}

void Heavy_ChaffVerb::cBinop_XvhezXue_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_A7gWX3An, m);
}

void Heavy_ChaffVerb::cBinop_7LBiOp3M_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cPack_onMessage(_c, &Context(_c)->cPack_RjH0cWG9, 0, m, &cPack_RjH0cWG9_sendMessage);
}

void Heavy_ChaffVerb::cMsg_Ru8iaJgG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 3000.0f);
  cVar_onMessage(_c, &Context(_c)->cVar_TGzMkoH6, 0, m, &cVar_TGzMkoH6_sendMessage);
}

void Heavy_ChaffVerb::cBinop_26E2dheE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cPack_onMessage(_c, &Context(_c)->cPack_RRU1jAF3, 0, m, &cPack_RRU1jAF3_sendMessage);
}

void Heavy_ChaffVerb::cBinop_JzTiV4RG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cPack_onMessage(_c, &Context(_c)->cPack_Feo0fVsu, 0, m, &cPack_Feo0fVsu_sendMessage);
}

void Heavy_ChaffVerb::cSwitchcase_ImglQkga_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x0: { // "0.0"
      cMsg_uZXXAIYx_sendMessage(_c, 0, m);
      break;
    }
    case 0x7A5B032D: { // "stop"
      cMsg_uZXXAIYx_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_ym3Suejl_sendMessage);
      break;
    }
  }
}

void Heavy_ChaffVerb::cDelay_iFVceLaD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_iFVceLaD, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_iFVceLaD, 0, m, &cDelay_iFVceLaD_sendMessage);
  cSwitchcase_KO2biodD_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_ChaffVerb::cCast_ym3Suejl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_uZXXAIYx_sendMessage(_c, 0, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_iFVceLaD, 0, m, &cDelay_iFVceLaD_sendMessage);
  cSwitchcase_KO2biodD_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_ChaffVerb::cMsg_cNbjylTe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_4nN2Ctge_sendMessage);
}

void Heavy_ChaffVerb::cSystem_4nN2Ctge_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_Nbi1VT6O_sendMessage);
}

void Heavy_ChaffVerb::cVar_JHWFBLAA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_NstkuakS, HV_BINOP_MULTIPLY, 0, m, &cBinop_NstkuakS_sendMessage);
}

void Heavy_ChaffVerb::cMsg_uZXXAIYx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_iFVceLaD, 0, m, &cDelay_iFVceLaD_sendMessage);
}

void Heavy_ChaffVerb::cBinop_5XYWwCJS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_iFVceLaD, 2, m, &cDelay_iFVceLaD_sendMessage);
}

void Heavy_ChaffVerb::cBinop_Nbi1VT6O_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_NstkuakS, HV_BINOP_MULTIPLY, 1, m, &cBinop_NstkuakS_sendMessage);
}

void Heavy_ChaffVerb::cBinop_NstkuakS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 1.0f, 0, m, &cBinop_5XYWwCJS_sendMessage);
}

void Heavy_ChaffVerb::cVar_OuBkSOsn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MOD_UNIPOLAR, 628.0f, 0, m, &cBinop_Y3gykJRK_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 2.0f, 0, m, &cBinop_DQIaGrMG_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 100.0f, 0, m, &cBinop_8zCgvJkM_sendMessage);
}

void Heavy_ChaffVerb::cVar_cXWBY3z9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_0IShaIPC_sendMessage);
  cIf_onMessage(_c, &Context(_c)->cIf_MKXPThwJ, 0, m, &cIf_MKXPThwJ_sendMessage);
}

void Heavy_ChaffVerb::cUnop_UOOoXqVU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_fchnKVOE, HV_BINOP_MOD_UNIPOLAR, 1, m, &cBinop_fchnKVOE_sendMessage);
}

void Heavy_ChaffVerb::cUnop_0ZiSBKNV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_fchnKVOE, HV_BINOP_MOD_UNIPOLAR, 1, m, &cBinop_fchnKVOE_sendMessage);
}

void Heavy_ChaffVerb::cIf_MKXPThwJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cUnop_onMessage(_c, HV_UNOP_CEIL, m, &cUnop_0ZiSBKNV_sendMessage);
      break;
    }
    case 1: {
      cUnop_onMessage(_c, HV_UNOP_FLOOR, m, &cUnop_UOOoXqVU_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_ChaffVerb::cBinop_0IShaIPC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_MKXPThwJ, 1, m, &cIf_MKXPThwJ_sendMessage);
}

void Heavy_ChaffVerb::cMsg_pgfhv5Ee_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_jMgRbzff_sendMessage);
}

void Heavy_ChaffVerb::cSystem_jMgRbzff_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_L0Yj6o9G_sendMessage);
}

void Heavy_ChaffVerb::cDelay_5TmdQh2y_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_5TmdQh2y, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_5vudOYti, 0, m, &cDelay_5vudOYti_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_5TmdQh2y, 0, m, &cDelay_5TmdQh2y_sendMessage);
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_SXsn9obO, 1, m, NULL);
}

void Heavy_ChaffVerb::cDelay_5vudOYti_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_5vudOYti, m);
  cMsg_5cgpHbvL_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cSwitchcase_PK2e5FCs_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x47BE8354: { // "clear"
      cMsg_pgvqxetJ_sendMessage(_c, 0, m);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_ChaffVerb::cBinop_cywfDSqm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_PPLV3ke1_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::hTable_oXYCtuD5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_mQIG75Be_sendMessage(_c, 0, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_5TmdQh2y, 2, m, &cDelay_5TmdQh2y_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_ycjB3HwL_sendMessage);
}

void Heavy_ChaffVerb::cMsg_PPLV3ke1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "resize");
  msg_setElementToFrom(m, 1, n, 0);
  hTable_onMessage(_c, &Context(_c)->hTable_oXYCtuD5, 0, m, &hTable_oXYCtuD5_sendMessage);
}

void Heavy_ChaffVerb::cBinop_L0Yj6o9G_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 3000.0f, 0, m, &cBinop_cywfDSqm_sendMessage);
}

void Heavy_ChaffVerb::cMsg_5cgpHbvL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mirror");
  hTable_onMessage(_c, &Context(_c)->hTable_oXYCtuD5, 0, m, &hTable_oXYCtuD5_sendMessage);
}

void Heavy_ChaffVerb::cCast_ycjB3HwL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_5TmdQh2y, 0, m, &cDelay_5TmdQh2y_sendMessage);
}

void Heavy_ChaffVerb::cMsg_mQIG75Be_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cDelay_onMessage(_c, &Context(_c)->cDelay_5vudOYti, 2, m, &cDelay_5vudOYti_sendMessage);
}

void Heavy_ChaffVerb::cMsg_pgvqxetJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_SXsn9obO, 1, m, NULL);
}

void Heavy_ChaffVerb::cTabhead_WKn3hzaV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_gqaUsNxb, HV_BINOP_SUBTRACT, 0, m, &cBinop_gqaUsNxb_sendMessage);
}

void Heavy_ChaffVerb::cMsg_NiTP1fJl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_GxapFaNh_sendMessage);
}

void Heavy_ChaffVerb::cSystem_GxapFaNh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_8gnUypQZ_sendMessage);
}

void Heavy_ChaffVerb::cVar_abx5UgOt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_wL1NDUXC_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cDelay_4ideaiAI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_4ideaiAI, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_VmNNfjvg, 0, m, &cDelay_VmNNfjvg_sendMessage);
  sTabread_onMessage(_c, &Context(_c)->sTabread_MBpVdwiF, 0, m, &sTabread_MBpVdwiF_sendMessage);
}

void Heavy_ChaffVerb::cDelay_VmNNfjvg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_VmNNfjvg, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_MBpVdwiF, 0, m, &sTabread_MBpVdwiF_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_VmNNfjvg, 0, m, &cDelay_VmNNfjvg_sendMessage);
}

void Heavy_ChaffVerb::sTabread_MBpVdwiF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_onMessage(_c, &Context(_c)->cBinop_4vgvX2Dg, HV_BINOP_SUBTRACT, 0, m, &cBinop_4vgvX2Dg_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_ChaffVerb::cBinop_OipbTnGn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_HgRsJ0CK, HV_BINOP_MAX, 0, m, &cBinop_HgRsJ0CK_sendMessage);
}

void Heavy_ChaffVerb::cBinop_8gnUypQZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_OipbTnGn, HV_BINOP_MULTIPLY, 0, m, &cBinop_OipbTnGn_sendMessage);
}

void Heavy_ChaffVerb::cBinop_gqaUsNxb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_KXlUWkCu_sendMessage(_c, 0, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_MBpVdwiF, 0, m, &sTabread_MBpVdwiF_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_kaGULr3R_sendMessage);
}

void Heavy_ChaffVerb::cSystem_ZVzoKqHe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_4vgvX2Dg, HV_BINOP_SUBTRACT, 1, m, &cBinop_4vgvX2Dg_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_VmNNfjvg, 2, m, &cDelay_VmNNfjvg_sendMessage);
}

void Heavy_ChaffVerb::cMsg_wL1NDUXC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(3);
  msg_init(m, 3, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "table");
  msg_setElementToFrom(m, 1, n, 0);
  msg_setSymbol(m, 2, "size");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_ZVzoKqHe_sendMessage);
}

void Heavy_ChaffVerb::cMsg_KXlUWkCu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_4ideaiAI, 0, m, &cDelay_4ideaiAI_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_VmNNfjvg, 0, m, &cDelay_VmNNfjvg_sendMessage);
}

void Heavy_ChaffVerb::cMsg_ZFvvdrqI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cBinop_onMessage(_c, &Context(_c)->cBinop_HgRsJ0CK, HV_BINOP_MAX, 1, m, &cBinop_HgRsJ0CK_sendMessage);
}

void Heavy_ChaffVerb::cBinop_HgRsJ0CK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_gqaUsNxb, HV_BINOP_SUBTRACT, 1, m, &cBinop_gqaUsNxb_sendMessage);
}

void Heavy_ChaffVerb::cCast_kaGULr3R_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_4ideaiAI, 0, m, &cDelay_4ideaiAI_sendMessage);
}

void Heavy_ChaffVerb::cBinop_L1p15rV2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_4ideaiAI, 2, m, &cDelay_4ideaiAI_sendMessage);
}

void Heavy_ChaffVerb::cBinop_4vgvX2Dg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_L1p15rV2_sendMessage);
}

void Heavy_ChaffVerb::cCast_NRRgyJSI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_abx5UgOt, 0, m, &cVar_abx5UgOt_sendMessage);
  cMsg_NiTP1fJl_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_WKn3hzaV, 0, m, &cTabhead_WKn3hzaV_sendMessage);
}

void Heavy_ChaffVerb::cSwitchcase_tRepiiKO_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x0: { // "0.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_RuPkr1oT_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_ChaffVerb::cCast_RuPkr1oT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_S1cvVh5B_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cVar_RayvicSX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Q5PW5Apn, HV_BINOP_ADD, 0, m, &cBinop_Q5PW5Apn_sendMessage);
}

void Heavy_ChaffVerb::cSwitchcase_D0PC9qMs_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x0: { // "0.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_Vo5xFsfJ_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_ChaffVerb::cCast_Vo5xFsfJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_lB9xPzai_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cVar_VMcLwNaV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_K3g6VAIF_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_X2hkyRX2_sendMessage);
}

void Heavy_ChaffVerb::cVar_D5qtwWo5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_Gzvjcgdo, 0, m, &cVar_Gzvjcgdo_sendMessage);
}

void Heavy_ChaffVerb::cVar_Gzvjcgdo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_s4j6h4NY, HV_BINOP_ADD, 0, m, &cBinop_s4j6h4NY_sendMessage);
}

void Heavy_ChaffVerb::cVar_Dy0ddCKf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_6QYovvZZ, HV_BINOP_ADD, 0, m, &cBinop_6QYovvZZ_sendMessage);
}

void Heavy_ChaffVerb::cVar_eUyh8bzR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_8RATZrXq_sendMessage);
  cIf_onMessage(_c, &Context(_c)->cIf_GxPrETHx, 0, m, &cIf_GxPrETHx_sendMessage);
}

void Heavy_ChaffVerb::cUnop_qYJLrLjb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_6QYovvZZ, HV_BINOP_ADD, 1, m, &cBinop_6QYovvZZ_sendMessage);
}

void Heavy_ChaffVerb::cUnop_0ysSkxwj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_6QYovvZZ, HV_BINOP_ADD, 1, m, &cBinop_6QYovvZZ_sendMessage);
}

void Heavy_ChaffVerb::cIf_GxPrETHx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cUnop_onMessage(_c, HV_UNOP_CEIL, m, &cUnop_0ysSkxwj_sendMessage);
      break;
    }
    case 1: {
      cUnop_onMessage(_c, HV_UNOP_FLOOR, m, &cUnop_qYJLrLjb_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_ChaffVerb::cBinop_8RATZrXq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_GxPrETHx, 1, m, &cIf_GxPrETHx_sendMessage);
}

void Heavy_ChaffVerb::cVar_w0Yog419_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_i9gALaeC_sendMessage);
  cIf_onMessage(_c, &Context(_c)->cIf_kZ7l6slT, 0, m, &cIf_kZ7l6slT_sendMessage);
}

void Heavy_ChaffVerb::cUnop_txorMjqT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_KxDIFLft_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_ChaffVerb::cUnop_F4l19tyG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_KxDIFLft_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_ChaffVerb::cIf_kZ7l6slT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cUnop_onMessage(_c, HV_UNOP_CEIL, m, &cUnop_F4l19tyG_sendMessage);
      break;
    }
    case 1: {
      cUnop_onMessage(_c, HV_UNOP_FLOOR, m, &cUnop_txorMjqT_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_ChaffVerb::cBinop_i9gALaeC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_kZ7l6slT, 1, m, &cIf_kZ7l6slT_sendMessage);
}

void Heavy_ChaffVerb::cSwitchcase_KxDIFLft_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xFFFFFFFF: { // "bang"
      cSlice_onMessage(_c, &Context(_c)->cSlice_NrY6ecRa, 0, m, &cSlice_NrY6ecRa_sendMessage);
      break;
    }
    case 0x3E004DAB: { // "set"
      cSlice_onMessage(_c, &Context(_c)->cSlice_FpV2fsVZ, 0, m, &cSlice_FpV2fsVZ_sendMessage);
      break;
    }
    default: {
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_3Pj5UZpE_sendMessage);
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_UzKO3JJ0_sendMessage);
      break;
    }
  }
}

void Heavy_ChaffVerb::cSlice_NrY6ecRa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cVar_onMessage(_c, &Context(_c)->cVar_vGKcHmze, 0, m, &cVar_vGKcHmze_sendMessage);
      break;
    }
    case 1: {
      cVar_onMessage(_c, &Context(_c)->cVar_vGKcHmze, 0, m, &cVar_vGKcHmze_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_ChaffVerb::cSlice_FpV2fsVZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cBinop_onMessage(_c, &Context(_c)->cBinop_ADwXGBqB, HV_BINOP_NEQ, 1, m, &cBinop_ADwXGBqB_sendMessage);
      cVar_onMessage(_c, &Context(_c)->cVar_vGKcHmze, 1, m, &cVar_vGKcHmze_sendMessage);
      break;
    }
    case 1: {
      cBinop_onMessage(_c, &Context(_c)->cBinop_ADwXGBqB, HV_BINOP_NEQ, 1, m, &cBinop_ADwXGBqB_sendMessage);
      cVar_onMessage(_c, &Context(_c)->cVar_vGKcHmze, 1, m, &cVar_vGKcHmze_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_ChaffVerb::cVar_vGKcHmze_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_4C6K0X2G_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_x1raXrcS_sendMessage);
}

void Heavy_ChaffVerb::cIf_tirxjr7F_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_L5QelSwy_sendMessage);
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_vf2l2wZQ_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_ChaffVerb::cCast_L5QelSwy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_ADwXGBqB, HV_BINOP_NEQ, 1, m, &cBinop_ADwXGBqB_sendMessage);
}

void Heavy_ChaffVerb::cCast_vf2l2wZQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_vGKcHmze, 0, m, &cVar_vGKcHmze_sendMessage);
}

void Heavy_ChaffVerb::cBinop_ADwXGBqB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_tirxjr7F, 1, m, &cIf_tirxjr7F_sendMessage);
}

void Heavy_ChaffVerb::cCast_3Pj5UZpE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_ADwXGBqB, HV_BINOP_NEQ, 0, m, &cBinop_ADwXGBqB_sendMessage);
}

void Heavy_ChaffVerb::cCast_UzKO3JJ0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_tirxjr7F, 0, m, &cIf_tirxjr7F_sendMessage);
}

void Heavy_ChaffVerb::cIf_RKwV0BYN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cVar_onMessage(_c, &Context(_c)->cVar_D5qtwWo5, 0, m, &cVar_D5qtwWo5_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_ChaffVerb::cIf_AxC4FC0r_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cIf_onMessage(_c, &Context(_c)->cIf_RKwV0BYN, 0, m, &cIf_RKwV0BYN_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_ChaffVerb::cIf_CCdcjYus_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cIf_onMessage(_c, &Context(_c)->cIf_RKwV0BYN, 0, m, &cIf_RKwV0BYN_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_ChaffVerb::cIf_YzPmdZjq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cIf_onMessage(_c, &Context(_c)->cIf_RKwV0BYN, 0, m, &cIf_RKwV0BYN_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_ChaffVerb::cIf_3S3klRuP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cVar_onMessage(_c, &Context(_c)->cVar_VMcLwNaV, 0, m, &cVar_VMcLwNaV_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_ChaffVerb::cCast_xOObeuXx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_Dy0ddCKf, 0, m, &cVar_Dy0ddCKf_sendMessage);
}

void Heavy_ChaffVerb::cMsg_Kpu5Xpzv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_AxC4FC0r, 1, m, &cIf_AxC4FC0r_sendMessage);
}

void Heavy_ChaffVerb::cMsg_6Nt4UG02_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_YzPmdZjq, 1, m, &cIf_YzPmdZjq_sendMessage);
}

void Heavy_ChaffVerb::cMsg_KQE5if51_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_AxC4FC0r, 1, m, &cIf_AxC4FC0r_sendMessage);
  cIf_onMessage(_c, &Context(_c)->cIf_CCdcjYus, 1, m, &cIf_CCdcjYus_sendMessage);
  cIf_onMessage(_c, &Context(_c)->cIf_YzPmdZjq, 1, m, &cIf_YzPmdZjq_sendMessage);
}

void Heavy_ChaffVerb::cBinop_vX1elQre_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_RayvicSX, 0, m, &cVar_RayvicSX_sendMessage);
}

void Heavy_ChaffVerb::cBinop_nwEeAe6X_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 100.0f, 0, m, &cBinop_vX1elQre_sendMessage);
}

void Heavy_ChaffVerb::cMsg_lB9xPzai_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cVar_onMessage(_c, &Context(_c)->cVar_VMcLwNaV, 0, m, &cVar_VMcLwNaV_sendMessage);
}

void Heavy_ChaffVerb::cBinop_fchnKVOE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_40p842Kz, HV_BINOP_MULTIPLY, 0, m, &cBinop_40p842Kz_sendMessage);
}

void Heavy_ChaffVerb::cBinop_8zCgvJkM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_fchnKVOE, HV_BINOP_MOD_UNIPOLAR, 0, m, &cBinop_fchnKVOE_sendMessage);
}

void Heavy_ChaffVerb::cMsg_INDGEanL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_CCdcjYus, 1, m, &cIf_CCdcjYus_sendMessage);
}

void Heavy_ChaffVerb::cBinop_6QYovvZZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_RuLju4zG_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_UUZBFZbJ_sendMessage);
}

void Heavy_ChaffVerb::cBinop_QNO7eqAJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_lXxlgfO4, 0, m, &cVar_lXxlgfO4_sendMessage);
}

void Heavy_ChaffVerb::cCast_RuLju4zG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_QNO7eqAJ, HV_BINOP_ADD, 1, m, &cBinop_QNO7eqAJ_sendMessage);
}

void Heavy_ChaffVerb::cCast_UUZBFZbJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_D5qtwWo5, 0, m, &cVar_D5qtwWo5_sendMessage);
}

void Heavy_ChaffVerb::cCast_x1raXrcS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_q4m76GIB_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_ChaffVerb::cCast_4C6K0X2G_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_KQE5if51_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cBinop_ZvsuUsqq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_65zwXySq, 0, m, &cVar_65zwXySq_sendMessage);
}

void Heavy_ChaffVerb::cBinop_40p842Kz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_CCdcjYus, 0, m, &cIf_CCdcjYus_sendMessage);
}

void Heavy_ChaffVerb::cBinop_klI8fYA9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_YzPmdZjq, 0, m, &cIf_YzPmdZjq_sendMessage);
}

void Heavy_ChaffVerb::cBinop_Q4XgR5Hy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SIN, m, &cUnop_Tnl6GXQ3_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 3.1415f, 0, m, &cBinop_klI8fYA9_sendMessage);
}

void Heavy_ChaffVerb::cBinop_Y3gykJRK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 314.0f, 0, m, &cBinop_T4dJmJGJ_sendMessage);
}

void Heavy_ChaffVerb::cBinop_T4dJmJGJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 100.0f, 0, m, &cBinop_Q4XgR5Hy_sendMessage);
}

void Heavy_ChaffVerb::cBinop_DQIaGrMG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_OuBkSOsn, 1, m, &cVar_OuBkSOsn_sendMessage);
}

void Heavy_ChaffVerb::cBinop_tj25aSOn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_d2qJXo7W, 0, m, &cVar_d2qJXo7W_sendMessage);
}

void Heavy_ChaffVerb::cBinop_xG5WAEvV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_JHWFBLAA, 0, m, &cVar_JHWFBLAA_sendMessage);
}

void Heavy_ChaffVerb::cMsg_S1cvVh5B_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cVar_onMessage(_c, &Context(_c)->cVar_D5qtwWo5, 0, m, &cVar_D5qtwWo5_sendMessage);
}

void Heavy_ChaffVerb::cBinop_Q5PW5Apn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Eu5XNvYU, HV_BINOP_MULTIPLY, 0, m, &cBinop_Eu5XNvYU_sendMessage);
}

void Heavy_ChaffVerb::cBinop_Eu5XNvYU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_3S3klRuP, 0, m, &cIf_3S3klRuP_sendMessage);
}

void Heavy_ChaffVerb::cBinop_jX3eoTPD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_QNO7eqAJ, HV_BINOP_ADD, 0, m, &cBinop_QNO7eqAJ_sendMessage);
}

void Heavy_ChaffVerb::cCast_K3g6VAIF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_jX3eoTPD, HV_BINOP_ADD, 1, m, &cBinop_jX3eoTPD_sendMessage);
}

void Heavy_ChaffVerb::cCast_X2hkyRX2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_D5qtwWo5, 0, m, &cVar_D5qtwWo5_sendMessage);
}

void Heavy_ChaffVerb::cCast_XRVxYpn6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_RKwV0BYN, 1, m, &cIf_RKwV0BYN_sendMessage);
}

void Heavy_ChaffVerb::cCast_cu3XqxHu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_tRepiiKO_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_ChaffVerb::cCast_9KXXAcmN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_RayvicSX, 0, m, &cVar_RayvicSX_sendMessage);
}

void Heavy_ChaffVerb::cCast_TsZ884bh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Eu5XNvYU, HV_BINOP_MULTIPLY, 1, m, &cBinop_Eu5XNvYU_sendMessage);
}

void Heavy_ChaffVerb::cCast_SKmDvzfp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_D0PC9qMs_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_ChaffVerb::cCast_BpaOuBCv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_3S3klRuP, 1, m, &cIf_3S3klRuP_sendMessage);
}

void Heavy_ChaffVerb::cCast_icsTl5oz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Q5PW5Apn, HV_BINOP_ADD, 1, m, &cBinop_Q5PW5Apn_sendMessage);
}

void Heavy_ChaffVerb::cCast_bnocvfW9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_RayvicSX, 0, m, &cVar_RayvicSX_sendMessage);
}

void Heavy_ChaffVerb::cBinop_99SszjlU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_jX3eoTPD, HV_BINOP_ADD, 0, m, &cBinop_jX3eoTPD_sendMessage);
}

void Heavy_ChaffVerb::cBinop_s4j6h4NY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_99SszjlU, HV_BINOP_MULTIPLY, 0, m, &cBinop_99SszjlU_sendMessage);
}

void Heavy_ChaffVerb::cCast_SLeVZYQu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_D5qtwWo5, 0, m, &cVar_D5qtwWo5_sendMessage);
}

void Heavy_ChaffVerb::cCast_ZcSrvbRs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_99SszjlU, HV_BINOP_MULTIPLY, 1, m, &cBinop_99SszjlU_sendMessage);
}

void Heavy_ChaffVerb::cCast_X7dflLAf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_D5qtwWo5, 0, m, &cVar_D5qtwWo5_sendMessage);
}

void Heavy_ChaffVerb::cCast_crlAZQbq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_s4j6h4NY, HV_BINOP_ADD, 1, m, &cBinop_s4j6h4NY_sendMessage);
}

void Heavy_ChaffVerb::cMsg_zkWX3CVd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_4C6K0X2G_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_x1raXrcS_sendMessage);
}

void Heavy_ChaffVerb::cReceive_488053y6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_4AotWg2y_sendMessage(_c, 0, m);
  cMsg_JBIbhXu0_sendMessage(_c, 0, m);
  cMsg_ZXWLgNUv_sendMessage(_c, 0, m);
  cMsg_kgMVc8YN_sendMessage(_c, 0, m);
  cMsg_YTsoLAqd_sendMessage(_c, 0, m);
  cMsg_FXDNwlmu_sendMessage(_c, 0, m);
  cMsg_49DsYQhA_sendMessage(_c, 0, m);
  cMsg_bjyCPvFF_sendMessage(_c, 0, m);
  cMsg_DsiVNcQb_sendMessage(_c, 0, m);
  cMsg_m0sszrfW_sendMessage(_c, 0, m);
  cMsg_viGNWezD_sendMessage(_c, 0, m);
  cMsg_214ERUVM_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_jGto9i39, 0, m, &cVar_jGto9i39_sendMessage);
  cMsg_6rVWRQZl_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_DQO2LvfY, 0, m, &cVar_DQO2LvfY_sendMessage);
  cMsg_DevgMWxx_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_I5gaO0tC, 0, m, &cVar_I5gaO0tC_sendMessage);
  cMsg_AiAnWgne_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_KRCt0WBa, 0, m, &cVar_KRCt0WBa_sendMessage);
  cMsg_0ABzFTWn_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_nf9bFbxt, 0, m, &cVar_nf9bFbxt_sendMessage);
  cMsg_IPJQniWW_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_d2qJXo7W, 0, m, &cVar_d2qJXo7W_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_blvX2ydM, 0, m, &cVar_blvX2ydM_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_65zwXySq, 0, m, &cVar_65zwXySq_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_ZdJmEBbE, 0, m, &cVar_ZdJmEBbE_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_sGcl5Qwr, 0, m, &cVar_sGcl5Qwr_sendMessage);
  cMsg_cNbjylTe_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_JHWFBLAA, 0, m, &cVar_JHWFBLAA_sendMessage);
  cMsg_pgfhv5Ee_sendMessage(_c, 0, m);
  cSwitchcase_iGciybF6_onMessage(_c, NULL, 0, m, NULL);
  cMsg_S1cvVh5B_sendMessage(_c, 0, m);
  cMsg_zkWX3CVd_sendMessage(_c, 0, m);
  cMsg_lB9xPzai_sendMessage(_c, 0, m);
  cSwitchcase_ImglQkga_onMessage(_c, NULL, 0, m, NULL);
  cVar_onMessage(_c, &Context(_c)->cVar_9LdQQRSE, 0, m, &cVar_9LdQQRSE_sendMessage);
  cMsg_hqXcXCS6_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_VDMWxd5L, 0, m, &cVar_VDMWxd5L_sendMessage);
  cMsg_dzwlQ8yr_sendMessage(_c, 0, m);
  cMsg_2LVo4F5W_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_wGus0R6b, 0, m, &cVar_wGus0R6b_sendMessage);
  cMsg_aNZLIfOi_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_cp8DKvRz, 0, m, &cTabhead_cp8DKvRz_sendMessage);
  cMsg_cEEB3nYX_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_dLvNv0er, 0, m, &cVar_dLvNv0er_sendMessage);
  cMsg_jGhbUYvn_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_qyVXGops, 0, m, &cTabhead_qyVXGops_sendMessage);
  cMsg_rBaptnYC_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_n1oflsyY, 0, m, &cVar_n1oflsyY_sendMessage);
  cMsg_vbCACrHm_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_P1m3wftP, 0, m, &cTabhead_P1m3wftP_sendMessage);
  cMsg_OLHvVK9X_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_EkCzpM1O, 0, m, &cVar_EkCzpM1O_sendMessage);
  cMsg_sPA6I0qg_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_KfIdq9l7, 0, m, &cTabhead_KfIdq9l7_sendMessage);
  cMsg_QG1mDwBf_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_62QYKRhC, 0, m, &cVar_62QYKRhC_sendMessage);
  cMsg_bNQYXxiz_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_nqB3ukpi, 0, m, &cTabhead_nqB3ukpi_sendMessage);
  cMsg_yvQht1tf_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_vo0ItMgB, 0, m, &cVar_vo0ItMgB_sendMessage);
  cMsg_HapOxkwp_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_MtHrWXUm, 0, m, &cTabhead_MtHrWXUm_sendMessage);
  cMsg_KAC4ltPi_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_QrDb74mu, 0, m, &cVar_QrDb74mu_sendMessage);
  cMsg_01JXROjJ_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_Bf5vLuO2, 0, m, &cTabhead_Bf5vLuO2_sendMessage);
  cMsg_Q21h6JmA_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_t9necXUl, 0, m, &cVar_t9necXUl_sendMessage);
  cMsg_DDd1dlqu_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_yOkCpBwB, 0, m, &cTabhead_yOkCpBwB_sendMessage);
  cMsg_ZGK52a5t_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_DFJ56Zu6, 0, m, &cVar_DFJ56Zu6_sendMessage);
  cMsg_8TUPkLkk_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_cOmUfBdC, 0, m, &cTabhead_cOmUfBdC_sendMessage);
  cMsg_1i077q1J_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_94vzqeN3, 0, m, &cVar_94vzqeN3_sendMessage);
  cMsg_hTOqHfVJ_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_FH5Gvk0k, 0, m, &cTabhead_FH5Gvk0k_sendMessage);
  cMsg_ZFvvdrqI_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_abx5UgOt, 0, m, &cVar_abx5UgOt_sendMessage);
  cMsg_NiTP1fJl_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_WKn3hzaV, 0, m, &cTabhead_WKn3hzaV_sendMessage);
}

void Heavy_ChaffVerb::cReceive_ZlsdcSog_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 157.0f, 0, m, &cBinop_tj25aSOn_sendMessage);
}

void Heavy_ChaffVerb::cReceive_cQcNDf3w_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_w0Yog419, 0, m, &cVar_w0Yog419_sendMessage);
}

void Heavy_ChaffVerb::cReceive_bAdbvxb0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_cXWBY3z9, 0, m, &cVar_cXWBY3z9_sendMessage);
}

void Heavy_ChaffVerb::cReceive_8UboToci_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_40p842Kz, HV_BINOP_MULTIPLY, 1, m, &cBinop_40p842Kz_sendMessage);
}

void Heavy_ChaffVerb::cReceive_8J387eUF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_crlAZQbq_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_X7dflLAf_sendMessage);
}

void Heavy_ChaffVerb::cReceive_QT5czTTM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_ZcSrvbRs_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_SLeVZYQu_sendMessage);
}

void Heavy_ChaffVerb::cReceive_HJav80r1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_Dy0ddCKf, 0, m, &cVar_Dy0ddCKf_sendMessage);
}

void Heavy_ChaffVerb::cReceive_M2aZR2uM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_xOObeuXx_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_eUyh8bzR, 0, m, &cVar_eUyh8bzR_sendMessage);
}

void Heavy_ChaffVerb::cReceive_aYM6HSmC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 157.0f, 0, m, &cBinop_xG5WAEvV_sendMessage);
}

void Heavy_ChaffVerb::cReceive_mzVLspDl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_icsTl5oz_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_bnocvfW9_sendMessage);
}

void Heavy_ChaffVerb::cReceive_sxSkmtjU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_TsZ884bh_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_9KXXAcmN_sendMessage);
}

void Heavy_ChaffVerb::cReceive_oQbZ2gro_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_BpaOuBCv_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_SKmDvzfp_sendMessage);
}

void Heavy_ChaffVerb::cReceive_MGRnV4rq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_hynS8Scz, m);
}

void Heavy_ChaffVerb::cReceive_EzkQWw0E_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_5gikGZdR, m);
}

void Heavy_ChaffVerb::cReceive_hRdBO2Te_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_blvX2ydM, 0, m, &cVar_blvX2ydM_sendMessage);
}

void Heavy_ChaffVerb::cReceive_y9abJ4C7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 100.0f, 0, m, &cBinop_ZvsuUsqq_sendMessage);
}

void Heavy_ChaffVerb::cReceive_OLmy2yPO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_7MbsimwS, 0, m, &cVar_7MbsimwS_sendMessage);
}

void Heavy_ChaffVerb::cReceive_EHCCCnuP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_UL2ol6A2, 0, m, &cVar_UL2ol6A2_sendMessage);
}

void Heavy_ChaffVerb::cReceive_upRSlT4T_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_nf9bFbxt, 0, m, &cVar_nf9bFbxt_sendMessage);
}

void Heavy_ChaffVerb::cReceive_TlWq6lUv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_51CGUAQR, m);
}

void Heavy_ChaffVerb::cReceive_Cg20Zzis_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_8cUDkXDK, m);
}

void Heavy_ChaffVerb::cReceive_OY31OVQS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_OipbTnGn, HV_BINOP_MULTIPLY, 1, m, &cBinop_OipbTnGn_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_NRRgyJSI_sendMessage);
}

void Heavy_ChaffVerb::cReceive_2EYMm4I7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_XRVxYpn6_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_cu3XqxHu_sendMessage);
}




/*
 * Context Process Implementation
 */

int Heavy_ChaffVerb::process(float **inputBuffers, float **outputBuffers, int n) {
  while (hLp_hasData(&inQueue)) {
    hv_uint32_t numBytes = 0;
    ReceiverMessagePair *p = reinterpret_cast<ReceiverMessagePair *>(hLp_getReadBuffer(&inQueue, &numBytes));
    hv_assert(numBytes >= sizeof(ReceiverMessagePair));
    scheduleMessageForReceiver(p->receiverHash, &p->msg);
    hLp_consume(&inQueue);
  }

  sendBangToReceiver(0xDD21C0EB); // send to __hv_bang~ on next cycle
  const int n4 = n & ~HV_N_SIMD_MASK; // ensure that the block size is a multiple of HV_N_SIMD

  // temporary signal vars
  hv_bufferf_t Bf0, Bf1, Bf2, Bf3, Bf4, Bf5, Bf6, Bf7, Bf8, Bf9, Bf10, Bf11, Bf12, Bf13, Bf14;
  hv_bufferi_t Bi0, Bi1;

  // input and output vars
  hv_bufferf_t O0, O1;
  hv_bufferf_t I0;

  // declare and init the zero buffer
  hv_bufferf_t ZERO; __hv_zero_f(VOf(ZERO));

  hv_uint32_t nextBlock = blockStartTimestamp;
  for (int n = 0; n < n4; n += HV_N_SIMD) {

    // process all of the messages for this block
    nextBlock += HV_N_SIMD;
    while (mq_hasMessageBefore(&mq, nextBlock)) {
      MessageNode *const node = mq_peek(&mq);
      node->sendMessage(this, node->let, node->m);
      mq_pop(&mq);
    }

    // load input buffers
    __hv_load_f(inputBuffers[0]+n, VOf(I0));

    // zero output buffers
    __hv_zero_f(VOf(O0));
    __hv_zero_f(VOf(O1));

    // process all signal functions
    __hv_phasor_k_f(&sPhasor_oMM6tSkH, VOf(Bf0));
    __hv_var_k_f(VOf(Bf1), 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f);
    __hv_sub_f(VIf(Bf0), VIf(Bf1), VOf(Bf1));
    __hv_var_k_f(VOf(Bf2), 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f);
    __hv_mul_f(VIf(Bf1), VIf(Bf2), VOf(Bf2));
    __hv_floor_f(VIf(Bf2), VOf(Bf1));
    __hv_sub_f(VIf(Bf2), VIf(Bf1), VOf(Bf1));
    __hv_var_k_f(VOf(Bf2), 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f);
    __hv_sub_f(VIf(Bf1), VIf(Bf2), VOf(Bf2));
    __hv_abs_f(VIf(Bf2), VOf(Bf2));
    __hv_var_k_f(VOf(Bf1), 0.25f, 0.25f, 0.25f, 0.25f, 0.25f, 0.25f, 0.25f, 0.25f);
    __hv_sub_f(VIf(Bf2), VIf(Bf1), VOf(Bf1));
    __hv_var_k_f(VOf(Bf2), 6.28319f, 6.28319f, 6.28319f, 6.28319f, 6.28319f, 6.28319f, 6.28319f, 6.28319f);
    __hv_mul_f(VIf(Bf1), VIf(Bf2), VOf(Bf2));
    __hv_mul_f(VIf(Bf2), VIf(Bf2), VOf(Bf1));
    __hv_mul_f(VIf(Bf2), VIf(Bf1), VOf(Bf3));
    __hv_mul_f(VIf(Bf3), VIf(Bf1), VOf(Bf1));
    __hv_var_k_f(VOf(Bf4), 0.00784314f, 0.00784314f, 0.00784314f, 0.00784314f, 0.00784314f, 0.00784314f, 0.00784314f, 0.00784314f);
    __hv_var_k_f(VOf(Bf5), 0.166667f, 0.166667f, 0.166667f, 0.166667f, 0.166667f, 0.166667f, 0.166667f, 0.166667f);
    __hv_mul_f(VIf(Bf3), VIf(Bf5), VOf(Bf5));
    __hv_sub_f(VIf(Bf2), VIf(Bf5), VOf(Bf5));
    __hv_fma_f(VIf(Bf1), VIf(Bf4), VIf(Bf5), VOf(Bf5));
    __hv_line_f(&sLine_UVTMOFJw, VOf(Bf4));
    __hv_line_f(&sLine_KxXNQs2p, VOf(Bf1));
    __hv_fma_f(VIf(Bf0), VIf(Bf4), VIf(Bf1), VOf(Bf2));
    __hv_tabhead_f(&sTabhead_TMrZvmRx, VOf(Bf3));
    __hv_var_k_f_r(VOf(Bf6), -1.0f, -2.0f, -3.0f, -4.0f, -5.0f, -6.0f, -7.0f, -8.0f);
    __hv_add_f(VIf(Bf3), VIf(Bf6), VOf(Bf6));
    __hv_varread_f(&sVarf_gJcP0uUO, VOf(Bf3));
    __hv_mul_f(VIf(Bf2), VIf(Bf3), VOf(Bf3));
    __hv_varread_f(&sVarf_ulhN83Qc, VOf(Bf2));
    __hv_min_f(VIf(Bf3), VIf(Bf2), VOf(Bf2));
    __hv_zero_f(VOf(Bf3));
    __hv_max_f(VIf(Bf2), VIf(Bf3), VOf(Bf3));
    __hv_sub_f(VIf(Bf6), VIf(Bf3), VOf(Bf3));
    __hv_floor_f(VIf(Bf3), VOf(Bf6));
    __hv_varread_f(&sVarf_mCi7Rvj4, VOf(Bf2));
    __hv_zero_f(VOf(Bf7));
    __hv_lt_f(VIf(Bf6), VIf(Bf7), VOf(Bf7));
    __hv_and_f(VIf(Bf2), VIf(Bf7), VOf(Bf7));
    __hv_add_f(VIf(Bf6), VIf(Bf7), VOf(Bf7));
    __hv_cast_fi(VIf(Bf7), VOi(Bi0));
    __hv_var_k_i(VOi(Bi1), 1, 1, 1, 1, 1, 1, 1, 1);
    __hv_add_i(VIi(Bi0), VIi(Bi1), VOi(Bi1));
    __hv_tabread_if(&sTabread_Gn5B9YNe, VIi(Bi1), VOf(Bf7));
    __hv_tabread_if(&sTabread_5AlxjDo1, VIi(Bi0), VOf(Bf2));
    __hv_sub_f(VIf(Bf7), VIf(Bf2), VOf(Bf7));
    __hv_sub_f(VIf(Bf3), VIf(Bf6), VOf(Bf6));
    __hv_fma_f(VIf(Bf7), VIf(Bf6), VIf(Bf2), VOf(Bf2));
    __hv_var_k_f(VOf(Bf6), 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f);
    __hv_add_f(VIf(Bf0), VIf(Bf6), VOf(Bf6));
    __hv_floor_f(VIf(Bf6), VOf(Bf0));
    __hv_sub_f(VIf(Bf6), VIf(Bf0), VOf(Bf0));
    __hv_var_k_f(VOf(Bf6), 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f);
    __hv_sub_f(VIf(Bf0), VIf(Bf6), VOf(Bf6));
    __hv_var_k_f(VOf(Bf7), 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f);
    __hv_mul_f(VIf(Bf6), VIf(Bf7), VOf(Bf7));
    __hv_floor_f(VIf(Bf7), VOf(Bf6));
    __hv_sub_f(VIf(Bf7), VIf(Bf6), VOf(Bf6));
    __hv_var_k_f(VOf(Bf7), 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f);
    __hv_sub_f(VIf(Bf6), VIf(Bf7), VOf(Bf7));
    __hv_abs_f(VIf(Bf7), VOf(Bf7));
    __hv_var_k_f(VOf(Bf6), 0.25f, 0.25f, 0.25f, 0.25f, 0.25f, 0.25f, 0.25f, 0.25f);
    __hv_sub_f(VIf(Bf7), VIf(Bf6), VOf(Bf6));
    __hv_var_k_f(VOf(Bf7), 6.28319f, 6.28319f, 6.28319f, 6.28319f, 6.28319f, 6.28319f, 6.28319f, 6.28319f);
    __hv_mul_f(VIf(Bf6), VIf(Bf7), VOf(Bf7));
    __hv_mul_f(VIf(Bf7), VIf(Bf7), VOf(Bf6));
    __hv_mul_f(VIf(Bf7), VIf(Bf6), VOf(Bf3));
    __hv_mul_f(VIf(Bf3), VIf(Bf6), VOf(Bf6));
    __hv_var_k_f(VOf(Bf8), 0.00784314f, 0.00784314f, 0.00784314f, 0.00784314f, 0.00784314f, 0.00784314f, 0.00784314f, 0.00784314f);
    __hv_var_k_f(VOf(Bf9), 0.166667f, 0.166667f, 0.166667f, 0.166667f, 0.166667f, 0.166667f, 0.166667f, 0.166667f);
    __hv_mul_f(VIf(Bf3), VIf(Bf9), VOf(Bf9));
    __hv_sub_f(VIf(Bf7), VIf(Bf9), VOf(Bf9));
    __hv_fma_f(VIf(Bf6), VIf(Bf8), VIf(Bf9), VOf(Bf9));
    __hv_fma_f(VIf(Bf0), VIf(Bf4), VIf(Bf1), VOf(Bf1));
    __hv_tabhead_f(&sTabhead_EDOuBrpS, VOf(Bf4));
    __hv_var_k_f_r(VOf(Bf0), -1.0f, -2.0f, -3.0f, -4.0f, -5.0f, -6.0f, -7.0f, -8.0f);
    __hv_add_f(VIf(Bf4), VIf(Bf0), VOf(Bf0));
    __hv_varread_f(&sVarf_F6GntIho, VOf(Bf4));
    __hv_mul_f(VIf(Bf1), VIf(Bf4), VOf(Bf4));
    __hv_varread_f(&sVarf_v3sNsTsi, VOf(Bf1));
    __hv_min_f(VIf(Bf4), VIf(Bf1), VOf(Bf1));
    __hv_zero_f(VOf(Bf4));
    __hv_max_f(VIf(Bf1), VIf(Bf4), VOf(Bf4));
    __hv_sub_f(VIf(Bf0), VIf(Bf4), VOf(Bf4));
    __hv_floor_f(VIf(Bf4), VOf(Bf0));
    __hv_varread_f(&sVarf_Br5dP5pX, VOf(Bf1));
    __hv_zero_f(VOf(Bf8));
    __hv_lt_f(VIf(Bf0), VIf(Bf8), VOf(Bf8));
    __hv_and_f(VIf(Bf1), VIf(Bf8), VOf(Bf8));
    __hv_add_f(VIf(Bf0), VIf(Bf8), VOf(Bf8));
    __hv_cast_fi(VIf(Bf8), VOi(Bi0));
    __hv_var_k_i(VOi(Bi1), 1, 1, 1, 1, 1, 1, 1, 1);
    __hv_add_i(VIi(Bi0), VIi(Bi1), VOi(Bi1));
    __hv_tabread_if(&sTabread_7H0P0rF2, VIi(Bi1), VOf(Bf8));
    __hv_tabread_if(&sTabread_KlTbtfq8, VIi(Bi0), VOf(Bf1));
    __hv_sub_f(VIf(Bf8), VIf(Bf1), VOf(Bf8));
    __hv_sub_f(VIf(Bf4), VIf(Bf0), VOf(Bf0));
    __hv_fma_f(VIf(Bf8), VIf(Bf0), VIf(Bf1), VOf(Bf1));
    __hv_mul_f(VIf(Bf9), VIf(Bf1), VOf(Bf1));
    __hv_fma_f(VIf(Bf5), VIf(Bf2), VIf(Bf1), VOf(Bf1));
    __hv_tabwrite_f(&sTabwrite_3dVaqRWN, VIf(I0));
    __hv_varread_f(&sVarf_ZzPSROtU, VOf(Bf2));
    __hv_rpole_f(&sRPole_o2U1PGba, VIf(Bf1), VIf(Bf2), VOf(Bf2));
    __hv_var_k_f(VOf(Bf1), 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f);
    __hv_del1_f(&sDel1_JhcQu2FE, VIf(Bf2), VOf(Bf5));
    __hv_mul_f(VIf(Bf5), VIf(Bf1), VOf(Bf1));
    __hv_sub_f(VIf(Bf2), VIf(Bf1), VOf(Bf1));
    __hv_varread_f(&sVarf_05SywGIo, VOf(Bf2));
    __hv_mul_f(VIf(Bf1), VIf(Bf2), VOf(Bf2));
    __hv_varread_f(&sVarf_51CGUAQR, VOf(Bf1));
    __hv_tabread_f(&sTabread_MBpVdwiF, VOf(Bf5));
    __hv_varread_f(&sVarf_8cUDkXDK, VOf(Bf9));
    __hv_mul_f(VIf(Bf5), VIf(Bf9), VOf(Bf9));
    __hv_fma_f(VIf(Bf2), VIf(Bf1), VIf(Bf9), VOf(Bf9));
    __hv_tabwrite_f(&sTabwrite_SXsn9obO, VIf(Bf9));
    __hv_varread_f(&sVarf_5gikGZdR, VOf(Bf9));
    __hv_fma_f(VIf(I0), VIf(Bf9), VIf(Bf5), VOf(Bf5));
    __hv_tabread_f(&sTabread_aLsECrs5, VOf(Bf9));
    __hv_varread_f(&sVarf_yuyuarWk, VOf(Bf1));
    __hv_mul_f(VIf(Bf9), VIf(Bf1), VOf(Bf1));
    __hv_varread_f(&sVarf_saMXdENi, VOf(Bf2));
    __hv_rpole_f(&sRPole_C9ZoRDL8, VIf(Bf1), VIf(Bf2), VOf(Bf2));
    __hv_sub_f(VIf(Bf2), VIf(Bf9), VOf(Bf2));
    __hv_line_f(&sLine_v8sA6rWG, VOf(Bf1));
    __hv_fma_f(VIf(Bf2), VIf(Bf1), VIf(Bf9), VOf(Bf9));
    __hv_line_f(&sLine_woutXzoG, VOf(Bf2));
    __hv_tabread_f(&sTabread_B8TSCxn7, VOf(Bf0));
    __hv_add_f(VIf(Bf5), VIf(Bf0), VOf(Bf8));
    __hv_tabread_f(&sTabread_gssM6Xbp, VOf(Bf4));
    __hv_add_f(VIf(Bf8), VIf(Bf4), VOf(Bf6));
    __hv_tabread_f(&sTabread_v8gCgSiv, VOf(Bf7));
    __hv_add_f(VIf(Bf6), VIf(Bf7), VOf(Bf3));
    __hv_tabread_f(&sTabread_ZVwjGSWx, VOf(Bf10));
    __hv_add_f(VIf(Bf3), VIf(Bf10), VOf(Bf11));
    __hv_tabread_f(&sTabread_pYhq9TgO, VOf(Bf12));
    __hv_add_f(VIf(Bf11), VIf(Bf12), VOf(Bf13));
    __hv_tabread_f(&sTabread_TFCHpICr, VOf(Bf14));
    __hv_tabwrite_f(&sTabwrite_406QjmMR, VIf(Bf5));
    __hv_sub_f(VIf(Bf5), VIf(Bf0), VOf(Bf0));
    __hv_tabwrite_f(&sTabwrite_WjBDwhFo, VIf(Bf0));
    __hv_sub_f(VIf(Bf8), VIf(Bf4), VOf(Bf4));
    __hv_tabwrite_f(&sTabwrite_tE63Zqi9, VIf(Bf4));
    __hv_sub_f(VIf(Bf6), VIf(Bf7), VOf(Bf7));
    __hv_tabwrite_f(&sTabwrite_pNsH1xbf, VIf(Bf7));
    __hv_sub_f(VIf(Bf11), VIf(Bf12), VOf(Bf12));
    __hv_tabwrite_f(&sTabwrite_xAbXIcpY, VIf(Bf12));
    __hv_sub_f(VIf(Bf3), VIf(Bf10), VOf(Bf10));
    __hv_tabwrite_f(&sTabwrite_sDmtIoVv, VIf(Bf10));
    __hv_fma_f(VIf(Bf9), VIf(Bf2), VIf(Bf13), VOf(Bf13));
    __hv_tabread_f(&sTabread_FBDeFP8S, VOf(Bf9));
    __hv_varread_f(&sVarf_dHhr6ESU, VOf(Bf10));
    __hv_mul_f(VIf(Bf9), VIf(Bf10), VOf(Bf10));
    __hv_varread_f(&sVarf_pteFS2PQ, VOf(Bf3));
    __hv_rpole_f(&sRPole_mih8cdmK, VIf(Bf10), VIf(Bf3), VOf(Bf3));
    __hv_sub_f(VIf(Bf3), VIf(Bf9), VOf(Bf3));
    __hv_fma_f(VIf(Bf3), VIf(Bf1), VIf(Bf9), VOf(Bf9));
    __hv_fma_f(VIf(Bf9), VIf(Bf2), VIf(Bf14), VOf(Bf14));
    __hv_add_f(VIf(Bf13), VIf(Bf14), VOf(Bf9));
    __hv_tabread_f(&sTabread_liVnSrA8, VOf(Bf3));
    __hv_varread_f(&sVarf_YmoKf5nx, VOf(Bf10));
    __hv_mul_f(VIf(Bf3), VIf(Bf10), VOf(Bf10));
    __hv_varread_f(&sVarf_tTcxmJiT, VOf(Bf12));
    __hv_rpole_f(&sRPole_1icqCNb4, VIf(Bf10), VIf(Bf12), VOf(Bf12));
    __hv_sub_f(VIf(Bf12), VIf(Bf3), VOf(Bf12));
    __hv_fma_f(VIf(Bf12), VIf(Bf1), VIf(Bf3), VOf(Bf3));
    __hv_mul_f(VIf(Bf3), VIf(Bf2), VOf(Bf3));
    __hv_tabread_f(&sTabread_Ry19IS0x, VOf(Bf12));
    __hv_varread_f(&sVarf_qiuzN5la, VOf(Bf10));
    __hv_mul_f(VIf(Bf12), VIf(Bf10), VOf(Bf10));
    __hv_varread_f(&sVarf_A7gWX3An, VOf(Bf11));
    __hv_rpole_f(&sRPole_u80nZf9u, VIf(Bf10), VIf(Bf11), VOf(Bf11));
    __hv_sub_f(VIf(Bf11), VIf(Bf12), VOf(Bf11));
    __hv_fma_f(VIf(Bf11), VIf(Bf1), VIf(Bf12), VOf(Bf12));
    __hv_mul_f(VIf(Bf12), VIf(Bf2), VOf(Bf2));
    __hv_add_f(VIf(Bf3), VIf(Bf2), VOf(Bf12));
    __hv_add_f(VIf(Bf9), VIf(Bf12), VOf(Bf1));
    __hv_tabwrite_f(&sTabwrite_crqYqLHh, VIf(Bf1));
    __hv_sub_f(VIf(Bf13), VIf(Bf14), VOf(Bf1));
    __hv_sub_f(VIf(Bf3), VIf(Bf2), VOf(Bf11));
    __hv_add_f(VIf(Bf1), VIf(Bf11), VOf(Bf10));
    __hv_tabwrite_f(&sTabwrite_nUc2GthC, VIf(Bf10));
    __hv_sub_f(VIf(Bf9), VIf(Bf12), VOf(Bf12));
    __hv_tabwrite_f(&sTabwrite_5IRUmwEX, VIf(Bf12));
    __hv_sub_f(VIf(Bf1), VIf(Bf11), VOf(Bf11));
    __hv_tabwrite_f(&sTabwrite_NZHBFcRO, VIf(Bf11));
    __hv_line_f(&sLine_gMJPoKz9, VOf(Bf11));
    __hv_mul_f(VIf(Bf13), VIf(Bf11), VOf(Bf13));
    __hv_mul_f(VIf(Bf14), VIf(Bf11), VOf(Bf14));
    __hv_mul_f(VIf(Bf3), VIf(Bf11), VOf(Bf3));
    __hv_mul_f(VIf(Bf2), VIf(Bf11), VOf(Bf11));
    __hv_add_f(VIf(Bf14), VIf(Bf3), VOf(Bf3));
    __hv_add_f(VIf(Bf3), VIf(Bf11), VOf(Bf11));
    __hv_varread_f(&sVarf_hynS8Scz, VOf(Bf3));
    __hv_mul_f(VIf(I0), VIf(Bf3), VOf(Bf3));
    __hv_add_f(VIf(Bf11), VIf(Bf3), VOf(Bf11));
    __hv_add_f(VIf(Bf11), VIf(O1), VOf(O1));
    __hv_add_f(VIf(Bf13), VIf(Bf3), VOf(Bf3));
    __hv_add_f(VIf(Bf3), VIf(O0), VOf(O0));

    // save output vars to output buffer
    __hv_store_f(outputBuffers[0]+n, VIf(O0));
    __hv_store_f(outputBuffers[1]+n, VIf(O1));
  }

  blockStartTimestamp = nextBlock;

  return n4; // return the number of frames processed

}

int Heavy_ChaffVerb::processInline(float *inputBuffers, float *outputBuffers, int n4) {
  hv_assert(!(n4 & HV_N_SIMD_MASK)); // ensure that n4 is a multiple of HV_N_SIMD

  // define the heavy input buffer for 1 channel(s)
  float **const bIn = &inputBuffers;

  // define the heavy output buffer for 2 channel(s)
  float **const bOut = reinterpret_cast<float **>(hv_alloca(2*sizeof(float *)));
  bOut[0] = outputBuffers+(0*n4);
  bOut[1] = outputBuffers+(1*n4);

  int n = process(bIn, bOut, n4);
  return n;
}

int Heavy_ChaffVerb::processInlineInterleaved(float *inputBuffers, float *outputBuffers, int n4) {
  hv_assert(n4 & ~HV_N_SIMD_MASK); // ensure that n4 is a multiple of HV_N_SIMD

  // define the heavy input buffer for 1 channel(s), uninterleave
  float *const bIn = inputBuffers;

  // define the heavy output buffer for 2 channel(s)
  float *const bOut = reinterpret_cast<float *>(hv_alloca(2*n4*sizeof(float)));

  int n = processInline(bIn, bOut, n4);

  // interleave the heavy output into the output buffer
  #if HV_SIMD_AVX
  for (int i = 0, j = 0; j < n4; j += 8, i += 16) {
    __m256 x = _mm256_load_ps(bOut+j);    // LLLLLLLL
    __m256 y = _mm256_load_ps(bOut+n4+j); // RRRRRRRR
    __m256 a = _mm256_unpacklo_ps(x, y);  // LRLRLRLR
    __m256 b = _mm256_unpackhi_ps(x, y);  // LRLRLRLR
    _mm256_store_ps(outputBuffers+i, a);
    _mm256_store_ps(outputBuffers+8+i, b);
  }
  #elif HV_SIMD_SSE
  for (int i = 0, j = 0; j < n4; j += 4, i += 8) {
    __m128 x = _mm_load_ps(bOut+j);    // LLLL
    __m128 y = _mm_load_ps(bOut+n4+j); // RRRR
    __m128 a = _mm_unpacklo_ps(x, y);  // LRLR
    __m128 b = _mm_unpackhi_ps(x, y);  // LRLR
    _mm_store_ps(outputBuffers+i, a);
    _mm_store_ps(outputBuffers+4+i, b);
  }
  #elif HV_SIMD_NEON
  // https://community.arm.com/groups/processors/blog/2012/03/13/coding-for-neon--part-5-rearranging-vectors
  for (int i = 0, j = 0; j < n4; j += 4, i += 8) {
    float32x4_t x = vld1q_f32(bOut+j);
    float32x4_t y = vld1q_f32(bOut+n4+j);
    float32x4x2_t z = {x, y};
    vst2q_f32(outputBuffers+i, z); // interleave and store
  }
  #else // HV_SIMD_NONE
  for (int i = 0; i < 2; ++i) {
    for (int j = 0; j < n4; ++j) {
      outputBuffers[i+2*j] = bOut[i*n4+j];
    }
  }
  #endif

  return n;
}
